/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessComponent.impl;

import java.util.Iterator;
import java.util.List;

import net.simcafamily.paksou.businessComponent.ICategorieBC;
import net.simcafamily.paksou.businessComponent.IMotCleBC;
import net.simcafamily.paksou.businessObject.ICategorieBO;
import net.simcafamily.paksou.businessObject.IMotCleBO;
import net.simcafamily.paksou.businessObject.IOperationBO;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.GroupeVO;
import net.simcafamily.paksou.valueObject.MotCleVO;
import net.simcafamily.paksou.valueObject.OperationVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * The Class CategorieBC.
 * 
 * @author $Author: simon.guerard $
 * @version $Revision: 403 $
 */
public class CategorieBC implements ICategorieBC {

    /** The LOG. */
    private static final Log LOG = LogFactory.getLog(CategorieBC.class);

    /** The categorie BO. */
    private ICategorieBO categorieBO;

    /** The operation BO */
    private IOperationBO operationBO;

    /** The mot cle BC */
    private IMotCleBC motCleBC;

    /** The mot cle BO */
    private IMotCleBO motCleBO;

    /**
     * Associer categorie.
     * 
     * @param lstOperation
     *            the lst operation
     */
    public void associerCategorie(final List<OperationVO> lstOperation) {
        final Iterator<OperationVO> iterOperations = lstOperation.iterator();
        while (iterOperations.hasNext()) {
            final OperationVO opeVO = iterOperations.next();
            if (opeVO.getCategorie() == null) {
                chercherCategorie(opeVO);
            }
        }
    }

    /**
     * Cette methode permet d'ajouter un categorie a une operation.
     * 
     * @param opeVO
     * @param categorie
     */
    public void ajouterCategorie(final OperationVO opeVO, final String pCategorie) {
        // recherche de la categorie en base.
        CategorieVO categVO = this.categorieBO.findById(pCategorie);
        if (categVO == null) {
            if (CategorieBC.LOG.isDebugEnabled()) {
                CategorieBC.LOG.debug("la categorie n'existait pas, elle est donc creee.");
            }
            categVO = new CategorieVO();
            categVO.setLibelle(pCategorie);
            // creation de la categorie en base.
            this.categorieBO.persist(categVO);
        }
        // mise a jour de l'operation avec la categorie.
        opeVO.setCategorie(categVO);
        this.operationBO.update(opeVO);

        // recuperation d'un mot potentiel pour la categorie.
        final String motCle = this.motCleBC.identifierMotCle(opeVO.getLibelle());
        if (motCle != null) {
            if (CategorieBC.LOG.isDebugEnabled()) {
                CategorieBC.LOG.debug("le mot cle " + motCle + " sera associe a la categorie " + pCategorie + ".");
            }
            final MotCleVO motCleVO = this.motCleBC.ajouterMotCle(motCle, pCategorie);
            categVO.getLstMotsCles().add(motCleVO);
            this.categorieBO.update(categVO);
        }
    }

    public CategorieVO rechercherCategorieParId(final String pLibelle) {
        return this.categorieBO.findById(pLibelle);
    }

    /**
     * Chercher categorie.
     * 
     * @param opeVO
     *            the ope VO
     */
    private void chercherCategorie(final OperationVO opeVO) {
        if (CategorieBC.LOG.isDebugEnabled()) {
            CategorieBC.LOG.debug("recherche d'une categorie possible pour l'operation " + opeVO.getIdentifiant());
        }
        final String libelle = opeVO.getLibelle();
        final List<MotCleVO> corresp = this.motCleBO.retrieveValidList();
        if (CategorieBC.LOG.isDebugEnabled()) {
            CategorieBC.LOG.debug("recuperation de la liste des mots cles valides : " + corresp);
        }
        final Iterator<MotCleVO> iterCorresp = corresp.iterator();
        while (iterCorresp.hasNext()) {
            final MotCleVO motCle = iterCorresp.next();
            String pattern;
            if (motCle.getLibelle().equals(ConstantesValeurs.ABRV_VIREMENT)) {
                pattern = motCle.getLibelle() + ".*";
            } else {
                pattern = "(.* " + motCle.getLibelle() + " .*)|(" + motCle.getLibelle() + ")|(.* "
                        + motCle.getLibelle() + ")|(" + motCle.getLibelle() + " .*)";
            }
            if (libelle.matches(pattern)) {
                if (CategorieBC.LOG.isDebugEnabled()) {
                    CategorieBC.LOG.debug("le libelle de l'operation (" + libelle + ") contient un mot cle ("
                            + motCle.getLibelle() + ").");
                }
                final CategorieVO categVO = motCle.getCategorie();
                if (CategorieBC.LOG.isDebugEnabled()) {
                    CategorieBC.LOG.debug("la categorie " + categVO.getLibelle()
                            + " est associee a l'operation d'identifiant " + opeVO.getIdentifiant());
                }
                opeVO.setCategorie(categVO);
                opeVO.setAttribCategAuto(Boolean.TRUE);
                this.operationBO.update(opeVO);
            }
        }
    }

    public List<CategorieVO> recupererListeCategorie() {
        return this.categorieBO.retrieveList();
    }

    public List<CategorieVO> recupererListeCategorieParGroupe(final GroupeVO pGroupe) {
        return this.categorieBO.retrieveListByGroup(pGroupe);
    }

    /**
     * @return the categorieBO
     */
    public final ICategorieBO getCategorieBO() {
        return this.categorieBO;
    }

    /**
     * @param pCategorieBO
     *            the categorieBO to set
     */
    public final void setCategorieBO(final ICategorieBO pCategorieBO) {
        this.categorieBO = pCategorieBO;
    }

    /**
     * @return the operationBO
     */
    public final IOperationBO getOperationBO() {
        return this.operationBO;
    }

    /**
     * @param pOperationBO
     *            the operationBO to set
     */
    public final void setOperationBO(final IOperationBO pOperationBO) {
        this.operationBO = pOperationBO;
    }

    /**
     * @return the motCleBC
     */
    public final IMotCleBC getMotCleBC() {
        return this.motCleBC;
    }

    /**
     * @param pMotCleBC
     *            the motCleBC to set
     */
    public final void setMotCleBC(final IMotCleBC pMotCleBC) {
        this.motCleBC = pMotCleBC;
    }

    /**
     * @return the motCleBO
     */
    public final IMotCleBO getMotCleBO() {
        return this.motCleBO;
    }

    /**
     * @param pMotCleBO
     *            the motCleBO to set
     */
    public final void setMotCleBO(final IMotCleBO pMotCleBO) {
        this.motCleBO = pMotCleBO;
    }

    /**
     * @see net.simcafamily.paksou.businessComponent.ICategorieBC#deleteByName(java.lang.String)
     */
    public void deleteByName(String pName) {
        this.categorieBO.delete(this.categorieBO.findById(pName));
    }

}