/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessComponent.impl;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.LinkedList;
import java.util.List;

import jxl.Workbook;
import jxl.read.biff.BiffException;
import net.simcafamily.paksou.businessComponent.ICategorieBC;
import net.simcafamily.paksou.businessComponent.IFichierBC;
import net.simcafamily.paksou.businessObject.IBanqueBO;
import net.simcafamily.paksou.businessObject.ICompteBO;
import net.simcafamily.paksou.businessObject.IOperationBO;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.enumeration.EtatOperation;
import net.simcafamily.paksou.enumeration.MoyenPaiement;
import net.simcafamily.paksou.enumeration.SensOperation;
import net.simcafamily.paksou.valueObject.BanqueVO;
import net.simcafamily.paksou.valueObject.CompteVO;
import net.simcafamily.paksou.valueObject.OperationVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * The Class FichierBC.
 * 
 * @author $Author: simon.guerard $
 * @version $Revision: 403 $
 */
public class FichierBC implements IFichierBC {

    /** The LOGGER. */
    Log log = LogFactory.getLog(FichierBC.class);

    /** The sdf import. */
    private final SimpleDateFormat sdfImport = new SimpleDateFormat("yyyyMMddHHmmss");

    /** The sdf operation. */
    private final SimpleDateFormat sdfOperation = new SimpleDateFormat("yyyyMMdd");

    /** The operation BO. */
    private IOperationBO operationBO;

    /** The compte BO. */
    private ICompteBO compteBO;

    /** The banque BO. */
    private IBanqueBO banqueBO;

    /** The categorie BC. */
    private ICategorieBC categorieBC;

    /**
     * Import fichier du serveur avec son nom.
     * 
     * @param fileName
     *            nom du fichier
     * 
     * @throws Exception
     *             the exception
     */
    public void importFichier(final String fileName, final InputStream input) throws Exception {
        final CompteVO compteVO = null;
        final BanqueVO banqueVO = null;
        final List<OperationVO> lstOperations = new LinkedList<OperationVO>();
        this.log.debug("lecture du fichier " + fileName);

        if (fileName.endsWith(".ofx")) {
            final BufferedInputStream buffer = new BufferedInputStream(input);
            traitementFichierOFX(buffer, lstOperations, compteVO, banqueVO);
            this.log.debug("fin du chargement du fichier ofx");
        }

        this.log.debug("fin du chargement du fichier");

        this.operationBO.chargerListeOperations(lstOperations);
        this.log.info("liste des operations:" + lstOperations);

        this.categorieBC.associerCategorie(lstOperations);
    }

    /**
     * Import fichier du serveur avec son nom.
     * 
     * @param fileName
     *            nom du fichier
     * 
     * @throws Exception
     *             the exception
     */
    public void importFichier(final String fileName) throws Exception {
        final CompteVO compteVO = null;
        final BanqueVO banqueVO = null;
        final List<OperationVO> lstOperations = new LinkedList<OperationVO>();
        final File file = new File(fileName);
        if ((file == null) || !file.exists()) {
            throw new IOException("fichier introuvable");
        } else if (!file.isFile()) {
            throw new IOException("le nom passe en parametre ne correspond pas a un fichier.");
        } else if (!file.canRead()) {
            throw new IOException("le fichier ne peut pas etre lu.");
        } else {
            this.log.debug("lecture du fichier " + file);

            if (file.getAbsolutePath().endsWith(".xls")) {
                this.log.debug("traitement du fichier XLS");
                // utilisation de jxl
                try {
                    Workbook.getWorkbook(file);
                } catch (final BiffException e) {
                    this.log.error(e.getLocalizedMessage(), e);
                    throw e;
                }
            } else if (file.getAbsolutePath().endsWith(".mht")) {
                traitementFichierMHT(file, lstOperations, compteVO, banqueVO);
                this.log.debug("traitement du fichier MHT");
            } else if (file.getAbsolutePath().endsWith(".csv")) {
                this.log.debug("traitement du fichier CSV");

            } else if (file.getAbsolutePath().endsWith(".ofx")) {
                final BufferedInputStream input = new BufferedInputStream(new FileInputStream(file));
                traitementFichierOFX(input, lstOperations, compteVO, banqueVO);
                this.log.debug("fin du chargement du fichier ofx");
            }
        }
        this.log.debug("fin du chargement du fichier");

        this.operationBO.chargerListeOperations(lstOperations);
        this.log.info("liste des operations:" + lstOperations);

        this.categorieBC.associerCategorie(lstOperations);
    }

    /**
     * Traitement fichier MHT.
     * 
     * @param file
     *            the file
     * @param lstOperations
     *            the lst operations
     * @param compte
     *            the compte
     * @param banque
     *            the banque
     * 
     * @throws Exception
     *             the exception
     */
    private void traitementFichierMHT(final File file, final List<OperationVO> lstOperations, final CompteVO compte,
            final BanqueVO banque) throws Exception {
        this.log.debug("traitement du fichier MHT");
        final FileReader fr = new FileReader(file);
        final BufferedReader br = new BufferedReader(fr);
        String stLu = br.readLine();
        boolean isHtml = false;
        while (stLu != null) {
            if (stLu != null) {
                if (stLu.startsWith("<body")) {
                    isHtml = true;
                }
                if (isHtml) {
                    this.log.debug("traitement de la ligne : " + stLu);
                }
            }
            stLu = br.readLine();
        }

    }

    /**
     * Traitement fichier OFX.
     * 
     * @param file
     *            the file
     * @param lstOperations
     *            the lst operations
     * @param compte
     *            the compte
     * @param banque
     *            the banque
     * 
     * @throws Exception
     *             the exception
     */
    private void traitementFichierOFX(final BufferedInputStream input, final List<OperationVO> lstOperations,
            CompteVO compte, BanqueVO banque) throws Exception {
        this.log.debug("traitement du fichier OFX");
        final BufferedReader buffer = new BufferedReader(new InputStreamReader(input));
        String ligne = buffer.readLine();
        final List<String> lstBalise = new LinkedList<String>();
        String baliseOuverte = "";
        String dateDernierImport = "";
        OperationVO ope = null;
        while (ligne != null) {
            this.log.debug("traitement de la ligne : " + ligne);
            // si pas de balise, pas de traitement
            if (ligne.startsWith("<")) {
                // recuperation de la balise en cours
                final String balise = ligne.substring(ligne.indexOf("<") + 1, ligne.indexOf(">"));
                if (ligne.startsWith("</")) {
                    // fermeture de la derniere balise ouverte
                    if (lstBalise.size() > 1) {
                        baliseOuverte = lstBalise.get(lstBalise.size() - 2);
                    }
                    lstBalise.remove(lstBalise.size() - 1);
                    if (balise.equals(ConstantesValeurs.FIN_STMTTRN)) {
                        if (ope == null) {
                            this.log.error("pas d'operation a charger");
                            throw new Exception("pas d'operation a charger");
                        }
                        ope.setEtatOperation(EtatOperation.EFFECTIF);
                        lstOperations.add(ope);
                    }
                } else {
                    if (ligne.endsWith(">")) {
                        // si il n'y a qu'une balise sur la ligne, on la
                        // stocke et on passe a la ligne suivante
                        lstBalise.add(balise);
                        baliseOuverte = balise;
                        if (balise.equals(ConstantesValeurs.STMTTRN)) {
                            ope = new OperationVO();
                            ope.setCompte(compte);
                        }
                    } else {
                        // recuperation de la valeur associee a la
                        // balise en cours
                        final String value = ligne.substring(ligne.indexOf(">") + 1);
                        // test de la balise en cours
                        if (balise.equals(ConstantesValeurs.DATE_IMPORT)) {
                            // <DTSERVER>20070703173016
                            dateDernierImport = value;
                        } else if (balise.equals(ConstantesValeurs.ACCTID)) {
                            // <ACCTID>91028545000
                            compte = recupereCompte(value, banque);

                            try {
                                compte.setDateDernierImport(this.sdfImport.parse(dateDernierImport));
                            } catch (final ParseException e) {
                                this.log.error(e.getLocalizedMessage(), e);
                                throw e;
                            }
                        } else if (baliseOuverte.equals(ConstantesValeurs.BANKACCTFROM)) {
                            // <BANKACCTFROM>
                            if (balise.equals(ConstantesValeurs.BANKID)) {
                                // <BANKID>14706
                                banque = recupereBanque(value);
                            } else if (balise.equals(ConstantesValeurs.BRANCHID)) {
                                // <BRANCHID>00136
                                banque.setContact(value);
                            }

                        } else if (baliseOuverte.equals(ConstantesValeurs.STMTTRN)) {
                            // <STMTTRN>
                            if (compte.getNumero() == null) {
                                this.log.error("le compte associe n'existe pas");
                                throw new Exception("le compte associe n'existe pas");

                            }
                            if (balise.equals(ConstantesValeurs.TRNTYPE)) {
                                // <TRNTYPE>DIRECTDEP
                                ope.setMoyenPaiement(MoyenPaiement.getMoyenPaiementById(value));
                            } else if (balise.equals(ConstantesValeurs.DTPOSTED)) {
                                // <DTPOSTED>20070702
                                ope.setDate(this.sdfOperation.parse(value));
                            } else if (balise.equals(ConstantesValeurs.TRNAMT)) {
                                // <TRNAMT>+400.00
                                ope.setMontant(Float.valueOf(value));
                                if (value.startsWith("-")) {
                                    ope.setSensOperation(SensOperation.DEBIT);
                                } else {
                                    ope.setSensOperation(SensOperation.CREDIT);
                                }
                            } else if (balise.equals(ConstantesValeurs.FITID)) {
                                // <FITID>02000021
                                ope.setIdentifiant(Integer.valueOf(value));
                            } else if (balise.equals(ConstantesValeurs.NAME)) {
                                // <NAME>VIR.GUERARD SIMON-MLE NIMAL
                                // CARO
                                ope.setLibelle(value);
                            } else if (balise.equals(ConstantesValeurs.MEMO)) {
                                // <MEMO>.
                                ope.setMemo(value);
                            }

                        }
                    }
                }
            }
            ligne = buffer.readLine();
        }

    }

    /**
     * Recupere banque.
     * 
     * @param numero
     *            the numero
     * 
     * @return the banque VO
     */
    private BanqueVO recupereBanque(final String numero) {
        BanqueVO banque = this.banqueBO.findByName(numero);
        if (banque == null) {
            banque = new BanqueVO();
            banque.setNom(numero);
            this.banqueBO.persist(banque);
        }
        return banque;
    }

    /**
     * Recupere compte.
     * 
     * @param numero
     *            the numero
     * @param banque
     *            the banque
     * 
     * @return the comptes VO
     */
    private CompteVO recupereCompte(final String numero, final BanqueVO banque) {
        CompteVO compte = this.compteBO.findById(numero);
        if (compte == null) {
            compte = new CompteVO();
            compte.setNumero(numero);
            compte.setBanque(banque);
            this.compteBO.persist(compte);
        }
        return compte;
    }

    /**
     * @return the operationBO
     */
    public final IOperationBO getOperationBO() {
        return this.operationBO;
    }

    /**
     * @param pOperationBO
     *            the operationBO to set
     */
    public final void setOperationBO(final IOperationBO pOperationBO) {
        this.operationBO = pOperationBO;
    }

    /**
     * @return the compteBO
     */
    public final ICompteBO getCompteBO() {
        return this.compteBO;
    }

    /**
     * @param pCompteBO
     *            the compteBO to set
     */
    public final void setCompteBO(final ICompteBO pCompteBO) {
        this.compteBO = pCompteBO;
    }

    /**
     * @return the banqueBO
     */
    public final IBanqueBO getBanqueBO() {
        return this.banqueBO;
    }

    /**
     * @param pBanqueBO
     *            the banqueBO to set
     */
    public final void setBanqueBO(final IBanqueBO pBanqueBO) {
        this.banqueBO = pBanqueBO;
    }

    /**
     * @return the categorieBC
     */
    public final ICategorieBC getCategorieBC() {
        return this.categorieBC;
    }

    /**
     * @param pCategorieBC
     *            the categorieBC to set
     */
    public final void setCategorieBC(final ICategorieBC pCategorieBC) {
        this.categorieBC = pCategorieBC;
    }
}
