/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessComponent.impl;

import java.util.regex.Pattern;

import net.simcafamily.paksou.businessComponent.IMotCleBC;
import net.simcafamily.paksou.businessObject.ICategorieBO;
import net.simcafamily.paksou.businessObject.IMotCleBO;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.MotCleVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

// TODO: Auto-generated Javadoc
/**
 * The Class MotCleBC.
 * 
 * @author $Author: simon.guerard $
 * @version $Revision: 403 $
 */
public class MotCleBC implements IMotCleBC {

    /** The Constant LOG. */
    private static final Log LOG = LogFactory.getLog(MotCleBC.class);

    private IMotCleBO motCleBO;

    private ICategorieBO categorieBO;

    /**
     * Cette methode permet d'identifier des mots cles potentiels dans le libelle de l'operation.
     * 
     * @param pLibelle
     *            libelle de l'operation.
     */
    public String identifierMotCle(final String pLibelle) {
        String result = null;
        String libelle = pLibelle.toUpperCase().trim();
        // pas de mots clefs dans le cas d'un virement en dehors de
        // l'abreviation "VIR."
        final String[] mots = libelle.split(" ");
        if (libelle.startsWith(ConstantesValeurs.ABRV_PRELEVEMENT)) {
            // en cas de prelevement, le mot cle est le deuxieme mot
            int idx = 1;
            while ((idx < 10) && ((mots[idx] == null) || (mots[idx].length() < 1))) {
                idx++;
            }
            if (MotCleBC.LOG.isDebugEnabled()) {
                MotCleBC.LOG.debug("le mot cle (" + mots[1] + ") a ete selectionne.");
            }
            result = mots[idx];
        } else if (ConstantesValeurs.ABRV_CARTE.equals(mots[0])) {
            libelle = libelle.substring(libelle.indexOf(" ")).trim();
            if (libelle.matches(".* ../../..")) {
                final Pattern modele = Pattern.compile(" ../../..");
                final String[] tab = modele.split(libelle);
                result = tab[0];
            }
        } else if (ConstantesValeurs.ABRV_RETRAIT.equals(mots[0])) {
            result = ConstantesValeurs.ABRV_RETRAIT;
        } else {
            result = libelle;
        }

        return result;
    }

    /**
     * Ajouter mot cle.
     * 
     * @param pLibelle
     *            the libelle
     * @param pCategorie
     *            the categorie
     */
    public MotCleVO ajouterMotCle(final String pLibelle, final String pCategorie) {
        MotCleVO motCleVO = this.motCleBO.findById(pLibelle);
        if (motCleVO == null) {
            if (MotCleBC.LOG.isDebugEnabled()) {
                MotCleBC.LOG.debug("le mot cle n'existait pas, il est donc cree.");
            }
            motCleVO = new MotCleVO();
            motCleVO.setLibelle(pLibelle);
            motCleVO.setCreationAuto(Boolean.TRUE);
            final CategorieVO categ = this.categorieBO.findById(pCategorie);
            if (categ != null) {
                motCleVO.setCategorie(categ);
                // creation de la categorie en base.
                this.motCleBO.persist(motCleVO);
            } else {
                MotCleBC.LOG.error("la categorie associee n'existe pas");
                throw new RuntimeException("la categorie associee n'existe pas");
            }
        }
        return motCleVO;
    }

    /**
     * @return the motCleBO
     */
    public final IMotCleBO getMotCleBO() {
        return this.motCleBO;
    }

    /**
     * @param pMotCleBO
     *            the motCleBO to set
     */
    public final void setMotCleBO(final IMotCleBO pMotCleBO) {
        this.motCleBO = pMotCleBO;
    }

    /**
     * @return the categorieBO
     */
    public final ICategorieBO getCategorieBO() {
        return this.categorieBO;
    }

    /**
     * @param pCategorieBO
     *            the categorieBO to set
     */
    public final void setCategorieBO(final ICategorieBO pCategorieBO) {
        this.categorieBO = pCategorieBO;
    }

    /**
     * @see net.simcafamily.paksou.businessComponent.IMotCleBC#supprimerParLibelle(java.lang.String)
     */
    public void supprimerParLibelle(String pLibelle) {
        this.motCleBO.delete(this.motCleBO.findById(pLibelle));
    }

    /**
     * @see net.simcafamily.paksou.businessComponent.IMotCleBC#recupererMotCle(java.lang.String)
     */
    public MotCleVO recupererMotCle(String pIdMotCle) {
        return this.motCleBO.findById(pIdMotCle);
    }

}
