/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessComponent.impl;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

import net.simcafamily.paksou.businessComponent.ICategorieBC;
import net.simcafamily.paksou.businessComponent.IOperationBC;
import net.simcafamily.paksou.businessObject.ICompteBO;
import net.simcafamily.paksou.businessObject.IGroupeBO;
import net.simcafamily.paksou.businessObject.IOperationBO;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.CompteVO;
import net.simcafamily.paksou.valueObject.GroupeVO;
import net.simcafamily.paksou.valueObject.OperationVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * The Class CategorieBC.
 * 
 * @author $Author$
 * @version $Revision$
 */
public class OperationBC implements IOperationBC {

    /** The LOG. */
    private static final Log LOGGER = LogFactory.getLog(OperationBC.class);

    /** The categorie BC. */
    private ICategorieBC categorieBC;

    /** The CompteBO BC. */
    private ICompteBO compteBO;

    /** The operation BO */
    private IOperationBO operationBO;

    public void creerOperation(final OperationVO pOperationVO) {
        if (OperationBC.LOGGER.isDebugEnabled()) {
            OperationBC.LOGGER.debug("creerOperation('" + pOperationVO + "')");
        }
        if ((pOperationVO.getLibCategorie() == null) || (pOperationVO.getLibCategorie().length() <= 0)) {
            pOperationVO.setCategorie(null);
        }
        if ((pOperationVO.getNumCompte() == null) || (pOperationVO.getNumCompte().length() <= 0)) {
            pOperationVO.setCompte(null);
        }
        this.operationBO.persist(pOperationVO);
    }

    public void mettreAJourOperation(final OperationVO pOperationVO) {
        if (OperationBC.LOGGER.isDebugEnabled()) {
            OperationBC.LOGGER.debug("mettreAJourOperation('" + pOperationVO + "')");
        }

        if ((pOperationVO.getNumCompte() == null) || (pOperationVO.getNumCompte().length() <= 0)) {
            pOperationVO.setCompte(null);
        } else {
            final CompteVO compte = this.compteBO.findById(pOperationVO.getNumCompte());
            pOperationVO.setCompte(compte);
        }
        if ((pOperationVO.getLibCategorie() == null) || (pOperationVO.getLibCategorie().length() <= 0)) {
            pOperationVO.setCategorie(null);
        } else {
            this.categorieBC.ajouterCategorie(pOperationVO, pOperationVO.getLibCategorie());
        }

        this.operationBO.update(pOperationVO);

    }

    /**
     * Methode permettant de recuperer la liste des operations par categorie.
     * 
     * @param pCompteVO
     * @param pDateDebut
     * @param pDateFin
     */
    public Map<GroupeVO, Map<CategorieVO, Float>> rechercherListeOperationsParCategories(final Calendar pDateDebut,
            final Calendar pDateFin, final CompteVO pCompteVO) {

        final IGroupeBO groupeBO = (IGroupeBO) ContextFactory.getContext().getBean("groupeBO");
        final List<GroupeVO> lstGroupe = groupeBO.retrieveList();
        final Map<GroupeVO, Map<CategorieVO, Float>> mapSynthese = new TreeMap<GroupeVO, Map<CategorieVO, Float>>();
        final Iterator<GroupeVO> iterGroupe = lstGroupe.iterator();
        while (iterGroupe.hasNext()) {
            final GroupeVO groupe = iterGroupe.next();
            final List<CategorieVO> lstCateg = this.categorieBC.recupererListeCategorieParGroupe(groupe);
            mapSynthese.put(groupe, initCateg(lstCateg, pDateDebut, pDateFin, pCompteVO));
        }
        final List<CategorieVO> lstCateg = this.categorieBC.recupererListeCategorieParGroupe(null);
        final Map<CategorieVO, Float> mapDivers = initCateg(lstCateg, pDateDebut, pDateFin, pCompteVO);
        final Map<CategorieVO, Float> mapVide = initCateg(null, pDateDebut, pDateFin, pCompteVO);
        mapDivers.putAll(mapVide);
        mapSynthese.put(new GroupeVO("Divers"), mapDivers);
        return mapSynthese;
    }

    private Map<CategorieVO, Float> initCateg(final List<CategorieVO> pLstCateg, final Calendar pDateDebut,
            final Calendar pDateFin, final CompteVO pCompteVO) {
        final Map<CategorieVO, Float> mapGroupe = new TreeMap<CategorieVO, Float>();
        final SimpleDateFormat sdf = new SimpleDateFormat("yy-MM-dd");
        if (pLstCateg != null) {
            final Iterator<CategorieVO> iterCateg = pLstCateg.iterator();
            while (iterCateg.hasNext()) {
                final CategorieVO categorie = iterCateg.next();
                final List<OperationVO> lstOperations = this.operationBO.findByCategorieAndDate(categorie, sdf
                        .format(pDateDebut.getTime()), sdf.format(pDateFin.getTime()), pCompteVO);
                mapGroupe.put(categorie, calculSommeMontant(lstOperations));
            }
        } else {
            final List<OperationVO> lstOperations = this.operationBO.findByCategorieAndDate(null, sdf.format(pDateDebut
                    .getTime()), sdf.format(pDateFin.getTime()), pCompteVO);
            mapGroupe.put(new CategorieVO(" - "), calculSommeMontant(lstOperations));
        }
        return mapGroupe;
    }

    public Float calculSommeMontant(final List<OperationVO> pLstOperations) {
        final Iterator<OperationVO> iterOpe = pLstOperations.iterator();
        Float montant = new Float(0);
        while (iterOpe.hasNext()) {
            final OperationVO operation = iterOpe.next();
            montant += operation.getMontant();
        }

        return new Float(Math.round(montant * 100)) / 100;
    }

    /**
     * @return the operationBO
     */
    public final IOperationBO getOperationBO() {
        return this.operationBO;
    }

    /**
     * @param pOperationBO
     *            the operationBO to set
     */
    public final void setOperationBO(final IOperationBO pOperationBO) {
        this.operationBO = pOperationBO;
    }

    /**
     * @return the categorieBC
     */
    public final ICategorieBC getCategorieBC() {
        return this.categorieBC;
    }

    /**
     * @return the compteBO
     */
    public final ICompteBO getCompteBO() {
        return this.compteBO;
    }

    /**
     * @param pCompteBO
     *            the compteBO to set
     */
    public final void setCompteBO(final ICompteBO pCompteBO) {
        this.compteBO = pCompteBO;
    }

    /**
     * @param pCategorieBC
     *            the categorieBC to set
     */
    public final void setCategorieBC(final ICategorieBC pCategorieBC) {
        this.categorieBC = pCategorieBC;
    }

    /**
     * @see net.simcafamily.paksou.businessComponent.IOperationBC#deleteByName(java.lang.String)
     */
    public void deleteByName(Integer pValueOf) {
        this.operationBO.delete(this.operationBO.findById(pValueOf));
    }

    /**
     * @see net.simcafamily.paksou.businessComponent.IOperationBC#recupererListeOperations()
     */
    public List<OperationVO> recupererListeOperations() {
        return this.operationBO.retrieveList();
    }
}