/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessObject.impl;

// Generated 27 juin 2007 22:05:40 by Hibernate Tools 3.2.0.b9

import java.util.List;

import net.simcafamily.paksou.businessObject.IBanqueBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.valueObject.BanqueVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Criteria;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.Conjunction;
import org.hibernate.criterion.Criterion;
import org.hibernate.criterion.Restrictions;

/**
 * Home object for domain model class BanqueVO.
 * 
 * @see net.simcafamily.paksou.businessObject.BanqueVO
 * @author $Author: simon.guerard $
 * @version $Revision: 390 $
 */
public class BanqueBO implements IBanqueBO {

    /** The Constant LOGGER. */
    private static final Log log = LogFactory.getLog(BanqueBO.class);

    /**
     * Persist.
     * 
     * @param transientInstance
     *            the transient instance
     */
    public void persist(final BanqueVO transientInstance) {
        BanqueBO.log.debug("persisting BanqueVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.persist(transientInstance);
            session.getTransaction().commit();
            BanqueBO.log.debug("persist successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BanqueBO.log.error("persist failed", re);
            throw re;
        }
    }

    /**
     * Update.
     * 
     * @param instance
     *            the instance
     */
    public void update(final BanqueVO instance) {
        BanqueBO.log.debug("update BanqueVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.update(instance);
            session.getTransaction().commit();
            BanqueBO.log.debug("update successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BanqueBO.log.error("update failed", re);
            throw re;
        }
    }

    /**
     * Attach clean.
     * 
     * @param instance
     *            the instance
     */
    public void attachClean(final BanqueVO instance) {
        BanqueBO.log.debug("attaching clean BanqueVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.lock(instance, LockMode.NONE);
            session.getTransaction().commit();
            BanqueBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BanqueBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Delete.
     * 
     * @param persistentInstance
     *            the persistent instance
     */
    public void delete(final BanqueVO persistentInstance) {
        BanqueBO.log.debug("deleting BanqueVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.delete(persistentInstance);
            session.getTransaction().commit();
            BanqueBO.log.debug("delete successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BanqueBO.log.error("delete failed", re);
            throw re;
        }
    }

    /**
     * Merge.
     * 
     * @param detachedInstance
     *            the detached instance
     * 
     * @return the banque VO
     */
    public BanqueVO merge(final BanqueVO detachedInstance) {
        BanqueBO.log.debug("merging BanqueVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final BanqueVO result = (BanqueVO) session.merge(detachedInstance);
            session.getTransaction().commit();
            BanqueBO.log.debug("merge successful");
            return result;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BanqueBO.log.error("merge failed", re);
            throw re;
        }
    }

    /**
     * Find by example.
     * 
     * @param instance
     *            the instance
     * 
     * @return the list
     */
    @SuppressWarnings("unchecked")
    public List<BanqueVO> findByExample(final BanqueVO instance) {
        BanqueBO.log.debug("finding BanqueVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final Criteria criteria = session.createCriteria("net.simcafamily.paksou.businessObject.BanqueVO");
            criteria.add(createcritere(instance));
            final List<BanqueVO> results = criteria.list();
            session.getTransaction().commit();
            BanqueBO.log.debug("find by example successful, result size: " + results.size());
            return results;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BanqueBO.log.error("find by example failed", re);
            throw re;
        }
    }

    /**
     * Find by functional id.
     * 
     * @param nom
     *            the nom
     * 
     * @return the banque VO
     */
    @SuppressWarnings("unchecked")
    public BanqueVO findByName(final String nom) {
        final BanqueVO critBanque = new BanqueVO();
        critBanque.setNom(nom);
        BanqueBO.log.debug("finding BanqueVO instance by Name");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        List<BanqueVO> results = null;
        try {
            session.beginTransaction();
            final Criteria criteria = session.createCriteria("net.simcafamily.paksou.valueObject.BanqueVO");
            criteria.add(createcritere(critBanque));
            results = criteria.list();
            session.getTransaction().commit();
            BanqueBO.log.debug("find by example successful, result size: " + results.size());
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BanqueBO.log.error("find by example failed", re);
            throw re;
        }
        if (results.size() < 1) {
            return null;
        } else if (results.size() > 1) {
            throw new RuntimeException("trop de banque pour le meme nom");
        }
        return results.iterator().next();
    }

    /**
     * Createcritere.
     * 
     * @param banque
     *            the banque
     * 
     * @return the criterion
     */
    private Criterion createcritere(final BanqueVO banque) {
        final Conjunction crit = Restrictions.conjunction();
        if (banque.getNom() != null) {
            crit.add(Restrictions.ilike("nom", banque.getNom() + "%"));
        }
        if (banque.getAdresse() != null) {
            crit.add(Restrictions.ilike("adresse", banque.getAdresse() + "%"));
        }
        if (banque.getContact() != null) {
            crit.add(Restrictions.ilike("contact", banque.getContact() + "%"));
        }
        if (banque.getTelContact() != null) {
            crit.add(Restrictions.ilike("telContact", banque.getTelContact() + "%"));
        }
        return crit;
    }

    /**
     * Retrieve list.
     * 
     * @return the list
     */
    @SuppressWarnings("unchecked")
    public List<BanqueVO> retrieveList() {
        BanqueBO.log.debug("finding BanqueVO instance list");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        session.beginTransaction();
        final Query query = session.createQuery("from BanqueVO");
        final List<BanqueVO> liste = query.list();
        session.getTransaction().commit();
        return liste;
    }

}
