/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de budget bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessObject.impl;

// Generated 27 juin 2007 22:05:40 by Hibernate Tools 3.2.0.b9

import java.util.List;

import net.simcafamily.paksou.businessObject.IBudgetBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.valueObject.BudgetVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.Example;

/**
 * Home object for domain model class BudgetVO.
 * 
 * @see net.simcafamily.paksou.businessObject.BudgetVO
 * @author $Author$
 * @version $Revision$
 */
public class BudgetBO implements IBudgetBO {

    /** The Constant LOGGER. */
    private static final Log log = LogFactory.getLog(BudgetBO.class);

    /**
     * Persist.
     * 
     * @param transientInstance
     *            the transient instance
     */
    public void persist(final BudgetVO transientInstance) {
        BudgetBO.log.debug("persisting BudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.persist(transientInstance);
            session.getTransaction().commit();
            BudgetBO.log.debug("persist successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BudgetBO.log.error("persist failed", re);
            throw re;
        }
    }

    /**
     * Attach dirty.
     * 
     * @param instance
     *            the instance
     */
    public void attachDirty(final BudgetVO instance) {
        BudgetBO.log.debug("attaching dirty BudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.saveOrUpdate(instance);
            session.getTransaction().commit();
            BudgetBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BudgetBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Attach clean.
     * 
     * @param instance
     *            the instance
     */
    public void attachClean(final BudgetVO instance) {
        BudgetBO.log.debug("attaching clean BudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.lock(instance, LockMode.NONE);
            session.getTransaction().commit();
            BudgetBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BudgetBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Delete.
     * 
     * @param persistentInstance
     *            the persistent instance
     */
    public void delete(final BudgetVO persistentInstance) {
        BudgetBO.log.debug("deleting BudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.delete(persistentInstance);
            session.getTransaction().commit();
            BudgetBO.log.debug("delete successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BudgetBO.log.error("delete failed", re);
            throw re;
        }
    }

    /**
     * Merge.
     * 
     * @param detachedInstance
     *            the detached instance
     * 
     * @return the budget VO
     */
    public BudgetVO merge(final BudgetVO detachedInstance) {
        BudgetBO.log.debug("merging BudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final BudgetVO result = (BudgetVO) session.merge(detachedInstance);
            session.getTransaction().commit();
            BudgetBO.log.debug("merge successful");
            return result;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BudgetBO.log.error("merge failed", re);
            throw re;
        }
    }

    /**
     * Find by id.
     * 
     * @param libelle
     *            the libelle
     * 
     * @return the budget VO
     */
    public BudgetVO findById(final String libelle) {
        BudgetBO.log.debug("getting BudgetVO instance with id: " + libelle);
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final BudgetVO instance = (BudgetVO) session.get("net.simcafamily.paksou.valueObject.BudgetVO", libelle);
            session.getTransaction().commit();
            if (instance == null) {
                BudgetBO.log.debug("get successful, no instance found");
            } else {
                BudgetBO.log.debug("get successful, instance found");
            }
            return instance;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BudgetBO.log.error("get failed", re);
            throw re;
        }
    }

    /**
     * Find by example.
     * 
     * @param instance
     *            the instance
     * 
     * @return list de BudgetVO
     */
    @SuppressWarnings("unchecked")
    public List<BudgetVO> findByExample(final BudgetVO instance) {
        BudgetBO.log.debug("finding BudgetVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final List<BudgetVO> list = session.createCriteria("net.simcafamily.paksou.businessObject.BudgetVO").add(
                    Example.create(instance)).list();
            session.getTransaction().commit();
            final List<BudgetVO> results = list;
            BudgetBO.log.debug("find by example successful, result size: " + results.size());
            return results;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            BudgetBO.log.error("find by example failed", re);
            throw re;
        }
    }

    /**
     * Retrieve list.
     * 
     * @return the list
     */
    @SuppressWarnings("unchecked")
    public List<BudgetVO> retrieveList() {
        BudgetBO.log.debug("finding BudgetVO instance list");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        session.beginTransaction();
        final Query query = session.createQuery("from BudgetVO");
        final List<BudgetVO> liste = query.list();
        session.getTransaction().commit();
        return liste;
    }

}
