/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessObject.impl;

// Generated 27 juin 2007 22:05:40 by Hibernate Tools 3.2.0.b9

import java.util.List;

import net.simcafamily.paksou.businessObject.ICategorieBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.GroupeVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.Session;

/**
 * Home object for domain model class CategorieVO.
 * 
 * @see net.simcafamily.paksou.businessObject.CategorieVO
 * @author $Author: simon.guerard $
 * @version $Revision: 390 $
 */
public class CategorieBO implements ICategorieBO {

    /** The Constant LOGGER. */
    private static final Log log = LogFactory.getLog(CategorieBO.class);

    /**
     * Persist.
     * 
     * @param transientInstance
     *            the transient instance
     */
    public void persist(final CategorieVO transientInstance) {
        CategorieBO.log.debug("persisting CategorieVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.persist(transientInstance);
            session.getTransaction().commit();
            CategorieBO.log.debug("persist successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CategorieBO.log.error("persist failed", re);
            throw re;
        }
    }

    /**
     * update.
     * 
     * @param instance
     *            the instance
     */
    public void update(final CategorieVO instance) {
        CategorieBO.log.debug("update CategorieVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.update(instance);
            session.getTransaction().commit();
            CategorieBO.log.debug("update successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CategorieBO.log.error("update failed", re);
            throw re;
        }
    }

    /**
     * Attach clean.
     * 
     * @param instance
     *            the instance
     */
    public void attachClean(final CategorieVO instance) {
        CategorieBO.log.debug("attaching clean CategorieVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.lock(instance, LockMode.NONE);
            session.getTransaction().commit();
            CategorieBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CategorieBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Delete.
     * 
     * @param persistentInstance
     *            the persistent instance
     */
    public void delete(final CategorieVO persistentInstance) {
        CategorieBO.log.debug("deleting CategorieVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.delete(persistentInstance);
            session.getTransaction().commit();
            CategorieBO.log.debug("delete successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CategorieBO.log.error("delete failed", re);
            throw re;
        }
    }

    /**
     * Merge.
     * 
     * @param detachedInstance
     *            the detached instance
     * 
     * @return the categorie VO
     */
    public CategorieVO merge(final CategorieVO detachedInstance) {
        CategorieBO.log.debug("merging CategorieVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final CategorieVO result = (CategorieVO) session.merge(detachedInstance);
            session.getTransaction().commit();
            CategorieBO.log.debug("merge successful");
            return result;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CategorieBO.log.error("merge failed", re);
            throw re;
        }
    }

    /**
     * Find by id.
     * 
     * @param id
     *            the id
     * 
     * @return the categorie VO
     */
    public CategorieVO findById(final String id) {
        CategorieBO.log.debug("getting CategorieVO instance with id: " + id);
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final CategorieVO instance = (CategorieVO) session.get("net.simcafamily.paksou.valueObject.CategorieVO", id);
            session.getTransaction().commit();
            if (instance == null) {
                CategorieBO.log.debug("get successful, no instance found");
            } else {
                CategorieBO.log.debug("get successful, instance found");
            }
            return instance;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CategorieBO.log.error("get failed", re);
            throw re;
        }
    }

    /**
     * Find by example.
     * 
     * @param instance
     *            the instance
     * 
     * @return the list
     */
    public List<CategorieVO> findByExample(final CategorieVO instance) {
        CategorieBO.log.debug("finding CategorieVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final List<CategorieVO> results = session.createCriteria("net.simcafamily.paksou.businessObject.CategorieVO").add(
                    null/* create(instance) */).list();
            CategorieBO.log.debug("find by example successful, result size: " + results.size());
            session.getTransaction().commit();
            return results;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CategorieBO.log.error("find by example failed", re);
            throw re;
        }
    }

    /**
     * Retrieve list.
     * 
     * @return the list
     */
    public List<CategorieVO> retrieveList() {
        CategorieBO.log.debug("finding CategorieVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        session.beginTransaction();
        final Query query = session.createQuery("from net.simcafamily.paksou.valueObject.CategorieVO order by libelle asc");
        final List<CategorieVO> liste = query.list();
        session.getTransaction().commit();
        return liste;
    }

    /**
     * Retrieve list.
     * 
     * @return the list
     */
    public List<CategorieVO> retrieveListByGroup(final GroupeVO pGroupe) {
        CategorieBO.log.debug("finding CategorieVO instance by Group");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        session.beginTransaction();
        final StringBuffer requete = new StringBuffer("FROM net.simcafamily.paksou.valueObject.CategorieVO ");
        if (pGroupe != null) {
            requete.append(" WHERE groupe='");
            requete.append(pGroupe.getLibelle());
            requete.append("'");
        } else {
            requete.append(" WHERE groupe is null");
        }
        requete.append(" order by libelle asc ");
        final Query query = session.createQuery(requete.toString());
        final List<CategorieVO> liste = query.list();
        session.getTransaction().commit();
        return liste;
    }

}
