/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessObject.impl;

// Generated 27 juin 2007 22:05:40 by Hibernate Tools 3.2.0.b9

import java.util.List;

import net.simcafamily.paksou.businessObject.ICompteBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.valueObject.CompteVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.Example;

/**
 * Home object for domain model class CompteVO.
 * 
 * @see net.simcafamily.paksou.businessObject.CompteVO
 * @author $Author$
 * @version $Revision$
 */
public class CompteBO implements ICompteBO {

    /** The Constant LOGGER. */
    private static final Log log = LogFactory.getLog(CompteBO.class);

    /**
     * Persist.
     * 
     * @param transientInstance
     *            the transient instance
     */
    public void persist(final CompteVO transientInstance) {
        CompteBO.log.debug("persisting CompteVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.persist(transientInstance);
            session.getTransaction().commit();
            CompteBO.log.debug("persist successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CompteBO.log.error("persist failed", re);
            throw re;
        }
    }

    /**
     * Attach dirty.
     * 
     * @param instance
     *            the instance
     */
    public void attachDirty(final CompteVO instance) {
        CompteBO.log.debug("attaching dirty CompteVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.saveOrUpdate(instance);
            session.getTransaction().commit();
            CompteBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CompteBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Attach clean.
     * 
     * @param instance
     *            the instance
     */
    public void attachClean(final CompteVO instance) {
        CompteBO.log.debug("attaching clean CompteVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.lock(instance, LockMode.NONE);
            session.getTransaction().commit();
            CompteBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CompteBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Delete.
     * 
     * @param persistentInstance
     *            the persistent instance
     */
    public void delete(final CompteVO persistentInstance) {
        CompteBO.log.debug("deleting CompteVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.delete(persistentInstance);
            session.getTransaction().commit();
            CompteBO.log.debug("delete successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CompteBO.log.error("delete failed", re);
            throw re;
        }
    }

    /**
     * Merge.
     * 
     * @param detachedInstance
     *            the detached instance
     * 
     * @return the comptes VO
     */
    public CompteVO merge(final CompteVO detachedInstance) {
        CompteBO.log.debug("merging CompteVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final CompteVO result = (CompteVO) session.merge(detachedInstance);
            session.getTransaction().commit();
            CompteBO.log.debug("merge successful");
            return result;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CompteBO.log.error("merge failed", re);
            throw re;
        }
    }

    /**
     * Find by id.
     * 
     * @param numero
     *            the numero
     * 
     * @return the comptes VO
     */
    public CompteVO findById(final String numero) {
        CompteBO.log.debug("getting CompteVO instance with id: " + numero);
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final CompteVO instance = (CompteVO) session.get("net.simcafamily.paksou.valueObject.CompteVO", numero);
            session.getTransaction().commit();
            if (instance == null) {
                CompteBO.log.debug("get successful, no instance found");
            } else {
                CompteBO.log.debug("get successful, instance found");
            }
            return instance;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CompteBO.log.error("get failed", re);
            throw re;
        }
    }

    /**
     * Find by example.
     * 
     * @param instance
     *            the instance
     * 
     * @return the list< comptes V o>
     */
    @SuppressWarnings("unchecked")
    public List<CompteVO> findByExample(final CompteVO instance) {
        CompteBO.log.debug("finding CompteVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final List<CompteVO> list = session.createCriteria("net.simcafamily.paksou.businessObject.CompteVO").add(
                    Example.create(instance)).list();
            session.getTransaction().commit();
            final List<CompteVO> results = list;
            CompteBO.log.debug("find by example successful, result size: " + results.size());
            return results;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CompteBO.log.error("find by example failed", re);
            throw re;
        }
    }

    /**
     * Retrieve list.
     * 
     * @return the list
     */
    @SuppressWarnings("unchecked")
    public List<CompteVO> retrieveList() {
        CompteBO.log.debug("finding CompteVO instance list");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        session.beginTransaction();
        final Query query = session.createQuery("from CompteVO");
        final List<CompteVO> liste = query.list();
        session.getTransaction().commit();
        return liste;
    }

    /**
     * Update.
     * 
     * @param instance
     *            the instance
     */
    public void update(final CompteVO instance) {
        CompteBO.log.debug("update CompteVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.update(instance);
            session.getTransaction().commit();
            CompteBO.log.debug("update successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            CompteBO.log.error("update failed", re);
            throw re;
        }
    }

}
