/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessObject.impl;

// Generated 27 juin 2007 22:05:40 by Hibernate Tools 3.2.0.b9

import java.util.List;

import net.simcafamily.paksou.businessObject.IGroupeBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.valueObject.GroupeVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.Example;

/**
 * Home object for domain model class GroupeVO.
 * 
 * @see net.simcafamily.paksou.businessObject.GroupeVO
 * @author $Author: simon.guerard $
 * @version $Revision: 390 $
 */
public class GroupeBO implements IGroupeBO {

    /** The Constant LOGGER. */
    private static final Log log = LogFactory.getLog(GroupeBO.class);

    /**
     * Persist.
     * 
     * @param transientInstance
     *            the transient instance
     */
    public void persist(final GroupeVO transientInstance) {
        GroupeBO.log.debug("persisting GroupeVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.persist(transientInstance);
            session.getTransaction().commit();
            GroupeBO.log.debug("persist successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            GroupeBO.log.error("persist failed", re);
            throw re;
        }
    }

    /**
     * Attach dirty.
     * 
     * @param instance
     *            the instance
     */
    public void attachDirty(final GroupeVO instance) {
        GroupeBO.log.debug("attaching dirty GroupeVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.saveOrUpdate(instance);
            session.getTransaction().commit();
            GroupeBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            GroupeBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Attach clean.
     * 
     * @param instance
     *            the instance
     */
    public void attachClean(final GroupeVO instance) {
        GroupeBO.log.debug("attaching clean GroupeVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.lock(instance, LockMode.NONE);
            session.getTransaction().commit();
            GroupeBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            GroupeBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Delete.
     * 
     * @param persistentInstance
     *            the persistent instance
     */
    public void delete(final GroupeVO persistentInstance) {
        GroupeBO.log.debug("deleting GroupeVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.delete(persistentInstance);
            session.getTransaction().commit();
            GroupeBO.log.debug("delete successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            GroupeBO.log.error("delete failed", re);
            throw re;
        }
    }

    /**
     * Merge.
     * 
     * @param detachedInstance
     *            the detached instance
     * 
     * @return the groupe VO
     */
    public GroupeVO merge(final GroupeVO detachedInstance) {
        GroupeBO.log.debug("merging GroupeVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final GroupeVO result = (GroupeVO) session.merge(detachedInstance);
            session.getTransaction().commit();
            GroupeBO.log.debug("merge successful");
            return result;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            GroupeBO.log.error("merge failed", re);
            throw re;
        }
    }

    /**
     * update.
     * 
     * @param instance
     *            the instance
     */
    public void update(final GroupeVO instance) {
        GroupeBO.log.debug("update GroupeVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.update(instance);
            session.getTransaction().commit();
            GroupeBO.log.debug("update successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            GroupeBO.log.error("update failed", re);
            throw re;
        }
    }

    /**
     * Find by id.
     * 
     * @param id
     *            the id
     * 
     * @return the groupe VO
     */
    public GroupeVO findById(final String id) {
        GroupeBO.log.debug("getting GroupeVO instance with id: " + id);
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final GroupeVO instance = (GroupeVO) session.get("net.simcafamily.paksou.valueObject.GroupeVO", id);
            session.getTransaction().commit();
            if (instance == null) {
                GroupeBO.log.debug("get successful, no instance found");
            } else {
                GroupeBO.log.debug("get successful, instance found");
            }
            return instance;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            GroupeBO.log.error("get failed", re);
            throw re;
        }
    }

    /**
     * Find by example.
     * 
     * @param instance
     *            the instance
     * 
     * @return the list
     */
    @SuppressWarnings("unchecked")
    public List<GroupeVO> findByExample(final GroupeVO instance) {
        GroupeBO.log.debug("finding GroupeVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final List<GroupeVO> results = session.createCriteria("net.simcafamily.paksou.businessObject.GroupeVO").add(
                    Example.create(instance)).list();
            session.getTransaction().commit();
            GroupeBO.log.debug("find by example successful, result size: " + results.size());
            return results;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            GroupeBO.log.error("find by example failed", re);
            throw re;
        }
    }

    /**
     * Retrieve list.
     * 
     * @return the list
     */
    @SuppressWarnings("unchecked")
    public List<GroupeVO> retrieveList() {
        GroupeBO.log.debug("finding OperationVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        session.beginTransaction();
        final Query query = session.createQuery("from GroupeVO order by libelle");
        final List<GroupeVO> liste = query.list();
        session.getTransaction().commit();
        return liste;
    }

}
