/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessObject.impl;

import java.util.Iterator;
import java.util.List;

import net.simcafamily.paksou.businessObject.ILigneBudgetBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.valueObject.BudgetVO;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.LigneBudgetVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.Example;

/**
 * Home object for domain model class LigneBudgetVO.
 * 
 * @see net.simcafamily.paksou.valueObject.LigneBudgetVO
 * @author $Author$
 * @version $Revision$
 */
public class LigneBudgetBO implements ILigneBudgetBO {

    /** The Constant LOGGER. */
    private static final Log log = LogFactory.getLog(LigneBudgetBO.class);

    /**
     * Persist.
     * 
     * @param ligne
     *            the transient instance
     */
    public void persist(final LigneBudgetVO ligne) {
        LigneBudgetBO.log.debug("persisting LigneBudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.persist(ligne);
            session.getTransaction().commit();
            LigneBudgetBO.log.debug("persist successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            LigneBudgetBO.log.error("persist failed", re);
            throw re;
        }
    }

    public void update(final LigneBudgetVO ligne) {
        LigneBudgetBO.log.debug("update LigneBudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.update(ligne);
            session.getTransaction().commit();
            LigneBudgetBO.log.debug("update successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            LigneBudgetBO.log.error("update failed", re);
            throw re;
        }
    }

    /**
     * Attach clean.
     * 
     * @param ligne
     *            the instance
     */
    public void attachClean(final LigneBudgetVO ligne) {
        LigneBudgetBO.log.debug("attaching clean LigneBudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.lock(ligne, LockMode.NONE);
            session.getTransaction().commit();
            LigneBudgetBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            LigneBudgetBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Delete.
     * 
     * @param ligne
     *            the persistent instance
     */
    public void delete(final LigneBudgetVO ligne) {
        LigneBudgetBO.log.debug("deleting LigneBudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.delete(ligne);
            session.getTransaction().commit();
            LigneBudgetBO.log.debug("delete successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            LigneBudgetBO.log.error("delete failed", re);
            throw re;
        }
    }

    /**
     * Merge.
     * 
     * @param ligne
     *            the detached instance
     * 
     * @return the ligneBudget VO
     */
    public LigneBudgetVO merge(final LigneBudgetVO ligne) {
        LigneBudgetBO.log.debug("merging LigneBudgetVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final LigneBudgetVO result = (LigneBudgetVO) session.merge(ligne);
            session.getTransaction().commit();
            LigneBudgetBO.log.debug("merge successful");
            return result;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            LigneBudgetBO.log.error("merge failed", re);
            throw re;
        }
    }

    /**
     * Find by id.
     * 
     * @param pNoRefInt
     *            the id
     * 
     * @return the ligneBudget VO
     */
    public LigneBudgetVO findById(final java.lang.Integer pNoRefInt) {
        LigneBudgetBO.log.debug("getting LigneBudgetVO instance with id: " + pNoRefInt);
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final LigneBudgetVO instance = (LigneBudgetVO) session.get("net.simcafamily.paksou.valueObject.LigneBudgetVO",
                    pNoRefInt);
            session.getTransaction().commit();
            if (instance == null) {
                LigneBudgetBO.log.debug("get successful, no instance found");
            } else {
                LigneBudgetBO.log.debug("get successful, instance found");
            }
            return instance;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            LigneBudgetBO.log.error("get failed", re);
            throw re;
        }
    }

    /**
     * Find by id.
     * 
     * @param pNoRefInt
     *            the id
     * 
     * @return the ligneBudget VO
     */
    @SuppressWarnings("unchecked")
    public LigneBudgetVO findByFunctionnalId(final String pBudget, final String pCategorie) {
        final LigneBudgetVO critLigneBudget = new LigneBudgetVO();
        final BudgetVO budget = new BudgetVO(pBudget);
        critLigneBudget.setBudget(budget);
        final CategorieVO categorie = new CategorieVO(pCategorie);
        critLigneBudget.setCategorie(categorie);
        LigneBudgetBO.log.debug("finding LigneBudgetVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        List<LigneBudgetVO> results = null;
        try {
            session.beginTransaction();
            final Query query = session.createQuery("FROM LigneBudgetVO WHERE budget like '" + pBudget
                    + "' AND categorie like '" + pCategorie + "'");
            results = query.list();
            session.getTransaction().commit();
            LigneBudgetBO.log.debug("find by example successful, result size: " + results.size());
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            LigneBudgetBO.log.error("find by example failed", re);
            throw re;
        }
        if (results.size() < 1) {
            return null;
        } else if (results.size() > 1) {
            throw new RuntimeException("trop de banque pour le meme nom");
        }
        return results.iterator().next();
    }

    /**
     * Find by example.
     * 
     * @param ligne
     *            the instance
     * 
     * @return the list
     */
    @SuppressWarnings("unchecked")
    public List<LigneBudgetVO> findByExample(final LigneBudgetVO ligne) {
        LigneBudgetBO.log.debug("finding LigneBudgetVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final List<LigneBudgetVO> results = session.createCriteria("net.simcafamily.paksou.valueObject.LigneBudgetVO")
                    .add(Example.create(ligne)).list();
            session.getTransaction().commit();
            LigneBudgetBO.log.debug("find by example successful, result size: " + results.size());
            return results;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            LigneBudgetBO.log.error("find by example failed", re);
            throw re;
        }
    }

    /**
     * Charger liste ligneBudgets.
     * 
     * @param lstLigneBudgets
     *            the lst ligneBudgets
     */
    public void chargerListeLigneBudgets(final List<LigneBudgetVO> lstLigneBudgets) {
        final Iterator<LigneBudgetVO> iterLigneBudget = lstLigneBudgets.iterator();
        while (iterLigneBudget.hasNext()) {
            final LigneBudgetVO ope = iterLigneBudget.next();
            if (findById(ope.getNoRefInt()) == null) {
                persist(ope);
            }
        }
    }

}
