/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessObject.impl;

// Generated 27 juin 2007 22:05:40 by Hibernate Tools 3.2.0.b9

import java.util.List;

import net.simcafamily.paksou.businessObject.IMotCleBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.valueObject.MotCleVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Session;
import org.hibernate.criterion.Example;

/**
 * Home object for domain model class MotCleVO.
 * 
 * @see net.simcafamily.paksou.businessObject.MotCleVO
 * @author $Author: simon.guerard $
 * @version $Revision: 390 $
 */
public class MotCleBO implements IMotCleBO {

    /** The Constant LOGGER. */
    private static final Log log = LogFactory.getLog(MotCleBO.class);

    /**
     * Persist.
     * 
     * @param transientInstance
     *            the transient instance
     */
    public void persist(final MotCleVO transientInstance) {
        MotCleBO.log.debug("persisting MotCleVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.persist(transientInstance);
            session.getTransaction().commit();
            MotCleBO.log.debug("persist successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            MotCleBO.log.error("persist failed", re);
            throw re;
        }
    }

    /**
     * update.
     * 
     * @param instance
     *            the instance
     */
    public void update(final MotCleVO instance) {
        MotCleBO.log.debug("update MotCleVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.update(instance);
            session.getTransaction().commit();
            MotCleBO.log.debug("update successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            MotCleBO.log.error("update failed", re);
            throw re;
        }
    }

    /**
     * Attach clean.
     * 
     * @param instance
     *            the instance
     */
    public void attachClean(final MotCleVO instance) {
        MotCleBO.log.debug("attaching clean MotCleVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.lock(instance, LockMode.NONE);
            session.getTransaction().commit();
            MotCleBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            MotCleBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Delete.
     * 
     * @param persistentInstance
     *            the persistent instance
     */
    public void delete(final MotCleVO persistentInstance) {
        MotCleBO.log.debug("deleting MotCleVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.delete(persistentInstance);
            session.getTransaction().commit();
            MotCleBO.log.debug("delete successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            MotCleBO.log.error("delete failed", re);
            throw re;
        }
    }

    /**
     * Merge.
     * 
     * @param detachedInstance
     *            the detached instance
     * 
     * @return the mot cle VO
     */
    public MotCleVO merge(final MotCleVO detachedInstance) {
        MotCleBO.log.debug("merging MotCleVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final MotCleVO result = (MotCleVO) session.merge(detachedInstance);
            session.getTransaction().commit();
            MotCleBO.log.debug("merge successful");
            return result;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            MotCleBO.log.error("merge failed", re);
            throw re;
        }
    }

    /**
     * Find by id.
     * 
     * @param libelle
     *            the id
     * 
     * @return the mot cle VO
     */
    public MotCleVO findById(final String libelle) {
        MotCleBO.log.debug("getting MotCleVO instance with id: " + libelle);
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final MotCleVO instance = (MotCleVO) session.get("net.simcafamily.paksou.valueObject.MotCleVO", libelle);
            session.getTransaction().commit();
            if (instance == null) {
                MotCleBO.log.debug("get successful, no instance found");
            } else {
                MotCleBO.log.debug("get successful, instance found");
            }
            return instance;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            MotCleBO.log.error("get failed", re);
            throw re;
        }
    }

    /**
     * Find by example.
     * 
     * @param instance
     *            the instance
     * 
     * @return the list
     */
    @SuppressWarnings("unchecked")
    public List<MotCleVO> findByExample(final MotCleVO instance) {
        MotCleBO.log.debug("finding MotCleVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final List<MotCleVO> results = session.createCriteria("net.simcafamily.paksou.businessObject.MotCleVO").add(
                    Example.create(instance)).list();
            session.getTransaction().commit();
            MotCleBO.log.debug("find by example successful, result size: " + results.size());
            return results;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            MotCleBO.log.error("find by example failed", re);
            throw re;
        }
    }

    /**
     * Retrieve list.
     * 
     * @return the list
     */
    @SuppressWarnings("unchecked")
    public List<MotCleVO> retrieveList() {
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        session.beginTransaction();
        final List<MotCleVO> liste = session.createQuery("from MotCleVO").list();
        session.getTransaction().commit();
        return liste;
    }

    /**
     * @return
     */
    @SuppressWarnings("unchecked")
    public List<MotCleVO> retrieveValidList() {
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        session.beginTransaction();
        final List<MotCleVO> liste = session.createQuery("from MotCleVO where creationAuto=0").list();
        session.getTransaction().commit();
        return liste;
    }

    public void validerMotCle(final MotCleVO motCle) {
        motCle.setCreationAuto(Boolean.FALSE);
        update(motCle);
    }

}
