/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.businessObject.impl;

import java.sql.Date;
import java.util.Iterator;
import java.util.List;

import net.simcafamily.paksou.businessObject.IOperationBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.CompteVO;
import net.simcafamily.paksou.valueObject.OperationVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Criteria;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.Example;
import org.hibernate.criterion.Restrictions;

/**
 * Home object for domain model class OperationVO.
 * 
 * @see net.simcafamily.paksou.valueObject.OperationVO
 * @author $Author: simon.guerard $
 * @version $Revision: 390 $
 */
public class OperationBO implements IOperationBO {

    /** The Constant LOGGER. */
    private static final Log log = LogFactory.getLog(OperationBO.class);

    /**
     * Persist.
     * 
     * @param transientInstance
     *            the transient instance
     */
    public void persist(final OperationVO transientInstance) {
        OperationBO.log.debug("persisting OperationVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.persist(transientInstance);
            session.getTransaction().commit();
            OperationBO.log.debug("persist successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            OperationBO.log.error("persist failed", re);
            throw re;
        }
    }

    public void update(final OperationVO instance) {
        OperationBO.log.debug("update OperationVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.update(instance);
            session.getTransaction().commit();
            OperationBO.log.debug("update successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            OperationBO.log.error("update failed", re);
            throw re;
        }
    }

    /**
     * Attach clean.
     * 
     * @param instance
     *            the instance
     */
    public void attachClean(final OperationVO instance) {
        OperationBO.log.debug("attaching clean OperationVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.lock(instance, LockMode.NONE);
            session.getTransaction().commit();
            OperationBO.log.debug("attach successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            OperationBO.log.error("attach failed", re);
            throw re;
        }
    }

    /**
     * Delete.
     * 
     * @param persistentInstance
     *            the persistent instance
     */
    public void delete(final OperationVO persistentInstance) {
        OperationBO.log.debug("deleting OperationVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            session.delete(persistentInstance);
            session.getTransaction().commit();
            OperationBO.log.debug("delete successful");
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            OperationBO.log.error("delete failed", re);
            throw re;
        }
    }

    /**
     * Merge.
     * 
     * @param detachedInstance
     *            the detached instance
     * 
     * @return the operation VO
     */
    public OperationVO merge(final OperationVO detachedInstance) {
        OperationBO.log.debug("merging OperationVO instance");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final OperationVO result = (OperationVO) session.merge(detachedInstance);
            session.getTransaction().commit();
            OperationBO.log.debug("merge successful");
            return result;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            OperationBO.log.error("merge failed", re);
            throw re;
        }
    }

    /**
     * Find by id.
     * 
     * @param id
     *            the id
     * 
     * @return the operation VO
     */
    public OperationVO findById(final java.lang.Integer id) {
        OperationBO.log.debug("getting OperationVO instance with id: " + id);
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final OperationVO instance = (OperationVO) session.get("net.simcafamily.paksou.valueObject.OperationVO", id);
            session.getTransaction().commit();
            if (instance == null) {
                OperationBO.log.debug("get successful, no instance found");
            } else {
                OperationBO.log.debug("get successful, instance found");
            }
            return instance;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            OperationBO.log.error("get failed", re);
            throw re;
        }
    }

    /**
     * Find by categorie.
     * 
     * @param pDateFin
     * @param pDateDebut
     * @param pCompteVO
     * 
     * @param id
     *            the id
     * 
     * @return the operation VO
     */
    public List<OperationVO> findByCategorieAndDate(final CategorieVO pCategorie, final String pDateDebut,
            final String pDateFin, final CompteVO pCompteVO) {
        OperationBO.log.debug("getting OperationVO instance with categorie: " + pCategorie);
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            final StringBuffer requete = new StringBuffer("FROM OperationVO WHERE ");
            if (pCategorie != null) {
                requete.append("categorie='");
                requete.append(pCategorie.getLibelle());
                requete.append("' ");
            } else {
                requete.append("categorie IS NULL ");
            }
            requete.append("AND date>'");
            requete.append(Date.valueOf(pDateDebut));
            requete.append("' AND date<'");
            requete.append(Date.valueOf(pDateFin));
            requete.append("' AND compte='");
            requete.append(pCompteVO.getNumero());
            requete.append("' order by date asc");
            final Query query = session.createQuery(requete.toString());
            final List<OperationVO> lstOperations = query.list();
            session.getTransaction().commit();
            if ((lstOperations == null) || (lstOperations.size() == 0)) {
                OperationBO.log.debug("get successful, no instance found");
            } else {
                OperationBO.log.debug("get successful, instance found");
            }
            return lstOperations;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            OperationBO.log.error("get failed", re);
            throw re;
        }
    }

    /**
     * Find by example.
     * 
     * @param instance
     *            the instance
     * 
     * @return the list
     */
    public List<OperationVO> findByExample(final OperationVO instance) {
        if (instance == null) {
            return retrieveList();
        }
        OperationBO.log.debug("finding OperationVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        try {
            session.beginTransaction();
            Criteria critere = session.createCriteria("net.simcafamily.paksou.valueObject.OperationVO");
            critere = critere.add(Example.create(instance).ignoreCase());
            if ((instance.getCompte() != null) && (instance.getCompte().getNumero() != null)
                    && (instance.getCompte().getNumero().length() > 0)) {
                critere = critere.add(Restrictions.eq("compte", instance.getCompte()));
            }
            if ((instance.getCategorie() != null) && (instance.getCategorie().getLibelle() != null)
                    && (instance.getCategorie().getLibelle().length() > 0)) {
                critere = critere.add(Restrictions.eq("categorie", instance.getCategorie()));
            }
            final List<OperationVO> results = critere.list();
            session.getTransaction().commit();
            OperationBO.log.debug("find by example successful, result size: " + results.size());
            return results;
        } catch (final RuntimeException re) {
            session.getTransaction().rollback();
            OperationBO.log.error("find by example failed", re);
            throw re;
        }
    }

    /**
     * Charger liste operations.
     * 
     * @param lstOperations
     *            the lst operations
     */
    public void chargerListeOperations(final List<OperationVO> lstOperations) {
        final Iterator<OperationVO> iterOperation = lstOperations.iterator();
        while (iterOperation.hasNext()) {
            final OperationVO ope = iterOperation.next();
            if (findById(ope.getIdentifiant()) == null) {
                persist(ope);
            }
        }
    }

    /**
     * Retrieve list.
     * 
     * @return the list
     */
    public List<OperationVO> retrieveList() {
        OperationBO.log.debug("finding OperationVO instance by example");
        final Session session = HibernateUtil.getSessionFactory().getCurrentSession();
        session.beginTransaction();
        final Query query = session.createQuery("from OperationVO");
        final List<OperationVO> liste = query.list();
        session.getTransaction().commit();
        return liste;
    }

}
