/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.enumeration;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * <PRE>
 * 
 * Enumeration sur le sens de l'operation.
 * 
 * </PRE>
 * 
 * @author Simon Guerard
 * @version $Revision: 410 $
 */
public enum EtatOperation implements Serializable {

    /** The PREVISION. */
    PREVISION("P", "Prevision"),
    /** The EFFECTIF. */
    EFFECTIF("E", "Effectif");

    /** The identifiant. */
    public String identifiant;

    /** The code label. */
    public String codeLabel;

    /**
     * Instancie a un nouvel objet EtatOperation.
     * 
     * @param id
     *            the id
     * @param code
     *            the code
     */
    private EtatOperation(final String id, final String code) {
        this.identifiant = id;
        this.codeLabel = code;
    }

    /**
     * Gets the etat operation by id.
     * 
     * @param id
     *            the id
     * 
     * @return the etat operation by id
     */
    public static EtatOperation getEtatOperationById(final String id) {
        for (int i = 0; i < EtatOperation.values().length; i++) {
            if ((null != id) && id.equals(EtatOperation.values()[i].identifiant)) {
                return EtatOperation.values()[i];
            }
        }
        return null;
    }

    /**
     * Gets the etat operation by code label.
     * 
     * @param code
     *            the code
     * 
     * @return the etat operation by code label
     */
    public static EtatOperation getEtatOperationByCodeLabel(final String code) {
        for (int i = 0; i < EtatOperation.values().length; i++) {
            if ((null != code) && code.equals(EtatOperation.values()[i].codeLabel)) {
                return EtatOperation.values()[i];
            }
        }
        return null;
    }

    /**
     * Getter of EtatOperation's list.
     * 
     * @return liste des EtatOperation
     */
    public static List<EtatOperation> getListeEtatOperation() {
        final List<EtatOperation> listeEtats = new ArrayList<EtatOperation>();
        listeEtats.add(EtatOperation.PREVISION);
        listeEtats.add(EtatOperation.EFFECTIF);
        return listeEtats;
    }

    /**
     * Gets the code label.
     * 
     * @return codeLabel
     */
    public String getCodeLabel() {
        return this.codeLabel;
    }

    /**
     * Sets the code label.
     * 
     * @param code
     *            the code
     */
    public void setCodeLabel(final String code) {
        this.codeLabel = code;
    }

    /**
     * Gets the identifiant.
     * 
     * @return identifiant
     */
    public String getIdentifiant() {
        return this.identifiant;
    }

    /**
     * Sets the identifiant.
     * 
     * @param id
     *            the id
     */
    public void setIdentifiant(final String id) {
        this.identifiant = id;
    }

}
