/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.enumeration;

import java.util.ArrayList;
import java.util.List;

/**
 * The Enum MoyenPaiement.
 * 
 * @author $Author: simon.guerard $
 * @version $Revision: 403 $
 */
public enum MoyenPaiement {

    /** The CHEQUE. */
    CHEQUE("CHQ", "Cheque"),

    /** The CARTE. */
    CARTE("PAYMENT", "carte"),

    /** The DIRECTDEP. */
    DIRECTDEP("DIRECTDEP", "Virement permanent interne"),

    /** The AUTRE. */
    AUTRE("OTHER", "frais bancaires"),

    /** The XFER. */
    XFER("XFER", "virement interne");

    /** The identifiant. */
    protected String identifiant;

    /** The code label. */
    protected String codeLabel;

    /**
     * Instantiates a new moyen paiement.
     * 
     * @param id
     *            the id
     * @param code
     *            the code
     */
    private MoyenPaiement(final String id, final String code) {
        this.identifiant = id;
        this.codeLabel = code;
    }

    /**
     * Gets the moyen paiement by id.
     * 
     * @param id
     *            the id
     * 
     * @return the moyen paiement by id
     */
    public static MoyenPaiement getMoyenPaiementById(final String id) {
        for (int i = 0; i < MoyenPaiement.values().length; i++) {
            if (null != id && id.equals(MoyenPaiement.values()[i].identifiant)) {
                return MoyenPaiement.values()[i];
            }
        }
        return null;
    }

    /**
     * Gets the moyen paiement by code label.
     * 
     * @param code
     *            the code
     * 
     * @return the moyen paiement by code label
     */
    public static MoyenPaiement getMoyenPaiementByCodeLabel(final String code) {
        for (int i = 0; i < MoyenPaiement.values().length; i++) {
            if (null != code && code.equals(MoyenPaiement.values()[i].codeLabel)) {
                return MoyenPaiement.values()[i];
            }
        }
        return null;
    }

    /**
     * Getter of MoyenPaiement's list.
     * 
     * @return liste des MoyenPaiement
     */
    public static List<MoyenPaiement> getListeMoyenPaiement() {
        final List<MoyenPaiement> listeMoyens = new ArrayList<MoyenPaiement>();
        listeMoyens.add(MoyenPaiement.CARTE);
        listeMoyens.add(MoyenPaiement.CHEQUE);
        listeMoyens.add(MoyenPaiement.DIRECTDEP);
        listeMoyens.add(MoyenPaiement.XFER);
        listeMoyens.add(MoyenPaiement.AUTRE);
        return listeMoyens;
    }

    /**
     * Gets the code label.
     * 
     * @return codeLabel
     */
    public String getCodeLabel() {
        return this.codeLabel;
    }

    /**
     * Gets the identifiant.
     * 
     * @return identifiant
     */
    public String getIdentifiant() {
        return this.identifiant;
    }

}