/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.enumeration;

import java.util.ArrayList;
import java.util.List;

/**
 * <PRE>
 * 
 * Enumeration sur le sens de l'operation.
 * 
 * </PRE>
 * 
 * @author $Author: simon.guerard $
 * @version $Revision: 410 $
 */
public enum SensOperation {

    /** The DEBIT. */
    DEBIT("D", "debit"),

    /** The CREDIT. */
    CREDIT("C", "credit");

    /** The identifiant. */
    public String identifiant;

    /** The code label. */
    public String codeLabel;

    /**
     * Instantiates a new sens operation.
     * 
     * @param id
     *            the id
     * @param code
     *            the code
     */
    private SensOperation(final String id, final String code) {
        this.identifiant = id;
        this.codeLabel = code;
    }

    /**
     * Gets the sens operation by id.
     * 
     * @param id
     *            the id
     * 
     * @return the sens operation by id
     */
    public static SensOperation getSensOperationById(final String id) {
        for (int i = 0; i < SensOperation.values().length; i++) {
            if ((null != id) && id.equals(SensOperation.values()[i].identifiant)) {
                return SensOperation.values()[i];
            }
        }
        return null;
    }

    /**
     * Gets the sens operation by code label.
     * 
     * @param code
     *            the code
     * 
     * @return the sens operation by code label
     */
    public static SensOperation getSensOperationByCodeLabel(final String code) {
        for (int i = 0; i < SensOperation.values().length; i++) {
            if ((null != code) && code.equals(SensOperation.values()[i].codeLabel)) {
                return SensOperation.values()[i];
            }
        }
        return null;
    }

    /**
     * Getter of SensOperation's list.
     * 
     * @return liste des SensOperation
     */
    public static List<SensOperation> getListeSensOperation() {
        final List<SensOperation> listeSens = new ArrayList<SensOperation>();
        listeSens.add(SensOperation.CREDIT);
        listeSens.add(SensOperation.DEBIT);
        return listeSens;
    }

    /**
     * Gets the code label.
     * 
     * @return codeLabel
     */
    public String getCodeLabel() {
        return this.codeLabel;
    }

    /**
     * Gets the identifiant.
     * 
     * @return identifiant
     */
    public String getIdentifiant() {
        return this.identifiant;
    }

}