/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.hibernate;

import org.hibernate.SessionFactory;
import org.hibernate.cfg.Configuration;
import org.hibernate.classic.Session;

/**
 * The Class HibernateUtil.
 * 
 * @author $Author: simon.guerard $
 * @version $Revision: 390 $
 */
public abstract class HibernateUtil {

    /** The Constant sessionFactory. */
    private static final SessionFactory sessionFactory;
    private static final Configuration configuration;

    static {
        try {
            configuration = new Configuration().configure();
            // Creation de la SessionFactory a partir de hibernate.cfg.xml
            sessionFactory = HibernateUtil.configuration.buildSessionFactory();
            // JDBCTransaction tr = new JDBCTransaction(null, null);
        } catch (final Throwable ex) {
            // Make sure you LOGGER the exception, as it might be swallowed
            System.err.println("Initial SessionFactory creation failed." + ex);
            throw new ExceptionInInitializerError(ex);
        }
    }

    /** The Constant session. */
    public static final ThreadLocal session = new ThreadLocal();

    /**
     * Gets the session factory.
     * 
     * @return the session factory
     */
    public static SessionFactory getSessionFactory() {
        return HibernateUtil.sessionFactory;
    }

    public static Session getCurrentSession() {
        return HibernateUtil.sessionFactory.getCurrentSession();
    }

    /**
     * @return the configuration
     */
    public static final Configuration getConfiguration() {
        return HibernateUtil.configuration;
    }
}
