/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.action;

import net.simcafamily.paksou.businessComponent.IBanqueBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.presentation.core.AbstractBaseAction;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.BanqueVO;

public class EditerBanque extends AbstractBaseAction {

    private IBanqueBC banqueBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.AbstractBaseAction#execute()
     */
    @Override
    public String execute() {
        boolean creation = getSession().getBooleanAttribute(ConstantesValeurs.PARAM_CREATION);
        BanqueVO banqueVO = null;
        if (creation) {
            banqueVO = new BanqueVO();
        } else {
            try {
                String idBanque = getSession().getStringAttribute(ConstantesValeurs.ID_BANQUE);
                if ((idBanque == null) || (idBanque.length() <= 0)) {
                    creation = true;
                } else {
                    IBanqueBC banqueBC = (IBanqueBC) ContextFactory.getContext().getBean("banqueBC");
                    banqueVO = banqueBC.findByName(idBanque);
                }
            } catch (NumberFormatException e) {
                creation = true;
            }
        }
        try {
            banqueVO.setNom(getSession().getStringAttribute(ConstantesValeurs.PARAM_BANQUE_NAME));
            banqueVO.setAdresse(getSession().getStringAttribute(ConstantesValeurs.PARAM_BANQUE_ADRESSE));
            banqueVO.setContact(getSession().getStringAttribute(ConstantesValeurs.PARAM_BANQUE_CONTACT));
            banqueVO.setTelContact(getSession().getStringAttribute(ConstantesValeurs.PARAM_BANQUE_TELCONTACT));
            if (creation) {
                this.banqueBC.persist(banqueVO);
            } else {
                this.banqueBC.update(banqueVO);
            }
        } catch (Exception e) {
            // on signale une erreur
            getSession().getErreurs().clear();
            getSession().getErreurs().add("La demande de consultation n'a pu aboutir");
            // on rend le resultat [erreurs]
            return ConstantesValeurs.VUE_ERREURS;
        }
        // on rend l'etat [consulter]
        return ConstantesValeurs.VUE_LISTE_BANQUES;
    }

    /**
     * @return the banqueBC
     */
    public final IBanqueBC getBanqueBC() {
        return this.banqueBC;
    }

    /**
     * @param pBanqueBC
     *            the banqueBC to set
     */
    public final void setBanqueBC(IBanqueBC pBanqueBC) {
        this.banqueBC = pBanqueBC;
    }
}
