/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.action;

import net.simcafamily.paksou.businessComponent.IBanqueBC;
import net.simcafamily.paksou.businessComponent.ICompteBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.presentation.core.AbstractBaseAction;
import net.simcafamily.paksou.util.UtilChaine;
import net.simcafamily.paksou.valueObject.BanqueVO;
import net.simcafamily.paksou.valueObject.CompteVO;

public class EditerCompte extends AbstractBaseAction {

    private ICompteBC compteBC;
    private IBanqueBC banqueBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.AbstractBaseAction#execute()
     */
    @Override
    public String execute() {
        boolean creation = false;
        CompteVO compteVO = null;
        try {
            String idCompte = getSession().getStringAttribute(ConstantesValeurs.ID_COMPTE);
            if ((idCompte == null) || (idCompte.length() <= 0)) {
                creation = true;
            } else {
                compteVO = this.compteBC.findById(idCompte);
            }
        } catch (NumberFormatException e) {
            creation = true;
        }

        if (creation) {
            compteVO = new CompteVO();
        }
        try {
            compteVO.setNumero(getSession().getStringAttribute(ConstantesValeurs.PARAM_COMPTE_NUMERO));
            compteVO.setLibelle(getSession().getStringAttribute(ConstantesValeurs.PARAM_COMPTE_LIBELLE));
            String dateImport = getSession().getStringAttribute(ConstantesValeurs.PARAM_COMPTE_DATE_DERNIER_IMPORT);
            if (dateImport.length() > 0) {
                compteVO.setDateDernierImport(UtilChaine.string2Date(dateImport));
            } else {
                compteVO.setDateDernierImport(null);
            }
            BanqueVO banqueVO = this.banqueBC.findByName(getSession().getStringAttribute(
                    ConstantesValeurs.PARAM_COMPTE_NOM_BANQUE));
            compteVO.setBanque(banqueVO);
            this.compteBC.modifierCompte(compteVO);
        } catch (Exception e) {
            // on signale une erreur
            getSession().getErreurs().clear();
            getSession().getErreurs().add("La demande de consultation n'a pu aboutir");
            // on rend le resultat [erreurs]
            return ConstantesValeurs.VUE_ERREURS;
        }
        // on rend l'etat [consulter]
        return ConstantesValeurs.VUE_LISTE_COMPTES;
    }

    /**
     * @return the compteBC
     */
    public final ICompteBC getCompteBC() {
        return this.compteBC;
    }

    /**
     * @param pCompteBC
     *            the compteBC to set
     */
    public final void setCompteBC(ICompteBC pCompteBC) {
        this.compteBC = pCompteBC;
    }

    /**
     * @return the banqueBC
     */
    public final IBanqueBC getBanqueBC() {
        return this.banqueBC;
    }

    /**
     * @param pBanqueBC
     *            the banqueBC to set
     */
    public final void setBanqueBC(IBanqueBC pBanqueBC) {
        this.banqueBC = pBanqueBC;
    }
}
