/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.core;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Map;

import javax.swing.JPanel;

import net.simcafamily.paksou.presentation.listener.QuitListener;

/**
 * @version $Revision$
 * @author $Author$
 */
public class BaseControleur implements IControleur, ActionListener {

    // les actions a controler
    private Map<String, InfosAction> actions;

    // le nom de la 1ere action
    private String firstActionName;

    // le nom de la derniere action
    private String lastActionName;

    private Synchronisateur synchro;

    // frame principale de l'application.
    private BaseVueJFrame baseVue;

    /**
     * Constructeur par defaut.
     */
    public BaseControleur() {
    }

    // le moteur d'execution des actions
    public void run() {
        this.baseVue.init();
        this.baseVue.run();

        // variables locales
        InfosAction configAction = null;
        String actionName = null;
        String etat = null;
        IVue vue = null;

        // boucle d'execution des actions
        actionName = this.firstActionName;
        while ((actionName != null) && !actionName.equals("") && !actionName.equals(this.lastActionName)) {
            // on recupere la config de l'action
            configAction = this.actions.get(actionName);
            if (configAction == null) {
                // erreur de config - on s'arrete
                throw new RuntimeException("L'action [" + actionName + "] n'a pas ete configuree correctement");
            }
            // execution de l'action s'il y en a une
            if (configAction.getAction() != null) {
                // execution de l'action
                etat = configAction.getAction().execute();
                // on recupere la vue associee a l'etat
                vue = configAction.getEtats().get(etat);
                // si vue == null, erreur de config
                if (vue == null) {
                    throw new RuntimeException("L'etat [" + etat + "] de l'action [" + actionName
                            + "] n'a pas ete configure correctement");
                }
            } else {
                // pas d'action - directement la vue
                etat = "";
                vue = configAction.getVue();
            }
            // on affiche la vue en se synchronisant avec elle
            this.synchro.reset();
            final Component panelVue = vue.affiche();

            final Component c = this.baseVue.getManagerFrame().getContent();
            if ((c != null) && (c instanceof QuitListener)) {
                final QuitListener q = (QuitListener) c;
                q.quit();
                this.baseVue.removeQuitListener(q);
            }
            this.baseVue.getManagerFrame().setContent(new JPanel());
            this.baseVue.validate();
            this.baseVue.getManagerFrame().setContent(panelVue);
            this.baseVue.validate();
            this.synchro.waitOne();
            // action suivante
            actionName = this.baseVue.getAction();
            if ((actionName == null) || (actionName.length() <= 0)) {
                actionName = vue.getAction();
            }
        }
    }

    /**
     * @param actions
     *            The actions to set.
     */
    public void setActions(final Map<String, InfosAction> actions) {
        this.actions = actions;
    }

    /**
     * @param firstActionName
     *            The firstActionName to set.
     */
    public void setFirstActionName(final String firstActionName) {
        this.firstActionName = firstActionName;
    }

    /**
     * @param lastActionName
     *            The lastActionName to set.
     */
    public void setLastActionName(final String lastActionName) {
        this.lastActionName = lastActionName;
    }

    /**
     * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
     */
    public void actionPerformed(final ActionEvent pE) {
        run();
    }

    /**
     * @return Returns the actions.
     */
    public Map<String, InfosAction> getActions() {
        return this.actions;
    }

    /**
     * @return Returns the firstActionName.
     */
    public String getFirstActionName() {
        return this.firstActionName;
    }

    /**
     * @return Returns the lastActionName.
     */
    public String getLastActionName() {
        return this.lastActionName;
    }

    /**
     * @return the baseVue
     */
    public final BaseVueJFrame getBaseVue() {
        return this.baseVue;
    }

    /**
     * @param pBaseVue
     *            the baseVue to set
     */
    public final void setBaseVue(final BaseVueJFrame pBaseVue) {
        this.baseVue = pBaseVue;
    }

    /**
     * @return the synchro
     */
    public final Synchronisateur getSynchro() {
        return this.synchro;
    }

    /**
     * @param pSynchro
     *            the synchro to set
     */
    public final void setSynchro(final Synchronisateur pSynchro) {
        this.synchro = pSynchro;
    }

}
