/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.core;

import java.awt.AWTEvent;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.HeadlessException;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.ArrayList;

import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JSplitPane;
import javax.swing.LookAndFeel;
import javax.swing.SwingConstants;
import javax.swing.UIManager;
import javax.swing.WindowConstants;
import javax.swing.border.EmptyBorder;
import javax.swing.plaf.metal.MetalLookAndFeel;

import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.presentation.Session;
import net.simcafamily.paksou.presentation.UIHelper;
import net.simcafamily.paksou.presentation.listener.QuitListener;
import net.simcafamily.paksou.presentation.panel.HeaderPanel;
import net.simcafamily.paksou.presentation.panel.SimpleInternalFrame;

import org.hibernate.Query;
import org.xnap.commons.i18n.I18n;
import org.xnap.commons.i18n.I18nFactory;

import com.jgoodies.looks.Options;
import com.jgoodies.looks.plastic.PlasticLookAndFeel;
import com.jgoodies.looks.plastic.PlasticXPLookAndFeel;
import com.jgoodies.looks.plastic.theme.DesertBluer;

/**
 * @version $Revision$
 * @author $Author$
 */
public class BaseVueJFrame extends JFrame implements IVue, Runnable {

    /**
     * serialVersionUID.
     */
    private static final long serialVersionUID = -5755919593570170251L;

    // nom de la vue
    private String nom;

    // nom de l'action que le controleur doit executer
    private String action;

    private final ArrayList<QuitListener> quitListeners;

    private SimpleInternalFrame managerFrame;

    // session de l'application commune aux vues et actions
    private Session session;

    private Synchronisateur synchro;

    protected final I18n i18n = I18nFactory.getI18n(getClass());

    /**
     * @throws HeadlessException
     */
    public BaseVueJFrame() {
        this.quitListeners = new ArrayList<QuitListener>();

        // ajout d'un listerner pour l'arret propre de la base de donnees HSQL
        this.quitListeners.add(new QuitListener() {

            public void quit() {
                final org.hibernate.Session session = HibernateUtil.getSessionFactory().getCurrentSession();
                session.beginTransaction();
                Query query = session.createSQLQuery("SHUTDOWN");
                query.executeUpdate();
                session.getTransaction().commit();
            }
        });
    }

    public void init() throws HeadlessException {
        configureUI();
        // on ajoute le menu a la fenetre
        enableEvents(AWTEvent.WINDOW_EVENT_MASK);

        // configureUI();
        setContentPane(buildContentPane());
        initMenu();
        // setTitle("Paksou");

        setSize(new java.awt.Dimension(1024, 840));
        setResizable(false);
        UIHelper.centerOnScreen(this);

        setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(final WindowEvent evt) {
                quit();
            }
        });
    }

    // getters-setters
    public Session getSession() {
        return this.session;
    }

    public void setSession(final Session session) {
        this.session = session;
    }

    /**
     * @return Returns the action.
     */
    public String getAction() {
        return this.action;
    }

    /**
     * @return Returns the nom.
     */
    public String getNom() {
        return this.nom;
    }

    // methode du thread d'affichage
    public void run() {
        // affichage de la vue
        setVisible(true);
    }

    /**
     * @param action
     *            The action to set.
     */
    public void setAction(final String action) {
        this.action = action;
    }

    /**
     * @param nom
     *            The nom to set.
     */
    public void setNom(final String nom) {
        this.nom = nom;
    }

    /**
     * Ajoute un ecouteur de fin de session.
     * 
     * @param listener
     *            Ecouteur a notifier de la fin de session
     */
    public void addQuitListener(final QuitListener listener) {
        this.quitListeners.add(listener);
    }

    /**
     * Retire l'ecouteur.
     * 
     * @param listener
     *            L'ecouteur a retirer
     */
    public void removeQuitListener(final QuitListener listener) {
        this.quitListeners.remove(listener);
    }

    /**
     * Termine l'application apres demande de confirmation.
     */
    public boolean quit() {
        final int confirm = JOptionPane.showConfirmDialog(this, this.i18n.tr("Do you want to quit Paksou ?"), "Paksou",
                JOptionPane.YES_NO_OPTION);

        if (confirm == JOptionPane.YES_OPTION) {
            for (final QuitListener quitListener : this.quitListeners) {
                (quitListener).quit();
            }
            this.quitListeners.clear();

            dispose();
            System.exit(0);
            return true;
        }

        return false;
    }

    private void initMenu() {
        final JMenuBar menuBar = new JMenuBar();
        final JMenu fichier = new JMenu("File");
        fichier.setMnemonic(KeyEvent.VK_F);
        fichier.getAccessibleContext().setAccessibleDescription(this.i18n.tr("File Menu"));
        menuBar.add(fichier);
        final JMenu aide = new JMenu("Help");
        aide.setMnemonic(KeyEvent.VK_A);
        aide.getAccessibleContext().setAccessibleDescription(this.i18n.tr("Help Menu"));
        menuBar.add(aide);
        final JMenuItem about = new JMenuItem(this.i18n.tr("About ..."));
        about.setMnemonic(KeyEvent.VK_HELP);
        aide.add(about);
        setJMenuBar(menuBar);
    }

    /**
     * Applique les parametres de l'IHM en fonction des donnees du memebre settings. Ce code est extrait de la demo
     * Looks de jgoodies.com, voir en-tete du fichier. *
     * 
     * @author Karsten Lentzsch
     * @author Romain Guy
     */
    private void configureUI() {
        Options.setDefaultIconSize(new Dimension(18, 18));

        UIManager.put(Options.USE_SYSTEM_FONTS_APP_KEY, true);
        Options.setUseNarrowButtons(false);

        Options.setTabIconsEnabled(true);
        UIManager.put(Options.POPUP_DROP_SHADOW_ENABLED_KEY, true);

        final LookAndFeel selectedLaf = new PlasticXPLookAndFeel();
        MetalLookAndFeel.setCurrentTheme(new DesertBluer());
        PlasticLookAndFeel.setTabStyle(PlasticLookAndFeel.TAB_STYLE_DEFAULT_VALUE);
        PlasticLookAndFeel.setHighContrastFocusColorsEnabled(false);

        final JRadioButton radio = new JRadioButton();
        radio.getUI().uninstallUI(radio);
        final JCheckBox checkBox = new JCheckBox();
        checkBox.getUI().uninstallUI(checkBox);

        try {
            UIManager.setLookAndFeel(selectedLaf);
        } catch (final Exception e) {
            System.out.println("Can't change L&F: " + e);
        }
    }

    /**
     * Construit le panneau de composants principal. Au retour de cette methode, tous les composants graphiques de la
     * fenetre ont ete crees.
     * 
     * @return Le panneau de composants principal. Il s'agit du pere de tous les composants de l'application.
     */
    private Container buildContentPane() {
        // en-tete et titre
        final JPanel headerPanel = new JPanel(new BorderLayout());
        final HeaderPanel header = new HeaderPanel(this.i18n.tr("Paksou"), UIHelper.readImageIcon("placeholder.png"),
                0.0f);
        headerPanel.add(BorderLayout.NORTH, header);
        headerPanel.add(BorderLayout.SOUTH, new JSeparator(SwingConstants.HORIZONTAL));
        headerPanel.setBorder(new EmptyBorder(0, 0, 6, 0));

        // contenu
        final SimpleInternalFrame contentFrame = new SimpleInternalFrame(UIHelper.readImageIcon("operations.png"),
                this.i18n.trn("Operation", "Operations", 2));
        this.managerFrame = new SimpleInternalFrame(UIHelper.readImageIcon("manager.png"), this.i18n.tr("Manager"));

        final JSplitPane splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, false, contentFrame, this.managerFrame);
        splitPane.setResizeWeight(0.08f);
        splitPane.setContinuousLayout(true);

        // liste des operations possibles
        final JButton banque = UIHelper.createButton(this.i18n.trn("Bank", "Banks", 2), "item", true);
        banque.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                setAction(ConstantesValeurs.ACTION_LISTER_BANQUES);
                getSynchro().set();
            }
        });
        final JButton compte = UIHelper.createButton(this.i18n.trn("Account", "Accounts", 2), "item", true);
        compte.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                setAction(ConstantesValeurs.ACTION_LISTER_COMPTES);
                getSynchro().set();
            }
        });
        final JButton operation = UIHelper.createButton(this.i18n.trn("Operation", "Operations", 2), "item", true);
        operation.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                setAction(ConstantesValeurs.ACTION_LISTER_OPERATIONS);
                getSynchro().set();
            }
        });
        final JButton categorie = UIHelper.createButton(this.i18n.trn("Category", "Categories", 2), "item", true);
        categorie.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                setAction(ConstantesValeurs.ACTION_LISTER_CATEGORIES);
                getSynchro().set();
            }
        });
        final JButton budget = UIHelper.createButton(this.i18n.trn("Budget", "Budgets", 2), "item", true);
        budget.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                setAction(ConstantesValeurs.ACTION_LISTER_BUDGETS);
                getSynchro().set();
            }
        });
        final JButton groupe = UIHelper.createButton(this.i18n.trn("Group", "Groups", 2), "item", true);
        groupe.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                setAction(ConstantesValeurs.ACTION_LISTER_GROUPES);
                getSynchro().set();
            }
        });
        final JButton motCle = UIHelper.createButton(this.i18n.trn("Keyword", "Keywords", 2), "item", true);
        motCle.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                setAction(ConstantesValeurs.ACTION_LISTER_MOT_CLE);
                getSynchro().set();
            }
        });
        final JButton quit = UIHelper.createButton(this.i18n.tr("Exit"), "quit", true);
        quit.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                quit();
            }
        });

        final Box buttonsBox = Box.createVerticalBox();
        buttonsBox.setOpaque(false);
        buttonsBox.add(banque);
        buttonsBox.add(compte);
        buttonsBox.add(operation);
        buttonsBox.add(categorie);
        buttonsBox.add(budget);
        buttonsBox.add(quit);

        final JScrollPane operations = new JScrollPane(buttonsBox);
        operations.setOpaque(false);
        operations.getViewport().setOpaque(false);
        operations.setViewportBorder(null);
        contentFrame.setContent(operations);

        // contenu par defaut, intro animee
        this.managerFrame.setContent(new JPanel());

        // panneau de la fenetre
        final JPanel pane = new JPanel(new BorderLayout());
        pane.add(BorderLayout.NORTH, headerPanel);
        pane.add(BorderLayout.CENTER, splitPane);
        return pane;
    }

    /**
     * @return the managerFrame
     */
    public final SimpleInternalFrame getManagerFrame() {
        return this.managerFrame;
    }

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    public Component affiche() {
        return null;
    }

    /**
     * @return the synchro
     */
    public final Synchronisateur getSynchro() {
        return this.synchro;
    }

    /**
     * @param pSynchro
     *            the synchro to set
     */
    public final void setSynchro(final Synchronisateur pSynchro) {
        this.synchro = pSynchro;
    }

}
