/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.panel;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.EventObject;

import javax.swing.JButton;
import javax.swing.JOptionPane;
import javax.swing.JTable;
import javax.swing.UIManager;
import javax.swing.event.CellEditorListener;
import javax.swing.event.ChangeEvent;
import javax.swing.event.EventListenerList;
import javax.swing.table.TableCellEditor;
import javax.swing.table.TableCellRenderer;

/**
 * @version $Revision$
 * @author $Author$
 */
public class BoutonCellEditor extends JButton implements TableCellEditor, TableCellRenderer {

    /**
     * serialVersionUID
     */
    private static final long serialVersionUID = -4320452826904569515L;

    private String label;
    private boolean isPushed;

    public BoutonCellEditor(final String pLabel, final ActionListener pListener) {
        super();
        this.label = pLabel;
        this.setText(this.label);
        addActionListener(new ActionListener() {

            public void actionPerformed(ActionEvent pE) {
                pListener.actionPerformed(pE);
                fireEditingStopped();
            }
        });
        setOpaque(true);
    }

    public Object getCellEditorValue() {
        if (this.isPushed) {
            JOptionPane.showMessageDialog(this, this.label + ": Ouch!");
        }
        this.isPushed = false;
        return this;
    }

    public Component getTableCellEditorComponent(JTable pTable, Object pValue, boolean isSelected, int pRow, int pColumn) {
        if (isSelected) {
            this.setForeground(pTable.getSelectionForeground());
            this.setBackground(pTable.getSelectionBackground());
        } else {
            this.setForeground(pTable.getForeground());
            this.setBackground(pTable.getBackground());
        }
        this.isPushed = true;
        return this;
    }

    /**
     * @see javax.swing.table.TableCellRenderer#getTableCellRendererComponent(javax.swing.JTable, java.lang.Object,
     *      boolean, boolean, int, int)
     */
    public Component getTableCellRendererComponent(JTable pTable, Object pValue, boolean pIsSelected,
            boolean pHasFocus, int pRow, int pColumn) {
        if (pIsSelected) {
            setForeground(pTable.getSelectionForeground());
            setBackground(pTable.getSelectionBackground());
        } else {
            setForeground(pTable.getForeground());
            setBackground(UIManager.getColor("Button.background"));
        }
        return this;
    }

    /**
     * @see javax.swing.DefaultCellEditor#stopCellEditing()
     */
    public boolean stopCellEditing() {
        this.isPushed = false;
        fireEditingStopped();
        return true;
    }

    /**
     * Notifies all listeners that have registered interest for notification on this event type. The event instance is
     * created lazily.
     * 
     * @see EventListenerList
     */
    protected void fireEditingStopped() {
        // Guaranteed to return a non-null array
        Object[] listeners = this.listenerList.getListenerList();
        // Process the listeners last to first, notifying
        // those that are interested in this event
        for (int i = listeners.length - 2; i >= 0; i -= 2) {
            if (listeners[i] == CellEditorListener.class) {
                // Lazily create the event:
                if (this.changeEvent == null) {
                    this.changeEvent = new ChangeEvent(this);
                }
                ((CellEditorListener) listeners[i + 1]).editingStopped(this.changeEvent);
            }
        }
    }

    /**
     * @return the label
     */
    @Override
    public final String getLabel() {
        return this.label;
    }

    /**
     * @param pLabel
     *            the label to set
     */
    @Override
    public final void setLabel(String pLabel) {
        this.label = pLabel;
    }

    /**
     * @return the isPushed
     */
    public final boolean isPushed() {
        return this.isPushed;
    }

    /**
     * @param pIsPushed
     *            the isPushed to set
     */
    public final void setPushed(boolean pIsPushed) {
        this.isPushed = pIsPushed;
    }

    /**
     * @see javax.swing.CellEditor#addCellEditorListener(javax.swing.event.CellEditorListener)
     */
    public void addCellEditorListener(CellEditorListener pL) {

    }

    /**
     * @see javax.swing.CellEditor#cancelCellEditing()
     */
    public void cancelCellEditing() {

    }

    /**
     * @see javax.swing.CellEditor#isCellEditable(java.util.EventObject)
     */
    public boolean isCellEditable(EventObject pAnEvent) {
        return true;
    }

    /**
     * @see javax.swing.CellEditor#removeCellEditorListener(javax.swing.event.CellEditorListener)
     */
    public void removeCellEditorListener(CellEditorListener pL) {

    }

    /**
     * @see javax.swing.CellEditor#shouldSelectCell(java.util.EventObject)
     */
    public boolean shouldSelectCell(EventObject pAnEvent) {
        // specifie que la cellule doit etre selectionnee.
        return true;
    }
}
