/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.detail;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.simcafamily.paksou.businessComponent.IBanqueBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.presentation.core.AbstractVue;
import net.simcafamily.paksou.valueObject.BanqueVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueDetailBanque extends AbstractVue {

    private static final Log LOGGER = LogFactory.getLog(VueDetailBanque.class);

    protected JPanel contentPane = new JPanel(new BorderLayout());
    private IBanqueBC banqueBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueDetailBanque.LOGGER.isDebugEnabled()) {
            VueDetailBanque.LOGGER.debug("debut methode 'affiche()'");
        }
        boolean creation = false;
        BanqueVO banqueVO = null;
        try {
            String idBanque = getSession().getStringAttribute(ConstantesValeurs.ID_BANQUE);
            if ((idBanque == null) || (idBanque.length() <= 0) || idBanque.equals("null")) {
                creation = true;
                getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, true);
            } else {
                banqueVO = this.banqueBC.findByName(idBanque);
            }
        } catch (NumberFormatException e) {
            creation = true;
            getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, true);
        }

        if (creation) {
            banqueVO = new BanqueVO();
        }

        this.contentPane.add(BorderLayout.NORTH, new JLabel(this.i18n.tr("Details of Bank")));
        JPanel panel = new JPanel(new GridBagLayout());
        GridBagConstraints constraints = new GridBagConstraints();

        JLabel labelName = new JLabel(this.i18n.tr("Bank's name"));
        constraints.gridx = 0;
        constraints.gridy = 0;
        panel.add(labelName, constraints);
        final JTextField bankName = new JTextField(banqueVO.getNom(), 20);
        constraints.gridx = 1;
        constraints.gridy = 0;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(bankName, constraints);

        JLabel labelAddress = new JLabel(this.i18n.tr("Bank's address"));
        constraints.gridx = 0;
        constraints.gridy = 1;
        panel.add(labelAddress, constraints);
        final JTextField bankAddress = new JTextField(banqueVO.getAdresse(), 20);
        constraints.gridx = 1;
        constraints.gridy = 1;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(bankAddress, constraints);

        JLabel labelContact = new JLabel(this.i18n.tr("Bank's contact"));
        constraints.gridx = 0;
        constraints.gridy = 2;
        panel.add(labelContact, constraints);
        final JTextField bankContact = new JTextField(banqueVO.getContact(), 20);
        constraints.gridx = 1;
        constraints.gridy = 2;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(bankContact, constraints);

        JLabel labelContactTel = new JLabel(this.i18n.tr("Bank's contact tel"));
        constraints.gridx = 0;
        constraints.gridy = 3;
        panel.add(labelContactTel, constraints);
        final JTextField bankContactTel = new JTextField(banqueVO.getTelContact(), 20);
        constraints.gridx = 1;
        constraints.gridy = 3;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(bankContactTel, constraints);

        JButton btnModifier = new JButton(this.i18n.tr("Modify"));
        if (creation) {
            btnModifier.setText(this.i18n.tr("Create"));
        }
        btnModifier.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailBanque.this.baseVue.setAction(ConstantesValeurs.ACTION_EDITER_BANQUE);
                getSession().setAttribute(ConstantesValeurs.PARAM_BANQUE_NAME, bankName.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_BANQUE_ADRESSE, bankAddress.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_BANQUE_CONTACT, bankContact.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_BANQUE_TELCONTACT, bankContactTel.getText());
                VueDetailBanque.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 0;
        constraints.gridy = 4;
        panel.add(btnModifier, constraints);

        JButton btnCancel = new JButton(this.i18n.tr("Cancel"));
        btnCancel.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailBanque.this.baseVue.setAction(ConstantesValeurs.ACTION_LISTER_BANQUES);
                VueDetailBanque.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 1;
        constraints.gridy = 4;
        panel.add(btnCancel, constraints);

        this.contentPane.add(BorderLayout.CENTER, panel);

        return this.contentPane;
    }

    /**
     * @return the banqueBC
     */
    public final IBanqueBC getBanqueBC() {
        return this.banqueBC;
    }

    /**
     * @param pBanqueBC
     *            the banqueBC to set
     */
    public final void setBanqueBC(IBanqueBC pBanqueBC) {
        this.banqueBC = pBanqueBC;
    }

}
