/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.detail;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.simcafamily.paksou.businessComponent.IBudgetBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.presentation.core.AbstractVue;
import net.simcafamily.paksou.util.UtilChaine;
import net.simcafamily.paksou.valueObject.BudgetVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueDetailBudget extends AbstractVue {

    private static final Log LOGGER = LogFactory.getLog(VueDetailBudget.class);

    protected JPanel contentPane = new JPanel(new BorderLayout());
    private IBudgetBC budgetBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueDetailBudget.LOGGER.isDebugEnabled()) {
            VueDetailBudget.LOGGER.debug("debut methode 'affiche()'");
        }
        BudgetVO budgetVO = null;
        try {
            String idBudget = getSession().getStringAttribute(ConstantesValeurs.ID_BUDGET);
            if ((idBudget == null) || (idBudget.length() <= 0)) {
                getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, Boolean.TRUE);
            } else {

                budgetVO = this.budgetBC.findById(idBudget);
            }
        } catch (NumberFormatException e) {
            getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, true);
        }
        this.contentPane.add(BorderLayout.NORTH, new JLabel(this.i18n.tr("Details of Budget")));
        JPanel panel = new JPanel(new GridBagLayout());
        GridBagConstraints constraints = new GridBagConstraints();

        JLabel labelLabel = new JLabel(this.i18n.tr("Budget's label"));
        constraints.gridx = 0;
        constraints.gridy = 0;
        panel.add(labelLabel, constraints);
        final JTextField budgetLabel = new JTextField(String.valueOf(budgetVO.getLibelle()));
        budgetLabel.setEditable(false);
        constraints.gridx = 1;
        constraints.gridy = 0;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(budgetLabel, constraints);

        JLabel labelName = new JLabel(this.i18n.tr("Budget's account name"));
        constraints.gridx = 0;
        constraints.gridy = 1;
        panel.add(labelName, constraints);
        final JTextField budgetAccountName = new JTextField(budgetVO.getCompte().getLibelle(), 20);
        budgetAccountName.setEditable(false);
        constraints.gridx = 1;
        constraints.gridy = 1;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(budgetAccountName, constraints);

        JLabel labelBeginDate = new JLabel(this.i18n.tr("Budget's begin date"));
        constraints.gridx = 0;
        constraints.gridy = 2;
        panel.add(labelBeginDate, constraints);
        final JTextField budgetBeginDate = new JTextField(UtilChaine.date2String(budgetVO.getDateDebut()));
        constraints.gridx = 1;
        constraints.gridy = 2;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(budgetBeginDate, constraints);

        JLabel labelEndDate = new JLabel(this.i18n.tr("Budget's end date"));
        constraints.gridx = 0;
        constraints.gridy = 3;
        panel.add(labelEndDate, constraints);
        final JTextField budgetEndDate = new JTextField(UtilChaine.date2String(budgetVO.getDateFin()));
        constraints.gridx = 1;
        constraints.gridy = 3;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(budgetEndDate, constraints);

        JButton btnModifier = new JButton(this.i18n.tr("Modify"));
        btnModifier.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailBudget.this.baseVue.setAction(ConstantesValeurs.ACTION_EDITER_BUDGET);
                getSession().setAttribute(ConstantesValeurs.PARAM_BUDGET_LABEL, budgetLabel.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_BUDGET_ACCOUNT_NAME, budgetAccountName.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_BUDGET_BEGIN_DATE, budgetBeginDate.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_BUDGET_END_DATE, budgetEndDate.getText());
                VueDetailBudget.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 0;
        constraints.gridy = 4;
        panel.add(btnModifier, constraints);

        JButton btnCancel = new JButton(this.i18n.tr("Cancel"));
        btnCancel.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailBudget.this.baseVue.setAction(ConstantesValeurs.ACTION_LISTER_BUDGETS);
                VueDetailBudget.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 1;
        constraints.gridy = 4;
        panel.add(btnCancel, constraints);

        this.contentPane.add(BorderLayout.CENTER, panel);

        return this.contentPane;
    }

    /**
     * @return the budgetBC
     */
    public final IBudgetBC getBudgetBC() {
        return this.budgetBC;
    }

    /**
     * @param pBudgetBC
     *            the budgetBC to set
     */
    public final void setBudgetBC(IBudgetBC pBudgetBC) {
        this.budgetBC = pBudgetBC;
    }
}
