/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de categories bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.detail;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Iterator;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.table.DefaultTableModel;

import net.simcafamily.paksou.businessComponent.ICategorieBC;
import net.simcafamily.paksou.businessComponent.IMotCleBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.presentation.core.AbstractVue;
import net.simcafamily.paksou.presentation.panel.BoutonCellEditor;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.MotCleVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueDetailCategorie extends AbstractVue {

    private static final Log LOGGER = LogFactory.getLog(VueDetailCategorie.class);

    protected JPanel contentPane = new JPanel(new BorderLayout());

    private ICategorieBC categorieBC;

    private IMotCleBC motCleBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueDetailCategorie.LOGGER.isDebugEnabled()) {
            VueDetailCategorie.LOGGER.debug("debut methode 'affiche()'");
        }
        CategorieVO categorieVO = null;
        try {
            String idCategorie = getSession().getStringAttribute(ConstantesValeurs.ID_CATEGORIE);
            if ((idCategorie == null) || (idCategorie.length() <= 0)) {
                getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, Boolean.TRUE);
            } else {
                categorieVO = this.categorieBC.rechercherCategorieParId(idCategorie);
                getSession().setAttribute(ConstantesValeurs.PARAM_CATEGORIE, categorieVO);
            }
        } catch (NumberFormatException e) {
            getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, true);
        }

        this.contentPane.add(BorderLayout.NORTH, new JLabel(this.i18n.tr("Details of Categorie")));
        JPanel panel = new JPanel(new GridBagLayout());
        GridBagConstraints constraints = new GridBagConstraints();

        JLabel labelLabel = new JLabel(this.i18n.tr("Categorie's label"));
        constraints.gridx = 0;
        constraints.gridy = 0;
        panel.add(labelLabel, constraints);
        final JTextField categorieLabel = new JTextField(String.valueOf(categorieVO.getLibelle()), 20);
        constraints.gridx = 1;
        constraints.gridy = 0;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(categorieLabel, constraints);

        JLabel labelGroupName = new JLabel(this.i18n.tr("Categorie's group label"));
        constraints.gridx = 0;
        constraints.gridy = 1;
        panel.add(labelGroupName, constraints);
        final JTextField categorieGroupLabel = new JTextField(categorieVO.getLibGroupecategorie(), 20);
        constraints.gridx = 1;
        constraints.gridy = 1;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(categorieGroupLabel, constraints);

        JLabel labelKeywords = new JLabel(this.i18n.tr("Categorie's keywords"));
        constraints.gridx = 0;
        constraints.gridy = 3;
        panel.add(labelKeywords, constraints);
        final JTable tableKeyWords = new JTable();
        ((DefaultTableModel) tableKeyWords.getModel()).addColumn(this.i18n.tr("label"));
        ((DefaultTableModel) tableKeyWords.getModel()).addColumn(this.i18n.tr("auto creation"));
        // ajout de la colonne edition
        ((DefaultTableModel) tableKeyWords.getModel()).addColumn(this.i18n.tr("Edit"));
        int idxEdit = ((DefaultTableModel) tableKeyWords.getModel()).getColumnCount() - 1;

        // ajout de la colonne suppression
        ((DefaultTableModel) tableKeyWords.getModel()).addColumn(this.i18n.tr("Delete"));
        int idxDelete = ((DefaultTableModel) tableKeyWords.getModel()).getColumnCount() - 1;

        // ajout des cellrender pour les colonnes edition et suppression
        BoutonCellEditor btnEditor = new BoutonCellEditor(this.i18n.tr("Edit"), new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la banque selectionnee.
                int selectedRow = tableKeyWords.getSelectedRow();
                getSession().setAttribute(ConstantesValeurs.ID_MOT_CLE,
                        String.valueOf(tableKeyWords.getModel().getValueAt(selectedRow, 0)));

                // changement d'action
                VueDetailCategorie.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_MOT_CLE);
                VueDetailCategorie.this.baseVue.getSynchro().set();
            }
        });
        tableKeyWords.getColumnModel().getColumn(idxEdit).setCellRenderer(btnEditor);
        tableKeyWords.getColumnModel().getColumn(idxEdit).setCellEditor(btnEditor);
        BoutonCellEditor btnDelete = new BoutonCellEditor(this.i18n.tr("Delete"), new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la ligne selectionnee.
                int selectedRow = tableKeyWords.getSelectedRow();
                final int confirm = JOptionPane.showConfirmDialog(VueDetailCategorie.this.baseVue,
                        VueDetailCategorie.this.i18n.tr("Do you want to delete this bank ?"), "Paksou",
                        JOptionPane.YES_NO_OPTION);

                if (confirm == JOptionPane.YES_OPTION) {
                    // suppression de la banque correspondante a la ligne selectionnee.
                    VueDetailCategorie.this.motCleBC.supprimerParLibelle(String.valueOf(tableKeyWords.getModel()
                            .getValueAt(selectedRow, 0)));
                    ((DefaultTableModel) tableKeyWords.getModel()).removeRow(tableKeyWords.getEditingRow());
                }
            }
        });
        tableKeyWords.getColumnModel().getColumn(idxDelete).setCellRenderer(btnDelete);
        tableKeyWords.getColumnModel().getColumn(idxDelete).setCellEditor(btnDelete);

        Iterator<MotCleVO> iterMotCle = categorieVO.getLstMotsCles().iterator();
        while (iterMotCle.hasNext()) {
            MotCleVO motCleVO = iterMotCle.next();
            ((DefaultTableModel) tableKeyWords.getModel()).addRow(new String[] {
                    motCleVO.getLibelle(), String.valueOf(motCleVO.getCreationAuto())
            });
        }

        constraints.gridx = 1;
        constraints.gridy = 3;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(tableKeyWords, constraints);

        JButton btnModifier = new JButton(this.i18n.tr("Modify"));
        btnModifier.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailCategorie.this.baseVue.setAction(ConstantesValeurs.ACTION_EDITER_CATEGORIE);
                getSession().setAttribute(ConstantesValeurs.PARAM_CATEGORIE_LIBELLE, categorieLabel.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_CATEGORIE_GROUPE_LIBELLE,
                        categorieGroupLabel.getText());
                VueDetailCategorie.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 0;
        constraints.gridy = 2;
        panel.add(btnModifier, constraints);

        JButton btnCancel = new JButton(this.i18n.tr("Cancel"));
        btnCancel.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailCategorie.this.baseVue.setAction(ConstantesValeurs.ACTION_LISTER_CATEGORIES);
                VueDetailCategorie.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 1;
        constraints.gridy = 4;
        panel.add(btnCancel, constraints);

        this.contentPane.add(BorderLayout.CENTER, panel);

        return this.contentPane;
    }

    /**
     * @return the categorieBC
     */
    public final ICategorieBC getCategorieBC() {
        return this.categorieBC;
    }

    /**
     * @param pCategorieBC
     *            the categorieBC to set
     */
    public final void setCategorieBC(ICategorieBC pCategorieBC) {
        this.categorieBC = pCategorieBC;
    }

    /**
     * @return the motCleBC
     */
    public final IMotCleBC getMotCleBC() {
        return this.motCleBC;
    }

    /**
     * @param pMotCleBC
     *            the motCleBC to set
     */
    public final void setMotCleBC(IMotCleBC pMotCleBC) {
        this.motCleBC = pMotCleBC;
    }
}
