/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.detail;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Iterator;
import java.util.List;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.simcafamily.paksou.businessComponent.IBanqueBC;
import net.simcafamily.paksou.businessComponent.ICompteBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.presentation.core.AbstractVue;
import net.simcafamily.paksou.util.UtilChaine;
import net.simcafamily.paksou.valueObject.BanqueVO;
import net.simcafamily.paksou.valueObject.CompteVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueDetailCompte extends AbstractVue {

    private static final Log LOGGER = LogFactory.getLog(VueDetailCompte.class);

    protected JPanel contentPane = new JPanel(new BorderLayout());

    private ICompteBC compteBC;

    private IBanqueBC banqueBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueDetailCompte.LOGGER.isDebugEnabled()) {
            VueDetailCompte.LOGGER.debug("debut methode 'affiche()'");
        }
        CompteVO compteVO = null;
        try {
            String idCompte = getSession().getStringAttribute(ConstantesValeurs.ID_COMPTE);
            if ((idCompte == null) || (idCompte.length() <= 0)) {
                getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, Boolean.TRUE);
            } else {
                compteVO = this.compteBC.findById(idCompte);
                getSession().setAttribute(ConstantesValeurs.PARAM_COMPTE, compteVO);
            }
        } catch (NumberFormatException e) {
            getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, true);
        }

        this.contentPane.add(BorderLayout.NORTH, new JLabel(this.i18n.tr("Details of Account")));
        JPanel panel = new JPanel(new GridBagLayout());
        GridBagConstraints constraints = new GridBagConstraints();

        JLabel labelNumber = new JLabel(this.i18n.tr("Account's number"));
        constraints.gridx = 0;
        constraints.gridy = 0;
        panel.add(labelNumber, constraints);
        final JTextField accountNumber = new JTextField(String.valueOf(compteVO.getNumero()), 20);
        constraints.gridx = 1;
        constraints.gridy = 0;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(accountNumber, constraints);

        JLabel labelName = new JLabel(this.i18n.tr("Account's label"));
        constraints.gridx = 0;
        constraints.gridy = 1;
        panel.add(labelName, constraints);
        final JTextField accountLabel = new JTextField(compteVO.getLibelle(), 20);
        constraints.gridx = 1;
        constraints.gridy = 1;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(accountLabel, constraints);

        JLabel labelBankName = new JLabel(this.i18n.tr("Account's bank name"));
        constraints.gridx = 0;
        constraints.gridy = 2;
        panel.add(labelBankName, constraints);
        final JTextField idBank = new JTextField();
        idBank.setVisible(false);
        final JComboBox accountBank = new JComboBox();
        accountBank.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                idBank.setText(String.valueOf(accountBank.getSelectedItem()));
            }
        });
        List<BanqueVO> lstBanques = this.banqueBC.retrieveList();
        Iterator<BanqueVO> iterBank = lstBanques.iterator();
        while (iterBank.hasNext()) {
            final BanqueVO banqueVO = iterBank.next();
            accountBank.addItem(banqueVO.getNom());
            if (compteVO.getBanque().getNom().equals(banqueVO.getNom())) {
                accountBank.setSelectedItem(banqueVO.getNom());
            }
        }
        constraints.gridx = 1;
        constraints.gridy = 2;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(accountBank, constraints);

        JLabel labelLastImportDate = new JLabel(this.i18n.tr("Account's last import date"));
        constraints.gridx = 0;
        constraints.gridy = 3;
        panel.add(labelLastImportDate, constraints);
        String date = "";
        if (compteVO.getDateDernierImport() != null) {
            date = UtilChaine.date2String(compteVO.getDateDernierImport());
        }
        final JTextField accountLastImportDate = new JTextField(date, 20);
        accountLastImportDate.setEditable(false);
        constraints.gridx = 1;
        constraints.gridy = 3;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(accountLastImportDate, constraints);

        JButton btnModifier = new JButton(this.i18n.tr("Modify"));
        btnModifier.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailCompte.this.baseVue.setAction(ConstantesValeurs.ACTION_EDITER_COMPTE);
                getSession().setAttribute(ConstantesValeurs.PARAM_COMPTE_NUMERO, accountNumber.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_COMPTE_LIBELLE, accountLabel.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_COMPTE_NOM_BANQUE, idBank.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_COMPTE_DATE_DERNIER_IMPORT,
                        accountLastImportDate.getText());
                VueDetailCompte.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 0;
        constraints.gridy = 4;
        panel.add(btnModifier, constraints);

        JButton btnCancel = new JButton(this.i18n.tr("Cancel"));
        btnCancel.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailCompte.this.baseVue.setAction(ConstantesValeurs.ACTION_LISTER_COMPTES);
                VueDetailCompte.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 1;
        constraints.gridy = 4;
        panel.add(btnCancel, constraints);

        this.contentPane.add(BorderLayout.CENTER, panel);

        return this.contentPane;
    }

    /**
     * @return the compteBC
     */
    public final ICompteBC getCompteBC() {
        return this.compteBC;
    }

    /**
     * @param pCompteBC
     *            the compteBC to set
     */
    public final void setCompteBC(ICompteBC pCompteBC) {
        this.compteBC = pCompteBC;
    }

    /**
     * @return the banqueBC
     */
    public final IBanqueBC getBanqueBC() {
        return this.banqueBC;
    }

    /**
     * @param pBanqueBC
     *            the banqueBC to set
     */
    public final void setBanqueBC(IBanqueBC pBanqueBC) {
        this.banqueBC = pBanqueBC;
    }
}
