/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.detail;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.simcafamily.paksou.businessComponent.IGroupeBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.presentation.core.AbstractVue;
import net.simcafamily.paksou.valueObject.GroupeVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueDetailGroupe extends AbstractVue {

    private static final Log LOGGER = LogFactory.getLog(VueDetailGroupe.class);

    protected JPanel contentPane = new JPanel(new BorderLayout());

    private IGroupeBC groupeBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueDetailGroupe.LOGGER.isDebugEnabled()) {
            VueDetailGroupe.LOGGER.debug("debut methode 'affiche()'");
        }
        GroupeVO groupeVO = null;
        try {
            String idGroupe = getSession().getStringAttribute(ConstantesValeurs.ID_GROUPE);
            if ((idGroupe == null) || (idGroupe.length() <= 0)) {
                getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, Boolean.TRUE);
            } else {
                groupeVO = this.groupeBC.findById(idGroupe);
                getSession().setAttribute(ConstantesValeurs.PARAM_GROUPE, groupeVO);
            }
        } catch (NumberFormatException e) {
            getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, true);
        }

        this.contentPane.add(BorderLayout.NORTH, new JLabel(this.i18n.tr("Details of Group")));
        JPanel panel = new JPanel(new GridBagLayout());
        GridBagConstraints constraints = new GridBagConstraints();

        JLabel labelLabel = new JLabel(this.i18n.tr("Group's label"));
        constraints.gridx = 0;
        constraints.gridy = 0;
        panel.add(labelLabel, constraints);
        final JTextField groupLabel = new JTextField(groupeVO.getLibelle(), 20);
        constraints.gridx = 1;
        constraints.gridy = 0;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(groupLabel, constraints);

        JLabel labelNoRefInt = new JLabel(this.i18n.tr("Group's id"));
        constraints.gridx = 0;
        constraints.gridy = 1;
        panel.add(labelNoRefInt, constraints);
        final JTextField groupNoRefInt = new JTextField(String.valueOf(groupeVO.getNoRefInt()), 20);
        constraints.gridx = 1;
        constraints.gridy = 1;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(groupNoRefInt, constraints);

        JButton btnModifier = new JButton(this.i18n.tr("Modify"));
        btnModifier.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailGroupe.this.baseVue.setAction(ConstantesValeurs.ACTION_EDITER_GROUPE);
                getSession().setAttribute(ConstantesValeurs.PARAM_GROUPE_LIBELLE, groupLabel.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_GROUPE_NOREFINT, groupNoRefInt.getText());
                VueDetailGroupe.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 0;
        constraints.gridy = 4;
        panel.add(btnModifier, constraints);

        JButton btnCancel = new JButton(this.i18n.tr("Cancel"));
        btnCancel.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailGroupe.this.baseVue.setAction(ConstantesValeurs.ACTION_LISTER_GROUPES);
                VueDetailGroupe.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 1;
        constraints.gridy = 4;
        panel.add(btnCancel, constraints);

        this.contentPane.add(BorderLayout.CENTER, panel);

        return this.contentPane;
    }

    /**
     * @return the groupeBC
     */
    public final IGroupeBC getGroupeBC() {
        return this.groupeBC;
    }

    /**
     * @param pGroupeBC
     *            the groupeBC to set
     */
    public final void setGroupeBC(IGroupeBC pGroupeBC) {
        this.groupeBC = pGroupeBC;
    }
}
