/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.detail;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.simcafamily.paksou.businessComponent.IMotCleBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.presentation.core.AbstractVue;
import net.simcafamily.paksou.valueObject.MotCleVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueDetailMotCle extends AbstractVue {

    private static final Log LOGGER = LogFactory.getLog(VueDetailMotCle.class);

    protected JPanel contentPane = new JPanel(new BorderLayout());

    private IMotCleBC motCleBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueDetailMotCle.LOGGER.isDebugEnabled()) {
            VueDetailMotCle.LOGGER.debug("debut methode 'affiche()'");
        }
        MotCleVO motCleVO = null;
        try {
            String idMotCle = getSession().getStringAttribute(ConstantesValeurs.ID_MOT_CLE);
            if ((idMotCle == null) || (idMotCle.length() <= 0)) {
                getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, Boolean.TRUE);
            } else {
                motCleVO = this.motCleBC.recupererMotCle(idMotCle);
                getSession().setAttribute(ConstantesValeurs.PARAM_GROUPE, motCleVO);
            }
        } catch (NumberFormatException e) {
            getSession().setAttribute(ConstantesValeurs.PARAM_CREATION, true);
        }

        this.contentPane.add(BorderLayout.NORTH, new JLabel(this.i18n.tr("Details of Keyword")));
        JPanel panel = new JPanel(new GridBagLayout());
        GridBagConstraints constraints = new GridBagConstraints();

        JLabel labelLabel = new JLabel(this.i18n.tr("Keyword's label"));
        constraints.gridx = 0;
        constraints.gridy = 0;
        panel.add(labelLabel, constraints);
        final JTextField keywordLabel = new JTextField(motCleVO.getLibelle(), 20);
        constraints.gridx = 1;
        constraints.gridy = 0;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(keywordLabel, constraints);

        JLabel labelAutoCreation = new JLabel(this.i18n.tr("Keyword's auto creation"));
        constraints.gridx = 0;
        constraints.gridy = 1;
        panel.add(labelAutoCreation, constraints);
        final JTextField keywordAutoCreation = new JTextField(String.valueOf(motCleVO.getCreationAuto()), 20);
        constraints.gridx = 1;
        constraints.gridy = 1;
        constraints.insets = new Insets(5, 5, 0, 0);
        panel.add(keywordAutoCreation, constraints);

        JButton btnModifier = new JButton(this.i18n.tr("Modify"));
        btnModifier.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailMotCle.this.baseVue.setAction(ConstantesValeurs.ACTION_EDITER_MOT_CLE);
                getSession().setAttribute(ConstantesValeurs.PARAM_MOT_CLE_LIBELLE, keywordLabel.getText());
                getSession().setAttribute(ConstantesValeurs.PARAM_MOT_CLE_CREATION_AUTO, keywordAutoCreation.getText());
                VueDetailMotCle.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 0;
        constraints.gridy = 2;
        panel.add(btnModifier, constraints);

        JButton btnCancel = new JButton(this.i18n.tr("Cancel"));
        btnCancel.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueDetailMotCle.this.baseVue.setAction(ConstantesValeurs.ACTION_LISTER_MOT_CLE);
                VueDetailMotCle.this.baseVue.getSynchro().set();
            }
        });
        constraints.gridx = 1;
        constraints.gridy = 4;
        panel.add(btnCancel, constraints);

        this.contentPane.add(BorderLayout.CENTER, panel);

        return this.contentPane;
    }

    /**
     * @return the motCleBC
     */
    public final IMotCleBC getMotCleBC() {
        return this.motCleBC;
    }

    /**
     * @param pMotCleBC
     *            the motCleBC to set
     */
    public final void setMotCleBC(IMotCleBC pMotCleBC) {
        this.motCleBC = pMotCleBC;
    }
}
