/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.liste;

import java.awt.BorderLayout;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.table.DefaultTableModel;

import net.simcafamily.paksou.presentation.core.AbstractVue;
import net.simcafamily.paksou.presentation.panel.BoutonCellEditor;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.xnap.commons.i18n.I18n;
import org.xnap.commons.i18n.I18nFactory;

/**
 * @author bs238
 * 
 */
public abstract class AbstractVueListe extends AbstractVue {
    private static final Log LOGGER = LogFactory.getLog(AbstractVueListe.class);

    protected final I18n i18n = I18nFactory.getI18n(getClass());
    protected JPanel contentPane = new JPanel(new BorderLayout());
    protected final JTable jTable = new JTable();
    protected boolean init = false;

    protected void initPanel(final String pTitre) {
        if (AbstractVueListe.LOGGER.isDebugEnabled()) {
            AbstractVueListe.LOGGER.debug("initialisation de la fenetre");
        }
        if (!this.init) {
            this.contentPane.add(BorderLayout.NORTH, new JLabel(this.i18n.tr(pTitre)));
            this.contentPane.add(BorderLayout.CENTER, new JScrollPane(this.jTable));
            this.jTable.setModel(new DefaultTableModel());
            this.jTable.setRowSelectionAllowed(true);
            ((DefaultTableModel) this.jTable.getModel()).isCellEditable(0, 0);

            initTableModel();

            // ajout de la colonne edition
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Edit"));
            int idxEdit = ((DefaultTableModel) this.jTable.getModel()).getColumnCount() - 1;

            // ajout de la colonne suppression
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Delete"));
            int idxDelete = ((DefaultTableModel) this.jTable.getModel()).getColumnCount() - 1;

            // ajout des cellrender pour les colonnes edition et suppression
            BoutonCellEditor btnEditor = new BoutonCellEditor(this.i18n.tr("Edit"), getEditListener());
            this.jTable.getColumnModel().getColumn(idxEdit).setCellRenderer(btnEditor);
            this.jTable.getColumnModel().getColumn(idxEdit).setCellEditor(btnEditor);
            BoutonCellEditor btnDelete = new BoutonCellEditor(this.i18n.tr("Delete"), getDeleteListener());
            this.jTable.getColumnModel().getColumn(idxDelete).setCellRenderer(btnDelete);
            this.jTable.getColumnModel().getColumn(idxDelete).setCellEditor(btnDelete);

            JButton btnCreer = new JButton();
            btnCreer.setText(this.i18n.tr("Create"));
            btnCreer.addActionListener(getCreateListener());
            this.contentPane.add(BorderLayout.SOUTH, btnCreer);
            this.init = true;
        }
        int nbRow = this.jTable.getModel().getRowCount();
        for (int i = 0; i < nbRow; i++) {
            ((DefaultTableModel) this.jTable.getModel()).removeRow(0);
        }
    }

    /**
     * Cette methode permet d'initialiser le listener de creation d'une ligne du tableau
     * 
     * @return
     */
    protected abstract ActionListener getCreateListener();

    /**
     * Cette methode permet d'initialiser les colonnes du tableau
     */
    protected abstract void initTableModel();

    /**
     * Cette methode permet d'initialiser le listener de modification d'une ligne du tableau
     * 
     * @return
     */
    protected abstract ActionListener getEditListener();

    /**
     * Cette methode permet d'initialiser le listener de suppression d'une ligne du tableau
     * 
     * @return
     */
    protected abstract ActionListener getDeleteListener();

}
