/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.liste;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Iterator;
import java.util.List;

import javax.swing.JOptionPane;
import javax.swing.table.DefaultTableModel;

import net.simcafamily.paksou.businessComponent.IBanqueBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.valueObject.BanqueVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueListeBanques extends AbstractVueListe {

    private static final Log LOGGER = LogFactory.getLog(VueListeBanques.class);

    private IBanqueBC banqueBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueListeBanques.LOGGER.isDebugEnabled()) {
            VueListeBanques.LOGGER.debug("debut methode 'affiche()'");
        }
        initPanel("List of Banks");

        List<BanqueVO> lstBanques = this.banqueBC.retrieveList();
        if (lstBanques != null) {
            Iterator<BanqueVO> itBank = lstBanques.iterator();
            while (itBank.hasNext()) {
                BanqueVO banqueVO = itBank.next();
                ((DefaultTableModel) this.jTable.getModel()).addRow(new Object[] {
                        banqueVO.getNom(), banqueVO.getAdresse(), banqueVO.getContact(), banqueVO.getTelContact()
                });

            }
        }

        return this.contentPane;
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#initTableModel()
     */
    @Override
    protected void initTableModel() {
        if (!this.init) {
            ((DefaultTableModel) this.jTable.getModel()).setColumnCount(0);
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Name"));
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Address"));
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Contact"));
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Phone contact"));
        }
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getEditListener()
     */
    @Override
    protected ActionListener getEditListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la banque selectionnee.
                int selectedRow = VueListeBanques.this.jTable.getSelectedRow();
                getSession().setAttribute(ConstantesValeurs.ID_BANQUE,
                        String.valueOf(VueListeBanques.this.jTable.getModel().getValueAt(selectedRow, 0)));

                // changement d'action
                VueListeBanques.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_BANQUE);
                VueListeBanques.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getCreateListener()
     */
    @Override
    protected ActionListener getCreateListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueListeBanques.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_BANQUE);
                VueListeBanques.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getDeleteListener()
     */
    @Override
    protected ActionListener getDeleteListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la ligne selectionnee.
                int selectedRow = VueListeBanques.this.jTable.getSelectedRow();
                final int confirm = JOptionPane.showConfirmDialog(VueListeBanques.this.baseVue,
                        VueListeBanques.this.i18n.tr("Do you want to delete this bank ?"), "Paksou",
                        JOptionPane.YES_NO_OPTION);

                if (confirm == JOptionPane.YES_OPTION) {
                    // suppression de la banque correspondante a la ligne selectionnee.
                    VueListeBanques.this.banqueBC.deleteByName(String.valueOf(VueListeBanques.this.jTable.getModel()
                            .getValueAt(selectedRow, 0)));
                    ((DefaultTableModel) VueListeBanques.this.jTable.getModel()).removeRow(VueListeBanques.this.jTable
                            .getEditingRow());
                }
            }
        };
    }

    /**
     * @return the banqueBO
     */
    public final IBanqueBC getBanqueBC() {
        return this.banqueBC;
    }

    /**
     * @param pBanqueBO
     *            the banqueBO to set
     */
    public final void setBanqueBC(IBanqueBC pBanqueBC) {
        this.banqueBC = pBanqueBC;
    }

}
