/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.liste;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Iterator;
import java.util.List;

import javax.swing.JOptionPane;
import javax.swing.table.DefaultTableModel;

import net.simcafamily.paksou.businessComponent.ICategorieBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.valueObject.CategorieVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueListeCategories extends AbstractVueListe {

    private static final Log LOGGER = LogFactory.getLog(VueListeCategories.class);

    private ICategorieBC categorieBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueListeCategories.LOGGER.isDebugEnabled()) {
            VueListeCategories.LOGGER.debug("debut methode 'affiche()'");
        }
        initPanel("List of categories");

        List<CategorieVO> lstCategories = this.categorieBC.recupererListeCategorie();
        if (lstCategories != null) {
            Iterator<CategorieVO> itBank = lstCategories.iterator();
            while (itBank.hasNext()) {
                CategorieVO categ = itBank.next();
                ((DefaultTableModel) this.jTable.getModel()).addRow(new Object[] {
                        categ.getLibelle(), categ.getLibGroupecategorie(), categ.getNbMotsCles(),
                        String.valueOf(categ.getLstMotsCles())
                });
            }
        }

        return this.contentPane;
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#initTableModel()
     */
    @Override
    protected void initTableModel() {
        ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Label"));
        ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Group"));
        ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Number of keywords"));
        ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.trn("Keyword", "Keywords", 2));
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getEditListener()
     */
    @Override
    protected ActionListener getEditListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la banque selectionnee.
                int selectedRow = VueListeCategories.this.jTable.getSelectedRow();
                getSession().setAttribute(ConstantesValeurs.ID_CATEGORIE,
                        String.valueOf(VueListeCategories.this.jTable.getModel().getValueAt(selectedRow, 0)));

                // changement d'action
                VueListeCategories.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_CATEGORIE);
                VueListeCategories.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getCreateListener()
     */
    @Override
    protected ActionListener getCreateListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueListeCategories.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_CATEGORIE);
                VueListeCategories.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getDeleteListener()
     */
    @Override
    protected ActionListener getDeleteListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la ligne selectionnee.
                int selectedRow = VueListeCategories.this.jTable.getSelectedRow();
                final int confirm = JOptionPane.showConfirmDialog(VueListeCategories.this.baseVue,
                        VueListeCategories.this.i18n.tr("Do you want to delete this category ?"), "Paksou",
                        JOptionPane.YES_NO_OPTION);

                if (confirm == JOptionPane.YES_OPTION) {
                    // suppression de la banque correspondante a la ligne selectionnee.
                    VueListeCategories.this.categorieBC.deleteByName(String.valueOf(VueListeCategories.this.jTable
                            .getModel().getValueAt(selectedRow, 0)));
                    ((DefaultTableModel) VueListeCategories.this.jTable.getModel())
                            .removeRow(VueListeCategories.this.jTable.getEditingRow());
                }
            }
        };
    }

    /**
     * @return the categorieBC
     */
    public final ICategorieBC getCategorieBC() {
        return this.categorieBC;
    }

    /**
     * @param pCategBO
     *            the categorieBC to set
     */
    public final void setCategorieBC(ICategorieBC pCategBO) {
        this.categorieBC = pCategBO;
    }
}
