/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.liste;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Iterator;
import java.util.List;

import javax.swing.JOptionPane;
import javax.swing.table.DefaultTableModel;

import net.simcafamily.paksou.businessComponent.ICompteBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.valueObject.CompteVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueListeComptes extends AbstractVueListe {

    private static final Log LOGGER = LogFactory.getLog(VueListeComptes.class);

    private ICompteBC compteBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueListeComptes.LOGGER.isDebugEnabled()) {
            VueListeComptes.LOGGER.debug("debut methode 'affiche()'");
        }
        initPanel("List of Accounts");

        List<CompteVO> lstComptes = this.compteBC.retrieveList();
        if (lstComptes != null) {
            Iterator<CompteVO> itBank = lstComptes.iterator();
            while (itBank.hasNext()) {
                CompteVO compte = itBank.next();
                ((DefaultTableModel) this.jTable.getModel()).addRow(new Object[] {
                        compte.getNumero(), compte.getLibelle(), compte.getBanque().getNom(),
                        compte.getDateDernierImport()
                });
            }
        }

        return this.contentPane;
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#initTableModel()
     */
    @Override
    protected void initTableModel() {
        if (!this.init) {
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Number"));
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Label"));
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Bank name"));
            ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Last import date"));
        }
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getEditListener()
     */
    @Override
    protected ActionListener getEditListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la banque selectionnee.
                int selectedRow = VueListeComptes.this.jTable.getSelectedRow();
                getSession().setAttribute(ConstantesValeurs.ID_COMPTE,
                        String.valueOf(VueListeComptes.this.jTable.getModel().getValueAt(selectedRow, 0)));

                // changement d'action
                VueListeComptes.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_COMPTE);
                VueListeComptes.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getCreateListener()
     */
    @Override
    protected ActionListener getCreateListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueListeComptes.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_COMPTE);
                VueListeComptes.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getDeleteListener()
     */
    @Override
    protected ActionListener getDeleteListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la ligne selectionnee.
                int selectedRow = VueListeComptes.this.jTable.getSelectedRow();
                final int confirm = JOptionPane.showConfirmDialog(VueListeComptes.this.baseVue,
                        VueListeComptes.this.i18n.tr("Do you want to delete this account ?"), "Paksou",
                        JOptionPane.YES_NO_OPTION);

                if (confirm == JOptionPane.YES_OPTION) {
                    // suppression de la banque correspondante a la ligne selectionnee.
                    VueListeComptes.this.compteBC.deleteByNumber(String.valueOf(VueListeComptes.this.jTable.getModel()
                            .getValueAt(selectedRow, 0)));
                    ((DefaultTableModel) VueListeComptes.this.jTable.getModel()).removeRow(VueListeComptes.this.jTable
                            .getEditingRow());
                }
            }
        };
    }

    /**
     * @return the compteBO
     */
    public final ICompteBC getCompteBC() {
        return this.compteBC;
    }

    /**
     * @param pCompteBO
     *            the compteBO to set
     */
    public final void setCompteBC(ICompteBC pCompteBC) {
        this.compteBC = pCompteBC;
    }

}
