/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.liste;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Iterator;
import java.util.List;

import javax.swing.JOptionPane;
import javax.swing.table.DefaultTableModel;

import net.simcafamily.paksou.businessComponent.IGroupeBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.valueObject.GroupeVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueListeGroupes extends AbstractVueListe {

    private static final Log LOGGER = LogFactory.getLog(VueListeGroupes.class);

    private IGroupeBC groupeBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueListeGroupes.LOGGER.isDebugEnabled()) {
            VueListeGroupes.LOGGER.debug("debut methode 'affiche()'");
        }
        initPanel("List of groups");

        List<GroupeVO> lstGroupes = this.groupeBC.retrieveList();
        if (lstGroupes != null) {
            Iterator<GroupeVO> itBank = lstGroupes.iterator();
            while (itBank.hasNext()) {
                GroupeVO groupe = itBank.next();
                ((DefaultTableModel) this.jTable.getModel()).addRow(new Object[] {
                    groupe.getLibelle()
                });
            }
        }

        return this.contentPane;
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#initTableModel()
     */
    @Override
    protected void initTableModel() {
        ((DefaultTableModel) this.jTable.getModel()).setColumnCount(0);
        ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Label"));
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getEditListener()
     */
    @Override
    protected ActionListener getEditListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la banque selectionnee.
                int selectedRow = VueListeGroupes.this.jTable.getSelectedRow();
                getSession().setAttribute(ConstantesValeurs.ID_GROUPE,
                        String.valueOf(VueListeGroupes.this.jTable.getModel().getValueAt(selectedRow, 0)));

                // changement d'action
                VueListeGroupes.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_GROUPE);
                VueListeGroupes.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getCreateListener()
     */
    @Override
    protected ActionListener getCreateListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueListeGroupes.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_GROUPE);
                VueListeGroupes.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getDeleteListener()
     */
    @Override
    protected ActionListener getDeleteListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la ligne selectionnee.
                int selectedRow = VueListeGroupes.this.jTable.getSelectedRow();
                final int confirm = JOptionPane.showConfirmDialog(VueListeGroupes.this.baseVue,
                        VueListeGroupes.this.i18n.tr("Do you want to delete this group ?"), "Paksou",
                        JOptionPane.YES_NO_OPTION);

                if (confirm == JOptionPane.YES_OPTION) {
                    // suppression de la banque correspondante a la ligne selectionnee.
                    VueListeGroupes.this.groupeBC.deleteByName(String.valueOf(VueListeGroupes.this.jTable.getModel()
                            .getValueAt(selectedRow, 0)));
                    ((DefaultTableModel) VueListeGroupes.this.jTable.getModel()).removeRow(VueListeGroupes.this.jTable
                            .getEditingRow());
                }
            }
        };
    }

    /**
     * @return the groupeBC
     */
    public final IGroupeBC getGroupeBC() {
        return this.groupeBC;
    }

    /**
     * @param pGroupeBC
     *            the groupeBC to set
     */
    public final void setGroupeBC(IGroupeBC pGroupeBC) {
        this.groupeBC = pGroupeBC;
    }

}
