/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.presentation.vues.liste;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Iterator;
import java.util.List;

import javax.swing.JOptionPane;
import javax.swing.table.DefaultTableModel;

import net.simcafamily.paksou.businessComponent.IOperationBC;
import net.simcafamily.paksou.constantes.ConstantesValeurs;
import net.simcafamily.paksou.valueObject.OperationVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @version $Revision$
 * @author $Author$
 */
public class VueListeOperations extends AbstractVueListe {

    private static final Log LOGGER = LogFactory.getLog(VueListeOperations.class);

    private IOperationBC operationBC;

    /**
     * @see net.simcafamily.paksou.presentation.core.IVue#affiche()
     */
    @Override
    public Component affiche() {
        if (VueListeOperations.LOGGER.isDebugEnabled()) {
            VueListeOperations.LOGGER.debug("debut methode 'affiche()'");
        }
        initPanel("List of operations");

        List<OperationVO> lstOperations = this.operationBC.recupererListeOperations();
        if (lstOperations != null) {
            Iterator<OperationVO> itBank = lstOperations.iterator();
            while (itBank.hasNext()) {
                itBank.next();
                ((DefaultTableModel) this.jTable.getModel()).addRow(new Object[] {
                // categ.getLibelle(), categ.getLibGroupecategorie(), categ.getNbMotsCles(),
                        // String.valueOf(categ.getLstMotsCles())
                        });
            }
        }

        return this.contentPane;
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#initTableModel()
     */
    @Override
    protected void initTableModel() {
        ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Name"));
        ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Address"));
        ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Contact"));
        ((DefaultTableModel) this.jTable.getModel()).addColumn(this.i18n.tr("Phone contact"));
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getEditListener()
     */
    @Override
    protected ActionListener getEditListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la banque selectionnee.
                int selectedRow = VueListeOperations.this.jTable.getSelectedRow();
                getSession().setAttribute(ConstantesValeurs.ID_OPERATION,
                        String.valueOf(VueListeOperations.this.jTable.getModel().getValueAt(selectedRow, 0)));

                // changement d'action
                VueListeOperations.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_OPERATION);
                VueListeOperations.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getCreateListener()
     */
    @Override
    protected ActionListener getCreateListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                VueListeOperations.this.baseVue.setAction(ConstantesValeurs.ACTION_DETAILLER_OPERATION);
                VueListeOperations.this.baseVue.getSynchro().set();
            }
        };
    }

    /**
     * @see net.simcafamily.paksou.presentation.vues.liste.AbstractVueListe#getDeleteListener()
     */
    @Override
    protected ActionListener getDeleteListener() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent pE) {
                // recuperation de la ligne selectionnee.
                int selectedRow = VueListeOperations.this.jTable.getSelectedRow();
                final int confirm = JOptionPane.showConfirmDialog(VueListeOperations.this.baseVue,
                        VueListeOperations.this.i18n.tr("Do you want to delete this operation ?"), "Paksou",
                        JOptionPane.YES_NO_OPTION);

                if (confirm == JOptionPane.YES_OPTION) {
                    // suppression de la banque correspondante a la ligne selectionnee.
                    VueListeOperations.this.operationBC.deleteByName(Integer.parseInt(String
                            .valueOf(VueListeOperations.this.jTable.getModel().getValueAt(selectedRow, 0))));
                    ((DefaultTableModel) VueListeOperations.this.jTable.getModel())
                            .removeRow(VueListeOperations.this.jTable.getEditingRow());
                }
            }
        };
    }

    /**
     * @return the operationBC
     */
    public final IOperationBC getOperationBC() {
        return this.operationBC;
    }

    /**
     * @param pOperationBC
     *            the operationBC to set
     */
    public final void setOperationBC(IOperationBC pOperationBC) {
        this.operationBC = pOperationBC;
    }

}
