/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.util;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * The Class UtilFichier.
 * 
 * @author $Author: simon.guerard $
 * @version $Revision: 410 $
 */
public class UtilFichier {

    /** The LOGGER. */
    static Log log = LogFactory.getLog(UtilFichier.class);

    /**
     * Permet de deplacer un fichier d'une source vers une destination.
     * 
     * @param source
     *            the source
     * @param destination
     *            the destination
     * 
     * @throws IOException
     *             Signals that an I/O exception has occurred.
     */
    public static void deplacer(final File source, final File destination) throws IOException {
        if (!destination.exists()) {
            // On essaye avec renameTo
            final boolean result = source.renameTo(destination);
            if (!result) {
                // On essaye de copier
                UtilFichier.copier(source, destination);
                source.delete();

            }
        } else {
            throw new IOException("Le fichier destination n'exite pas");
        }
    }

    /**
     * Permet de deplacer un fichier d'une source vers une destination.
     * 
     * @param chemSource
     *            the chem source
     * @param nomSource
     *            the nom source
     * @param chemDest
     *            the chem dest
     * @param nomDest
     *            the nom dest
     * 
     * @throws IOException
     *             Signals that an I/O exception has occurred.
     */
    public static void deplacer(final String chemSource, final String nomSource, final String chemDest,
            final String nomDest) throws IOException {
        final File ficSource = new File(chemSource + nomSource);
        final File ficDest = new File(chemDest + nomDest);
        UtilFichier.deplacer(ficSource, ficDest);

    }

    /**
     * Permet de copier un fichier d'une source vers une destination.
     * 
     * @param source
     *            the source
     * @param destination
     *            the destination
     * 
     * @throws IOException
     *             Signals that an I/O exception has occurred.
     */
    public static void copier(final File source, final File destination) throws IOException {

        // Declaration des flux
        java.io.FileInputStream sourceFile = null;
        java.io.FileOutputStream destinationFile = null;

        // Creation du fichier :
        destination.createNewFile();

        // Ouverture des flux
        sourceFile = new java.io.FileInputStream(source);
        destinationFile = new java.io.FileOutputStream(destination);

        // Lecture par segment de 0.5Mo
        final byte buffer[] = new byte[512 * 1024];
        int nbLecture;

        while ((nbLecture = sourceFile.read(buffer)) != -1) {
            destinationFile.write(buffer, 0, nbLecture);
        }

        // Quoi qu'il arrive, on ferme les flux
        try {
            sourceFile.close();
        } catch (final Exception e) {
            UtilFichier.log.error(e, e);
        }
        try {
            destinationFile.close();
        } catch (final Exception e) {
            UtilFichier.log.error(e, e);
        }
    }

    /**
     * Permet de copier un fichier d'une source vers une destination.
     * 
     * @param chemSource
     *            the chem source
     * @param nomSource
     *            the nom source
     * @param chemDest
     *            the chem dest
     * @param nomDest
     *            the nom dest
     * 
     * @throws IOException
     *             Signals that an I/O exception has occurred.
     */
    public static void copier(final String chemSource, final String nomSource, final String chemDest,
            final String nomDest) throws IOException {
        final File ficSource = new File(chemSource + nomSource);
        final File ficDest = new File(chemDest + nomDest);
        UtilFichier.copier(ficSource, ficDest);

    }

    /**
     * Concatene un nom de repertoire et un nom de fichier dans une seule chaine. Rajoute si necessaire le separateur
     * '/' entre le repertoire et le fichier
     * 
     * @param directory
     *            the directory
     * @param fileName
     *            the file name
     * @param extension
     *            the extension
     * 
     * @return String
     * 
     * @throws IOException
     *             Signals that an I/O exception has occurred.
     */
    public static String formatteFileName(final String directory, final String fileName, final String extension)
            throws IOException {
        String nameOfFile = directory;

        if ((nameOfFile.length() > 0) && (nameOfFile.charAt(nameOfFile.length() - 1) != '/')) {
            nameOfFile += '/';
        }

        nameOfFile += fileName;
        if (extension.length() > 0) {
            nameOfFile += "." + extension;
        }

        return nameOfFile;
    }

    /**
     * Permet de renvoye le contenue du fichier.
     * 
     * @param fic
     *            the fic
     * 
     * @return the string
     * 
     * @throws IOException
     *             Signals that an I/O exception has occurred.
     */
    public static String litFichier(final File fic) throws IOException {
        final StringBuffer sb = new StringBuffer();
        FileReader fr;
        fr = new FileReader(fic);
        final BufferedReader br = new BufferedReader(fr);
        String stLu = br.readLine();
        while (stLu != null) {
            sb.append(stLu);
            stLu = br.readLine();
            if (stLu != null) {
                sb.append("\r\n");
            }
        }
        return (sb.toString());
    }

    /**
     * Connect andget file.
     * 
     * @param filename
     *            the filename
     * 
     * @return the input stream
     * 
     * @throws IOException
     *             Signals that an I/O exception has occurred.
     */
    synchronized public static InputStream connectAndgetFile(final String filename) throws IOException {
        UtilFichier.log.info("--> connectAndgetFile(" + filename + ")");
        InputStream isRet = null;
        URL myUrl;
        myUrl = new URL(filename);
        isRet = myUrl.openStream();
        UtilFichier.log.info("<-- connectAndgetFile() retourne:" + isRet);
        return isRet;
    }

    /**
     * Cette methode remplace dans un fichier toutes les occurences d'une chaine de caractere par une autre chaine de
     * caractere.
     * 
     * @param fichier
     *            fichier a modifier.
     * @param regExp
     *            chaine de caractere a remplacer.
     * @param chaine
     *            chaine de caractere remplacante.
     * 
     * @return fichier mis a jour.
     * 
     * @throws IOException
     *             exception de manipulation de fichier.
     */
    public static void replaceInFile(final File fichier, final String regExp, final String chaine) throws IOException {
        final File originFile = new File(fichier.getAbsolutePath() + ".tmp");
        UtilFichier.copier(fichier, originFile);
        final File destinationFile = fichier;
        String ligne;
        FileReader readerOriginFile;
        FileWriter writerDestinationFile;
        BufferedReader lecture;
        BufferedWriter ecriture;
        readerOriginFile = new FileReader(originFile);
        writerDestinationFile = new FileWriter(destinationFile);
        lecture = new BufferedReader(readerOriginFile);
        ecriture = new BufferedWriter(writerDestinationFile);

        while ((ligne = lecture.readLine()) != null) {
            final String newLine = ligne.replaceAll(regExp, chaine);
            ecriture.write(newLine);
            ecriture.newLine();
        }
        ecriture.flush();
        lecture.close();
        ecriture.close();

        if (!originFile.delete()) {
            throw new IOException("suppression du fichier " + originFile + " impossible.");
        }
    }

}
