/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.valueObject;

import java.util.Set;

/**
 * CategorieVO .
 * 
 * @author $Author: simon.guerard $
 * @version $Revision: 403 $
 */
public class CategorieVO implements java.io.Serializable, Comparable<CategorieVO> {

    /** serialVersionUID. */
    private static final long serialVersionUID = -8184874643685649770L;

    /** The groupecategorie. */
    private GroupeVO groupecategorie;

    /** The libelle. */
    private String libelle;

    /** The lst mots cles. */
    private Set<MotCleVO> lstMotsCles;

    /**
     * Instantiates a new categorie VO.
     */
    public CategorieVO() {
    }

    /**
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    public int compareTo(final CategorieVO pObj) {
        int result = 0;
        if (pObj != null && pObj instanceof CategorieVO) {
            result = this.libelle.compareTo((pObj).getLibelle());
        } else {
            result = 1;
        }
        return result;
    }

    /**
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(final Object pObj) {
        boolean result = false;
        if (pObj != null && pObj instanceof CategorieVO) {
            result = this.libelle.equals(((CategorieVO) pObj).getLibelle());
        } else {
            result = super.equals(pObj);
        }
        return result;
    }

    /**
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        final StringBuffer str = new StringBuffer("CategorieVO : ");
        str.append("\n\t libelle : ");
        str.append(this.libelle);
        str.append("\n\t groupecategorie : ");
        str.append((this.groupecategorie != null) ? this.groupecategorie.getLibelle() : "");
        str.append("\n\t lstMotsCles : ");
        str.append(this.lstMotsCles);
        return str.toString();
    }

    /**
     * Instantiates a new categorie VO.
     */
    public CategorieVO(final String pLibelle) {
        this.libelle = pLibelle;
    }

    /**
     * Instantiates a new categorie VO.
     * 
     * @param groupecategorie
     *            the groupecategorie
     * @param libelle
     *            the libelle
     */
    public CategorieVO(final GroupeVO groupecategorie, final String libelle) {
        this.groupecategorie = groupecategorie;
        this.libelle = libelle;
    }

    /**
     * Gets the groupecategorie.
     * 
     * @return the groupecategorie
     */
    public GroupeVO getGroupecategorie() {
        return this.groupecategorie;
    }

    /**
     * Sets the groupecategorie.
     * 
     * @param groupecategorie
     *            the new groupecategorie
     */
    public void setGroupecategorie(final GroupeVO groupecategorie) {
        this.groupecategorie = groupecategorie;
    }

    /**
     * Gets the groupecategorie.
     * 
     * @return the groupecategorie
     */
    public String getLibGroupecategorie() {
        if (this.groupecategorie != null) {
            return this.groupecategorie.getLibelle();
        }
        return null;
    }

    /**
     * Sets the groupecategorie.
     * 
     * @param groupecategorie
     *            the new groupecategorie
     */
    public void setLibGroupecategorie(final String pLibelle) {
        if (this.groupecategorie == null) {
            this.groupecategorie = new GroupeVO(pLibelle);
        } else {
            this.groupecategorie.setLibelle(pLibelle);
        }
    }

    /**
     * Gets the libelle.
     * 
     * @return the libelle
     */
    public String getLibelle() {
        return this.libelle;
    }

    /**
     * Sets the libelle.
     * 
     * @param libelle
     *            the new libelle
     */
    public void setLibelle(final String libelle) {
        this.libelle = libelle;
    }

    /**
     * Gets the lst mots cles.
     * 
     * @return the lstMotsCles
     */
    public Set<MotCleVO> getLstMotsCles() {
        return this.lstMotsCles;
    }

    /**
     * Sets the lst mots cles.
     * 
     * @param lstMotsCles
     *            the lstMotsCles to set
     */
    public void setLstMotsCles(final Set<MotCleVO> lstMotsCles) {
        this.lstMotsCles = lstMotsCles;
    }

    /**
     * Retourne le nombre de mots cles de la liste en attribut.
     * 
     * @return nombre de mots cles
     */
    public int getNbMotsCles() {
        int result = 0;
        if (this.lstMotsCles != null) {
            result = this.lstMotsCles.size();
        }
        return result;
    }

}
