/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.simcafamily.paksou.valueObject;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Map;

/**
 * SyntheseVO .
 * 
 * @author $Author$
 * @version $Revision$
 */
public class SyntheseVO implements java.io.Serializable {

    /** serialVersionUID. */
    private static final long serialVersionUID = 6066646076413364330L;

    private Calendar dateDebut;

    private Calendar dateFin;

    private CompteVO compte;

    private Map<String, Map<GroupeVO, Map<CategorieVO, Float>>> map;

    /**
     * Instantiates a new SyntheseVO.
     */
    public SyntheseVO() {
    }

    /**
     * @return the dateDebut
     */
    public final Calendar getDateDebut() {
        return this.dateDebut;
    }

    /**
     * @param pDateDebut
     *            the dateDebut to set
     */
    public final void setDateDebut(final Calendar pDateDebut) {
        this.dateDebut = pDateDebut;
    }

    /**
     * @return the dateDebut
     */
    public final String getDateDebutFormatee() {
        String date = "";
        if (this.dateDebut != null) {
            final SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
            date = sdf.format(this.dateDebut.getTime());
        }

        return date;
    }

    /**
     * @param pDateDebut
     *            the dateDebut to set
     */
    public final void setDateDebutFormatee(final String pDateDebut) {
        if (this.dateDebut == null) {
            this.dateDebut = Calendar.getInstance();
        }
        if (pDateDebut != null && pDateDebut.length() > 0) {
            final SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
            Date date = null;
            try {
                date = sdf.parse(pDateDebut);
            } catch (final ParseException e) {
                e.printStackTrace();
            }
            this.dateDebut.setTime(date);
        }
    }

    /**
     * @return the dateFin
     */
    public final Calendar getDateFin() {
        return this.dateFin;
    }

    /**
     * @param pDateFin
     *            the dateFin to set
     */
    public final void setDateFin(final Calendar pDateFin) {
        this.dateFin = pDateFin;
    }

    /**
     * @return the dateDebut
     */
    public final String getDateFinFormatee() {
        String date = "";
        if (this.dateFin != null) {
            final SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
            date = sdf.format(this.dateFin.getTime());
        }

        return date;
    }

    /**
     * @param pDateFin
     *            the dateFin to set
     */
    public final void setDateFinFormatee(final String pDateFin) {
        if (this.dateFin == null) {
            this.dateFin = Calendar.getInstance();
        }
        if (pDateFin != null && pDateFin.length() > 0) {
            final SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
            Date date = null;
            try {
                date = sdf.parse(pDateFin);
            } catch (final ParseException e) {
                e.printStackTrace();
            }
            this.dateFin.setTime(date);
        }
    }

    /**
     * @return the synthese
     */
    public final Map<String, Map<GroupeVO, Map<CategorieVO, Float>>> getMap() {
        return this.map;
    }

    /**
     * @param pSynthese
     *            the synthese to set
     */
    public final void setMap(final Map<String, Map<GroupeVO, Map<CategorieVO, Float>>> pSynthese) {
        this.map = pSynthese;
    }

    /**
     * @return the compte
     */
    public final CompteVO getCompte() {
        return this.compte;
    }

    /**
     * @param pCompte
     *            the compte to set
     */
    public final void setCompte(final CompteVO pCompte) {
        this.compte = pCompte;
    }

    /**
     * @return the compte
     */
    public final String getNumeroCompte() {
        String numero = "";
        if (this.compte != null) {
            numero = this.compte.getNumero();
        }
        return numero;
    }

    /**
     * @param pCompte
     *            the compte to set
     */
    public final void setNumeroCompte(final String pNumero) {
        if (this.compte == null) {
            this.compte = new CompteVO();
        }
        this.compte.setNumero(pNumero);
    }
}
