/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package test.net.simcafamily.paksou.businessComponent;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.List;

import junit.framework.Assert;
import net.simcafamily.paksou.businessComponent.ICategorieBC;
import net.simcafamily.paksou.businessObject.IBanqueBO;
import net.simcafamily.paksou.businessObject.ICategorieBO;
import net.simcafamily.paksou.businessObject.ICompteBO;
import net.simcafamily.paksou.businessObject.IMotCleBO;
import net.simcafamily.paksou.businessObject.IOperationBO;
import net.simcafamily.paksou.enumeration.SensOperation;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.BanqueVO;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.CompteVO;
import net.simcafamily.paksou.valueObject.MotCleVO;
import net.simcafamily.paksou.valueObject.OperationVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;
import org.junit.Test;

import test.net.simcafamily.paksou.test.BaseTest;

/**
 * @author $Author: simon@simcafamily.net $
 * @version $Revision: 406 $
 */
public class CategorieBCTest extends BaseTest {

    private static final Log LOGGER = LogFactory.getLog(CategorieBCTest.class);

    /** The Constant ID_OPE_1. */
    private static final Integer ID_OPE_1 = new Integer(9999);

    private static final Calendar dateOperation = new GregorianCalendar(1970, 01, 01);

    /** The Constant NUM_CPT_1. */
    private static final String NUM_CPT_1 = "123456789";

    private static final String LIB_CATEGORIE = "Test Voiture";

    private static final String LIB_BANQUE = "Banque de Test";

    private static final String LIB_OPE_1 = "PRLV   TEST_CREDIPAR PEUGEOT";

    private static final String LIB_MOT_CLE = "TEST_CREDIPAR";

    private static final Float MONTANT_1 = new Float(15.33);

    private CompteVO compte;

    private CategorieVO categ;

    private OperationVO operation;

    private MotCleVO motCle;

    /**
     * @see net.simcafamily.paksou.test.BaseTest#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        CategorieBCTest.LOGGER.info("mise a jour du schema de la base");
        final Configuration conf = HibernateUtil.getConfiguration();
        final SchemaUpdate schUpdate = new SchemaUpdate(conf);
        schUpdate.execute(true, true);
        final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");
        BanqueVO banque = accBqe.findByName(CategorieBCTest.LIB_BANQUE);
        if (banque == null) {
            banque = new BanqueVO();
            banque.setNom(CategorieBCTest.LIB_BANQUE);
            accBqe.persist(banque);
        }
        final ICompteBO accCpte = (ICompteBO) ContextFactory.getContext().getBean("compteBO");
        this.compte = accCpte.findById(CategorieBCTest.NUM_CPT_1);
        if (this.compte == null) {
            this.compte = new CompteVO();
            this.compte.setNumero(CategorieBCTest.NUM_CPT_1);
            this.compte.setBanque(banque);
            accCpte.persist(this.compte);
        }
        final ICategorieBO accCateg = (ICategorieBO) ContextFactory.getContext().getBean("categorieBO");
        this.categ = accCateg.findById(CategorieBCTest.LIB_CATEGORIE);
        if (this.categ == null) {
            this.categ = new CategorieVO();
            this.categ.setLibelle(CategorieBCTest.LIB_CATEGORIE);
            accCateg.persist(this.categ);
        }
        final IOperationBO operationBO = (IOperationBO) ContextFactory.getContext().getBean("operationBO");
        this.operation = operationBO.findById(CategorieBCTest.ID_OPE_1);
        if (this.operation == null) {
            this.operation = new OperationVO();
            this.operation.setIdentifiant(CategorieBCTest.ID_OPE_1);
            this.operation.setDate(CategorieBCTest.dateOperation.getTime());
            this.operation.setSensOperation(SensOperation.DEBIT);
            this.operation.setCompte(this.compte);
            this.operation.setLibelle(CategorieBCTest.LIB_OPE_1);
            this.operation.setMontant(CategorieBCTest.MONTANT_1);
            operationBO.persist(this.operation);
        }

        final IMotCleBO motCleBO = (IMotCleBO) ContextFactory.getContext().getBean("motCleBO");
        this.motCle = motCleBO.findById(CategorieBCTest.LIB_MOT_CLE);
        if (this.motCle == null) {
            this.motCle = new MotCleVO();
            this.motCle.setLibelle(CategorieBCTest.LIB_MOT_CLE);
            this.motCle.setCategorie(this.categ);
            this.motCle.setCreationAuto(Boolean.FALSE);
            motCleBO.persist(this.motCle);
        }
    }

    /**
     * @see net.simcafamily.paksou.test.BaseTest#tearDown()
     */
    @Override
    protected void tearDown() {
        final IOperationBO operationBO = (IOperationBO) ContextFactory.getContext().getBean("operationBO");
        this.operation = operationBO.findById(CategorieBCTest.ID_OPE_1);
        if (this.operation != null) {
            operationBO.delete(this.operation);
        }
        final ICompteBO accCpte = (ICompteBO) ContextFactory.getContext().getBean("compteBO");
        this.compte = accCpte.findById(CategorieBCTest.NUM_CPT_1);
        if (this.compte != null) {
            accCpte.delete(this.compte);
        }
        final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");
        final BanqueVO banque = accBqe.findByName(CategorieBCTest.LIB_BANQUE);
        if (banque != null) {
            accBqe.delete(banque);
        }
        final IMotCleBO motCleBO = (IMotCleBO) ContextFactory.getContext().getBean("motCleBO");
        final MotCleVO motCle = motCleBO.findById(CategorieBCTest.LIB_MOT_CLE);
        if (motCle != null) {
            motCleBO.delete(motCle);
        }
        final ICategorieBO accCateg = (ICategorieBO) ContextFactory.getContext().getBean("categorieBO");
        final CategorieVO categ = accCateg.findById(CategorieBCTest.LIB_CATEGORIE);
        if (categ != null) {
            accCateg.delete(categ);
        }
    }

    @Test
    public final void testAssocierCategorie() {
        final List<OperationVO> lstOperation = new ArrayList<OperationVO>();
        lstOperation.add(this.operation);
        final ICategorieBC categBC = (ICategorieBC) ContextFactory.getContext().getBean("categorieBC");
        categBC.associerCategorie(lstOperation);
        Assert.assertNotNull(this.operation.getCategorie());
    }

}
