/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package test.net.simcafamily.paksou.businessComponent;

import junit.framework.Assert;
import net.simcafamily.paksou.businessComponent.IMotCleBC;
import net.simcafamily.paksou.businessObject.ICategorieBO;
import net.simcafamily.paksou.businessObject.IMotCleBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.MotCleVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;
import org.junit.Before;
import org.junit.Test;

import test.net.simcafamily.paksou.test.BaseTest;

/**
 * @author $Author: simon@simcafamily.net $
 * @version $Revision: 406 $
 */
public class MotCleBCTest extends BaseTest {

    /** The LOGGER. */
    Log LOGGER = LogFactory.getLog(MotCleBCTest.class);

    private static final String LIBELLE_1 = "PRLV   TEST_CREDIPAR PEUGEOT";

    private static final String MOT_CLE_1 = "TEST_CREDIPAR";

    private static final String LIBELLE_2 = " Carte Kiosque Pizzas 17/06/07 ";

    private static final String MOT_CLE_2 = "KIOSQUE PIZZAS";

    private static final String LIB_CATEGORIE = "Test Salaire";

    private CategorieVO categ;

    /**
     * @throws java.lang.Exception
     */
    @Override
    @Before
    public void setUp() throws Exception {
        LOGGER.info("mise a jour du schema de la base");
        final Configuration conf = HibernateUtil.getConfiguration();
        final SchemaUpdate schUpdate = new SchemaUpdate(conf);
        schUpdate.execute(true, true);
        final ICategorieBO accCateg = (ICategorieBO) ContextFactory.getContext().getBean("categorieBO");
        this.categ = accCateg.findById(MotCleBCTest.LIB_CATEGORIE);
        if (this.categ == null) {
            this.categ = new CategorieVO();
            this.categ.setLibelle(MotCleBCTest.LIB_CATEGORIE);
            accCateg.persist(this.categ);
        }
    }

    /**
     * @see net.simcafamily.paksou.test.BaseTest#tearDown()
     */
    @Override
    protected void tearDown() {
        final IMotCleBO motCleBO = (IMotCleBO) ContextFactory.getContext().getBean("motCleBO");
        final MotCleVO motCle = motCleBO.findById(MotCleBCTest.MOT_CLE_1);
        if (motCle != null) {
            motCleBO.delete(motCle);
        }
        final ICategorieBO accCateg = (ICategorieBO) ContextFactory.getContext().getBean("categorieBO");
        this.categ = accCateg.findById(MotCleBCTest.LIB_CATEGORIE);
        if (this.categ != null) {
            accCateg.delete(this.categ);
        }
    }

    /**
     * Test method for
     * {@link net.simcafamily.paksou.businessComponent.IMotCleBC#identifierMotCle(java.lang.String, net.simcafamily.paksou.valueObject.CategorieVO)}
     * .
     */
    @Test
    public final void testIdentifierMotCle() {
        final IMotCleBC motCleBC = (IMotCleBC) ContextFactory.getContext().getBean("motCleBC");
        String mot = motCleBC.identifierMotCle(MotCleBCTest.LIBELLE_1);
        Assert.assertNotNull(mot);
        Assert.assertEquals(MotCleBCTest.MOT_CLE_1, mot);

        mot = motCleBC.identifierMotCle(MotCleBCTest.LIBELLE_2);
        Assert.assertNotNull(mot);
        Assert.assertEquals(MotCleBCTest.MOT_CLE_2, mot);
    }

    /**
     * Test method for
     * {@link net.simcafamily.paksou.businessComponent.IMotCleBC#ajouterMotCle(java.lang.String, java.lang.String)}.
     */
    @Test
    public final void testAjouterMotCle() {
        final IMotCleBC motCleBC = (IMotCleBC) ContextFactory.getContext().getBean("motCleBC");
        final MotCleVO motCle = motCleBC.ajouterMotCle(MotCleBCTest.MOT_CLE_1, MotCleBCTest.LIB_CATEGORIE);
        Assert.assertNotNull(motCle);
        Assert.assertEquals(MotCleBCTest.MOT_CLE_1, motCle.getLibelle());
        Assert.assertEquals(MotCleBCTest.LIB_CATEGORIE, motCle.getCategorie().getLibelle());
    }
}
