/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package test.net.simcafamily.paksou.businessComponent;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Map;
import java.util.TreeMap;

import net.simcafamily.paksou.businessComponent.IOperationBC;
import net.simcafamily.paksou.businessObject.IBanqueBO;
import net.simcafamily.paksou.businessObject.ICompteBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.BanqueVO;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.CompteVO;
import net.simcafamily.paksou.valueObject.GroupeVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;
import org.junit.Before;

import test.net.simcafamily.paksou.test.BaseTest;

/**
 * @author $Author$
 * @version $Revision$
 */
public class OperationBCTest extends BaseTest {

    /** The LOGGER. */
    Log LOGGER = LogFactory.getLog(OperationBCTest.class);

    private CompteVO compte;

    private final ICompteBO accCpte = (ICompteBO) ContextFactory.getContext().getBean("compteBO");

    private final IOperationBC operationBC = (IOperationBC) ContextFactory.getContext().getBean("operationBC");

    private static final String NUM_CPT_1 = "90774561000";

    private static final String LIB_BANQUE = "Banque de Test";

    /**
     * @throws java.lang.Exception
     */
    @Override
    @Before
    public void setUp() throws Exception {
        this.LOGGER.info("mise a jour du schema de la base");
        final Configuration conf = HibernateUtil.getConfiguration();
        final SchemaUpdate schUpdate = new SchemaUpdate(conf);
        schUpdate.execute(true, true);
        this.compte = this.accCpte.findById(OperationBCTest.NUM_CPT_1);
        if (this.compte == null) {
            final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");
            BanqueVO banque = accBqe.findByName(OperationBCTest.LIB_BANQUE);
            if (banque == null) {
                banque = new BanqueVO();
                banque.setNom(OperationBCTest.LIB_BANQUE);
                accBqe.persist(banque);
            }
            this.compte = new CompteVO();
            this.compte.setNumero(OperationBCTest.NUM_CPT_1);
            this.compte.setBanque(banque);
            this.accCpte.persist(this.compte);
        }
    }

    /**
     * @see net.simcafamily.paksou.test.BaseTest#tearDown()
     */
    @Override
    protected void tearDown() {
    }

    public void testRechercherListeOperationsParCategories() {
        final Map<String, Map<GroupeVO, Map<CategorieVO, Float>>> mapTotale = new TreeMap<String, Map<GroupeVO, Map<CategorieVO, Float>>>();
        final Calendar cldrDebut = Calendar.getInstance();
        cldrDebut.set(Calendar.DAY_OF_MONTH, 1);
        final Calendar cldrFin = Calendar.getInstance();
        for (int i = 0; i > -5; i--) {
            cldrDebut.add(Calendar.MONTH, i);
            cldrFin.add(Calendar.MONTH, i);
            cldrFin.set(Calendar.DAY_OF_MONTH, cldrFin.getMaximum(Calendar.DAY_OF_MONTH));
            final Map<GroupeVO, Map<CategorieVO, Float>> mapMensuelle = this.operationBC
                    .rechercherListeOperationsParCategories(cldrDebut, cldrFin, this.compte);
            final SimpleDateFormat sdf = new SimpleDateFormat("MM - MMMM");
            mapTotale.put(sdf.format(cldrDebut.getTime()), mapMensuelle);
        }
    }
}
