/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package test.net.simcafamily.paksou.businessObject;

import junit.framework.Assert;
import net.simcafamily.paksou.businessObject.IBanqueBO;
import net.simcafamily.paksou.businessObject.IBudgetBO;
import net.simcafamily.paksou.businessObject.ICompteBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.BanqueVO;
import net.simcafamily.paksou.valueObject.BudgetVO;
import net.simcafamily.paksou.valueObject.CompteVO;

import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;

import test.net.simcafamily.paksou.test.BaseTest;

/**
 * The Class BudgetBOTest.
 * 
 * @author $Author$
 * @version $Revision$
 */
public class BudgetBOTest extends BaseTest {

    /** The Constant LIB_BUDGET_1. */
    private static final String LIB_BUDGET_1 = "Budget de Test";

    private static final String LIB_BANQUE = "Banque de Test";

    private static final String NUM_CPT = "123456789";

    /** The acc. */
    private final IBudgetBO acc = (IBudgetBO) ContextFactory.getContext().getBean("budgetBO");

    private CompteVO compte;

    /**
     * Sets the up.
     * 
     * @throws Exception
     *             the exception
     * 
     * @see net.simcafamily.paksou.test.BaseTest#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        final Configuration conf = HibernateUtil.getConfiguration();
        final SchemaUpdate schUpdate = new SchemaUpdate(conf);
        schUpdate.execute(true, true);
        final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");
        BanqueVO banque = accBqe.findByName(BudgetBOTest.LIB_BANQUE);
        if (banque == null) {
            banque = new BanqueVO();
            banque.setNom(BudgetBOTest.LIB_BANQUE);
            accBqe.persist(banque);
        }
        final ICompteBO accCpte = (ICompteBO) ContextFactory.getContext().getBean("compteBO");
        this.compte = accCpte.findById(BudgetBOTest.NUM_CPT);
        if (this.compte == null) {
            this.compte = new CompteVO();
            this.compte.setNumero(BudgetBOTest.NUM_CPT);
            this.compte.setBanque(banque);
            accCpte.persist(this.compte);
        }
    }

    /**
     * @see net.simcafamily.paksou.test.BaseTest#tearDown()
     */
    @Override
    protected void tearDown() {
        final ICompteBO accCpte = (ICompteBO) ContextFactory.getContext().getBean("compteBO");
        this.compte = accCpte.findById(BudgetBOTest.NUM_CPT);
        if (this.compte != null) {
            accCpte.delete(this.compte);
        }
        final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");
        final BanqueVO banque = accBqe.findByName(BudgetBOTest.LIB_BANQUE);
        if (banque != null) {
            accBqe.delete(banque);
        }
    }

    /**
     * Test persist.
     */
    public void testBudgetBO() {
        BudgetVO budget = this.acc.findById(BudgetBOTest.LIB_BUDGET_1);
        if (budget == null) {
            budget = new BudgetVO();
            budget.setLibelle(BudgetBOTest.LIB_BUDGET_1);
            budget.setCompte(this.compte);
            this.acc.persist(budget);

            final BudgetVO cpte2 = this.acc.findById(BudgetBOTest.LIB_BUDGET_1);
            Assert.assertNotNull(cpte2);
            this.acc.delete(cpte2);

            final BudgetVO cpte3 = this.acc.findById(BudgetBOTest.LIB_BUDGET_1);
            Assert.assertNull(cpte3);
        } else {
            this.acc.delete(budget);
            final BudgetVO cpte2 = this.acc.findById(BudgetBOTest.LIB_BUDGET_1);
            Assert.assertNull(cpte2);
        }

    }
}
