/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package test.net.simcafamily.paksou.businessObject;

import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;

import junit.framework.Assert;
import net.simcafamily.paksou.businessObject.ICategorieBO;
import net.simcafamily.paksou.businessObject.IGroupeBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.GroupeVO;
import test.net.simcafamily.paksou.test.BaseTest;

/**
 * The Class CategorieBOTest.
 * 
 * @author $Author: simon@simcafamily.net $
 * @version $Revision: 406 $
 */
public class CategorieBOTest extends BaseTest {

    /** The Constant LIB_GROUPE. */
    private static final String LIB_GROUPE = "Test Loisir";

    private static final String LIB_CATEGORIE = "Test Salaire";

    private static final String LIB_CATEGORIE_2 = "Test Salaire 2";

    /** The acc. */
    private final ICategorieBO acc = (ICategorieBO) ContextFactory.getContext().getBean("categorieBO");

    private GroupeVO groupe;

    /**
     * Sets the up.
     * 
     * @throws Exception
     *             the exception
     * 
     * @see net.simcafamily.paksou.test.BaseTest#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        final Configuration conf = HibernateUtil.getConfiguration();
        final SchemaUpdate schUpdate = new SchemaUpdate(conf);
        schUpdate.execute(true, true);
        final IGroupeBO accGrp = (IGroupeBO) ContextFactory.getContext().getBean("groupeBO");
        this.groupe = accGrp.findById(CategorieBOTest.LIB_GROUPE);
        if (this.groupe == null) {
            this.groupe = new GroupeVO();
            this.groupe.setLibelle(CategorieBOTest.LIB_GROUPE);
            accGrp.persist(this.groupe);
        }

    }

    /**
     * @see net.simcafamily.paksou.test.BaseTest#tearDown()
     */
    @Override
    protected void tearDown() {
        CategorieVO categ = this.acc.findById(CategorieBOTest.LIB_CATEGORIE);
        if (categ != null) {
            this.acc.delete(categ);
        }
        categ = this.acc.findById(CategorieBOTest.LIB_CATEGORIE_2);
        if (categ != null) {
            this.acc.delete(categ);
        }
        final IGroupeBO accGrp = (IGroupeBO) ContextFactory.getContext().getBean("groupeBO");
        if (this.groupe != null) {
            accGrp.delete(this.groupe);
        }
    }

    /**
     * Test persist.
     */
    public void testPersist() {
        CategorieVO categ = new CategorieVO();
        categ.setLibelle(CategorieBOTest.LIB_CATEGORIE);
        this.acc.persist(categ);

        categ = this.acc.findById(CategorieBOTest.LIB_CATEGORIE);
        this.acc.delete(categ);
        final CategorieVO categResult = this.acc.findById(CategorieBOTest.LIB_CATEGORIE);
        Assert.assertNull(categResult);

        categ = new CategorieVO();
        categ.setLibelle(CategorieBOTest.LIB_CATEGORIE_2);
        categ.setGroupecategorie(this.groupe);
        this.acc.persist(categ);
    }

    public void testChercherCategorie() {
        final String libelle = "ECH PRET 70005687576 09/07";
        final String pattern = "(.* ECH PRET .*)|(ECH PRET)|(.* ECH PRET)|(ECH PRET .*)";
        if (!libelle.matches(pattern)) {
            Assert.fail();
        }
    }
}
