/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksous
 * 
 * Paksous is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksous is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksous; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package test.net.simcafamily.paksou.businessObject;

import junit.framework.Assert;
import net.simcafamily.paksou.businessObject.IBanqueBO;
import net.simcafamily.paksou.businessObject.ICompteBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.BanqueVO;
import net.simcafamily.paksou.valueObject.CompteVO;

import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;

import test.net.simcafamily.paksou.test.BaseTest;

/**
 * The Class ComptesBOTest.
 * 
 * @author $Author: simon@simcafamily.net $
 * @version $Revision: 406 $
 */
public class ComptesBOTest extends BaseTest {

    /** The Constant NUM_CPT_1. */
    private static final String NUM_CPT_1 = "123456789";

    private static final String LIB_BANQUE = "Banque de Test";

    /** The acc. */
    private final ICompteBO acc = (ICompteBO) ContextFactory.getContext().getBean("compteBO");

    private BanqueVO banque;

    /**
     * Sets the up.
     * 
     * @throws Exception
     *             the exception
     * 
     * @see net.simcafamily.paksou.test.BaseTest#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        final Configuration conf = HibernateUtil.getConfiguration();
        final SchemaUpdate schUpdate = new SchemaUpdate(conf);
        schUpdate.execute(true, true);
        final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");
        this.banque = accBqe.findByName(ComptesBOTest.LIB_BANQUE);
        if (this.banque == null) {
            this.banque = new BanqueVO();
            this.banque.setNom(ComptesBOTest.LIB_BANQUE);
            accBqe.persist(this.banque);
        }
    }

    /**
     * @see net.simcafamily.paksou.test.BaseTest#tearDown()
     */
    @Override
    protected void tearDown() {
        final CompteVO cpte = this.acc.findById(ComptesBOTest.NUM_CPT_1);
        if (cpte != null) {
            this.acc.delete(cpte);
        }
        final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");
        final BanqueVO banque = accBqe.findByName(ComptesBOTest.LIB_BANQUE);
        if (banque != null) {
            accBqe.delete(banque);
        }
    }

    /**
     * Test persist.
     */
    public void testCompteBO() {
        CompteVO cpte = this.acc.findById(ComptesBOTest.NUM_CPT_1);
        if (cpte == null) {
            cpte = new CompteVO();
            cpte.setNumero(ComptesBOTest.NUM_CPT_1);
            cpte.setBanque(this.banque);
            this.acc.persist(cpte);

            final CompteVO cpte2 = this.acc.findById(ComptesBOTest.NUM_CPT_1);
            Assert.assertNotNull(cpte2);
            this.acc.delete(cpte2);

            final CompteVO cpte3 = this.acc.findById(ComptesBOTest.NUM_CPT_1);
            Assert.assertNull(cpte3);
        } else {
            this.acc.delete(cpte);
            final CompteVO cpte2 = this.acc.findById(ComptesBOTest.NUM_CPT_1);
            Assert.assertNull(cpte2);
        }

    }
}
