/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package test.net.simcafamily.paksou.businessObject;

import junit.framework.Assert;
import net.simcafamily.paksou.businessObject.IBanqueBO;
import net.simcafamily.paksou.businessObject.IBudgetBO;
import net.simcafamily.paksou.businessObject.ICategorieBO;
import net.simcafamily.paksou.businessObject.ICompteBO;
import net.simcafamily.paksou.businessObject.ILigneBudgetBO;
import net.simcafamily.paksou.enumeration.SensOperation;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.BanqueVO;
import net.simcafamily.paksou.valueObject.BudgetVO;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.CompteVO;
import net.simcafamily.paksou.valueObject.LigneBudgetVO;

import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;

import test.net.simcafamily.paksou.test.BaseTest;

/**
 * The Class LigneBudgetBOTest.
 * 
 * @author $Author$
 * @version $Revision$
 */
public class LigneBudgetBOTest extends BaseTest {

    /** The Constant ID_OPE_1. */
    private static final Float MONTANT_1 = new Float(20.99);

    private static final Float MONTANT_2 = new Float(5.33);

    /** The Constant NUM_CPT. */
    private static final String LIB_BUDGET_1 = "Test budget 1";

    private static final String LIB_CATEGORIE = "Test Salaire";

    private static final String LIB_BANQUE = "Banque de Test";

    private static final String NUM_CPT = "123456789";

    /** The acc. */
    private final ILigneBudgetBO acc = (ILigneBudgetBO) ContextFactory.getContext().getBean("ligneBudgetBO");

    private BudgetVO budget;

    private CategorieVO categ;

    /**
     * Sets the up.
     * 
     * @throws Exception
     *             the exception
     * 
     * @see net.simcafamily.paksou.test.BaseTest#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        final Configuration conf = HibernateUtil.getConfiguration();
        final SchemaUpdate schUpdate = new SchemaUpdate(conf);
        schUpdate.execute(true, true);
        final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");
        BanqueVO banque = accBqe.findByName(LigneBudgetBOTest.LIB_BANQUE);
        if (banque == null) {
            banque = new BanqueVO();
            banque.setNom(LigneBudgetBOTest.LIB_BANQUE);
            accBqe.persist(banque);
        }
        final ICompteBO accCpte = (ICompteBO) ContextFactory.getContext().getBean("compteBO");
        CompteVO compte = accCpte.findById(LigneBudgetBOTest.NUM_CPT);
        if (compte == null) {
            compte = new CompteVO();
            compte.setNumero(LigneBudgetBOTest.NUM_CPT);
            compte.setBanque(banque);
            accCpte.persist(compte);
        }
        final IBudgetBO accBudget = (IBudgetBO) ContextFactory.getContext().getBean("budgetBO");
        this.budget = accBudget.findById(LigneBudgetBOTest.LIB_BUDGET_1);
        if (this.budget == null) {
            this.budget = new BudgetVO();
            this.budget.setLibelle(LigneBudgetBOTest.LIB_BUDGET_1);
            this.budget.setCompte(compte);
            accBudget.persist(this.budget);
        }
        final ICategorieBO accCateg = (ICategorieBO) ContextFactory.getContext().getBean("categorieBO");
        this.categ = accCateg.findById(LigneBudgetBOTest.LIB_CATEGORIE);
        if (this.categ == null) {
            this.categ = new CategorieVO();
            this.categ.setLibelle(LigneBudgetBOTest.LIB_CATEGORIE);
            accCateg.persist(this.categ);
        }
    }

    /**
     * @see net.simcafamily.paksou.test.BaseTest#tearDown()
     */
    @Override
    protected void tearDown() {
        final IBudgetBO accBudget = (IBudgetBO) ContextFactory.getContext().getBean("budgetBO");
        this.budget = accBudget.findById(LigneBudgetBOTest.LIB_BUDGET_1);
        if (this.budget != null) {
            accBudget.delete(this.budget);
        }
        final ICompteBO accCpte = (ICompteBO) ContextFactory.getContext().getBean("compteBO");
        final CompteVO compte = accCpte.findById(LigneBudgetBOTest.NUM_CPT);
        if (compte != null) {
            accCpte.delete(compte);
        }
        final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");
        final BanqueVO banque = accBqe.findByName(LigneBudgetBOTest.LIB_BANQUE);
        if (banque != null) {
            accBqe.delete(banque);
        }
        final ICategorieBO accCateg = (ICategorieBO) ContextFactory.getContext().getBean("categorieBO");
        this.categ = accCateg.findById(LigneBudgetBOTest.LIB_CATEGORIE);
        if (this.categ != null) {
            accCateg.delete(this.categ);
        }
    }

    /**
     * Test persist.
     */
    public void testLigneBudget() {
        LigneBudgetVO ligneBudget = new LigneBudgetVO();
        ligneBudget.setBudget(this.budget);
        ligneBudget.setCategorie(this.categ);
        ligneBudget.setMontant(LigneBudgetBOTest.MONTANT_1);
        ligneBudget.setSensOperation(SensOperation.DEBIT);
        this.acc.persist(ligneBudget);

        LigneBudgetVO ligneBudgetResult = this.acc.findByFunctionnalId(this.budget.getLibelle(), this.categ
                .getLibelle());
        Assert.assertNotNull(ligneBudgetResult);

        ligneBudget = this.acc.findByFunctionnalId(this.budget.getLibelle(), this.categ.getLibelle());
        if (ligneBudget != null) {
            this.acc.delete(ligneBudget);
        }
        ligneBudgetResult = this.acc.findByFunctionnalId(this.budget.getLibelle(), this.categ.getLibelle());
        Assert.assertNull(ligneBudgetResult);

        ligneBudget = new LigneBudgetVO();
        ligneBudget.setCategorie(this.categ);
        ligneBudget.setBudget(this.budget);
        ligneBudget.setMontant(LigneBudgetBOTest.MONTANT_2);
        ligneBudget.setSensOperation(SensOperation.DEBIT);
        this.acc.persist(ligneBudget);

        ligneBudget = this.acc.findByFunctionnalId(this.budget.getLibelle(), this.categ.getLibelle());
        if (ligneBudget != null) {
            this.acc.delete(ligneBudget);
        }
        ligneBudgetResult = this.acc.findByFunctionnalId(this.budget.getLibelle(), this.categ.getLibelle());
        Assert.assertNull(ligneBudgetResult);

    }

}
