/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package test.net.simcafamily.paksou.businessObject;

import junit.framework.Assert;
import net.simcafamily.paksou.businessObject.ICategorieBO;
import net.simcafamily.paksou.businessObject.IMotCleBO;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.MotCleVO;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;

import test.net.simcafamily.paksou.test.BaseTest;

/**
 * The Class MotCleBOTest.
 * 
 * @author $Author: simon@simcafamily.net $
 * @version $Revision: 406 $
 */
public class MotCleBOTest extends BaseTest {

    /** The LOGGER. */
    Log log = LogFactory.getLog(MotCleBOTest.class);

    private CategorieVO categ;

    private final IMotCleBO acc = (IMotCleBO) ContextFactory.getContext().getBean("motCleBO");

    private final ICategorieBO accCateg = (ICategorieBO) ContextFactory.getContext().getBean("categorieBO");

    private static final String LIB_CATEGORIE = "Test Salaire";

    private static final String LIBELLE = "TEST_PEUGEOT";

    /**
     * Sets the up.
     * 
     * @throws Exception
     *             the exception
     * 
     * @see net.simcafamily.paksou.test.BaseTest#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        final Configuration conf = HibernateUtil.getConfiguration();
        final SchemaUpdate schUpdate = new SchemaUpdate(conf);
        schUpdate.execute(true, true);

        this.categ = this.accCateg.findById(MotCleBOTest.LIB_CATEGORIE);
        if (this.categ == null) {
            this.categ = new CategorieVO();
            this.categ.setLibelle(MotCleBOTest.LIB_CATEGORIE);
            this.accCateg.persist(this.categ);
        }
    }

    /**
     * @see net.simcafamily.paksou.test.BaseTest#tearDown()
     */
    @Override
    protected void tearDown() {
        final MotCleVO motCle = this.acc.findById(MotCleBOTest.LIBELLE);
        if (motCle != null) {
            this.acc.delete(motCle);
        }
        this.categ = this.accCateg.findById(MotCleBOTest.LIB_CATEGORIE);
        if (this.categ != null) {
            this.accCateg.delete(this.categ);
        }
    }

    /**
     * Test persist.
     */
    public void testMotCleBO() {
        MotCleVO motCle = this.acc.findById(MotCleBOTest.LIBELLE);
        if (motCle == null) {
            motCle = new MotCleVO();
            motCle.setLibelle(MotCleBOTest.LIBELLE);
            motCle.setCategorie(this.categ);
            motCle.setCreationAuto(Boolean.TRUE);
            this.acc.persist(motCle);

            final MotCleVO cpte2 = this.acc.findById(MotCleBOTest.LIBELLE);
            Assert.assertNotNull(cpte2);
            this.acc.delete(cpte2);

            final MotCleVO cpte3 = this.acc.findById(MotCleBOTest.LIBELLE);
            Assert.assertNull(cpte3);
        } else {
            this.acc.delete(motCle);
            final MotCleVO cpte2 = this.acc.findById(MotCleBOTest.LIBELLE);
            Assert.assertNull(cpte2);
        }

    }

}
