/******************************************************************
 * Copyright (c) 2007 - 2007, Simon Guerard, All rights reserved.
 * 
 * Projet de gestion de comptes bancaires.
 * 
 * This File is part of Paksou
 * 
 * Paksou is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * Paksou is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with Paksou; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package test.net.simcafamily.paksou.businessObject;

import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.List;

import junit.framework.Assert;
import net.simcafamily.paksou.businessObject.IBanqueBO;
import net.simcafamily.paksou.businessObject.ICategorieBO;
import net.simcafamily.paksou.businessObject.ICompteBO;
import net.simcafamily.paksou.businessObject.IOperationBO;
import net.simcafamily.paksou.enumeration.SensOperation;
import net.simcafamily.paksou.hibernate.HibernateUtil;
import net.simcafamily.paksou.spring.ContextFactory;
import net.simcafamily.paksou.valueObject.BanqueVO;
import net.simcafamily.paksou.valueObject.CategorieVO;
import net.simcafamily.paksou.valueObject.CompteVO;
import net.simcafamily.paksou.valueObject.OperationVO;

import org.hibernate.cfg.Configuration;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;

import test.net.simcafamily.paksou.test.BaseTest;

/**
 * The Class OperationBOTest.
 * 
 * @author $Author: simon@simcafamily.net $
 * @version $Revision: 406 $
 */
public class OperationBOTest extends BaseTest {

    /** The Constant ID_OPE_1. */
    private static final Integer ID_OPE_1 = new Integer(9999);

    private static final Float MONTANT_1 = new Float(11.99);

    private static final Integer ID_OPE_2 = new Integer(8888);

    private static final Integer ID_OPE_3 = new Integer(8888888);

    private static final Calendar dateOperation = new GregorianCalendar(1970, 01, 01);

    /** The Constant NUM_CPT_1. */
    private static final String NUM_CPT_1 = "123456789";

    private static final String LIB_CATEGORIE = "Test Salaire";

    private static final String LIB_BANQUE = "Banque de Test";

    /** The acc. */
    private final IOperationBO acc = (IOperationBO) ContextFactory.getContext().getBean("operationBO");

    private final IBanqueBO accBqe = (IBanqueBO) ContextFactory.getContext().getBean("banqueBO");

    private final ICompteBO accCpte = (ICompteBO) ContextFactory.getContext().getBean("compteBO");

    private final ICategorieBO accCateg = (ICategorieBO) ContextFactory.getContext().getBean("categorieBO");

    private CompteVO compte;

    private CategorieVO categ;

    /**
     * Sets the up.
     * 
     * @throws Exception
     *             the exception
     * 
     * @see net.simcafamily.paksou.test.BaseTest#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        final Configuration conf = HibernateUtil.getConfiguration();
        final SchemaUpdate schUpdate = new SchemaUpdate(conf);
        schUpdate.execute(true, true);
        BanqueVO banque = this.accBqe.findByName(OperationBOTest.LIB_BANQUE);
        if (banque == null) {
            banque = new BanqueVO();
            banque.setNom(OperationBOTest.LIB_BANQUE);
            this.accBqe.persist(banque);
        }
        this.compte = this.accCpte.findById(OperationBOTest.NUM_CPT_1);
        if (this.compte == null) {
            this.compte = new CompteVO();
            this.compte.setNumero(OperationBOTest.NUM_CPT_1);
            this.compte.setBanque(banque);
            this.accCpte.persist(this.compte);
        }
        this.categ = this.accCateg.findById(OperationBOTest.LIB_CATEGORIE);
        if (this.categ == null) {
            this.categ = new CategorieVO();
            this.categ.setLibelle(OperationBOTest.LIB_CATEGORIE);
            this.accCateg.persist(this.categ);
        }
    }

    /**
     * @see net.simcafamily.paksou.test.BaseTest#tearDown()
     */
    @Override
    protected void tearDown() {
        OperationVO operation = this.acc.findById(OperationBOTest.ID_OPE_1);
        if (operation != null) {
            this.acc.delete(operation);
        }
        operation = this.acc.findById(OperationBOTest.ID_OPE_2);
        if (operation != null) {
            this.acc.delete(operation);
        }
        operation = this.acc.findById(OperationBOTest.ID_OPE_3);
        if (operation != null) {
            this.acc.delete(operation);
        }
        this.compte = this.accCpte.findById(OperationBOTest.NUM_CPT_1);
        if (this.compte != null) {
            this.accCpte.delete(this.compte);
        }
        final BanqueVO banque = this.accBqe.findByName(OperationBOTest.LIB_BANQUE);
        if (banque != null) {
            this.accBqe.delete(banque);
        }
        this.categ = this.accCateg.findById(OperationBOTest.LIB_CATEGORIE);
        if (this.categ != null) {
            this.accCateg.delete(this.categ);
        }
    }

    /**
     * Test persist.
     */
    public void testOperation() {
        OperationVO operation = this.acc.findById(OperationBOTest.ID_OPE_1);
        if (operation == null) {
            operation = new OperationVO();
            operation.setIdentifiant(OperationBOTest.ID_OPE_1);
            operation.setDate(OperationBOTest.dateOperation.getTime());
            operation.setSensOperation(SensOperation.DEBIT);
            operation.setCompte(this.compte);
            operation.setMontant(OperationBOTest.MONTANT_1);
            this.acc.persist(operation);

            OperationVO operationResult = this.acc.findById(OperationBOTest.ID_OPE_1);
            Assert.assertNotNull(operationResult);

            operation = this.acc.findById(OperationBOTest.ID_OPE_1);
            if (operation != null) {
                this.acc.delete(operation);
            }
            operationResult = this.acc.findById(OperationBOTest.ID_OPE_1);
            Assert.assertNull(operationResult);
        }
    }

    /**
     * Test persist.
     */
    public void testOperationWithCategorie() {
        OperationVO operation = new OperationVO();
        operation.setIdentifiant(OperationBOTest.ID_OPE_2);
        operation.setCategorie(this.categ);
        operation.setCompte(this.compte);
        operation.setMontant(OperationBOTest.MONTANT_1);
        operation.setDate(OperationBOTest.dateOperation.getTime());
        operation.setSensOperation(SensOperation.DEBIT);
        this.acc.persist(operation);

        OperationVO operationResult = this.acc.findById(OperationBOTest.ID_OPE_2);
        Assert.assertNotNull(operationResult);

        operation = this.acc.findById(OperationBOTest.ID_OPE_2);
        if (operation != null) {
            this.acc.delete(operation);
        }
        operationResult = this.acc.findById(OperationBOTest.ID_OPE_2);
        Assert.assertNull(operationResult);
    }

    public void testFindByCategorie() {
        OperationVO operation = new OperationVO();
        operation.setIdentifiant(OperationBOTest.ID_OPE_3);
        operation.setCategorie(this.categ);
        operation.setCompte(this.compte);
        operation.setMontant(OperationBOTest.MONTANT_1);
        operation.setDate(OperationBOTest.dateOperation.getTime());
        operation.setSensOperation(SensOperation.DEBIT);
        this.acc.persist(operation);

        OperationVO operationResult = this.acc.findById(OperationBOTest.ID_OPE_3);
        Assert.assertNotNull(operationResult);

        final CategorieVO categorie = new CategorieVO();
        categorie.setLibelle(OperationBOTest.LIB_CATEGORIE);
        List<OperationVO> lstOperations = this.acc.findByCategorieAndDate(categorie, "1969-12-1", "1970-7-7",
                this.compte);
        Assert.assertNotNull(lstOperations);
        Assert.assertEquals(1, lstOperations.size());
        lstOperations = this.acc.findByCategorieAndDate(categorie, "1970-2-2", "1970-7-7", this.compte);
        Assert.assertNotNull(lstOperations);
        Assert.assertEquals(0, lstOperations.size());

        operation = this.acc.findById(OperationBOTest.ID_OPE_3);
        if (operation != null) {
            this.acc.delete(operation);
        }
        operationResult = this.acc.findById(OperationBOTest.ID_OPE_3);
        Assert.assertNull(operationResult);
    }

    public void testFindByExample() {
        OperationVO operation = new OperationVO();
        operation.setIdentifiant(OperationBOTest.ID_OPE_3);
        operation.setCategorie(this.categ);
        operation.setCompte(this.compte);
        operation.setMontant(OperationBOTest.MONTANT_1);
        operation.setDate(OperationBOTest.dateOperation.getTime());
        operation.setSensOperation(SensOperation.DEBIT);
        this.acc.persist(operation);

        OperationVO operationResult = this.acc.findById(OperationBOTest.ID_OPE_3);
        Assert.assertNotNull(operationResult);

        OperationVO operationExample = new OperationVO();
        operationExample.setIdentifiant(OperationBOTest.ID_OPE_3);
        operationExample.setCategorie(this.categ);
        operationExample.setCompte(this.compte);
        operationExample.setMontant(OperationBOTest.MONTANT_1);
        operationExample.setDate(OperationBOTest.dateOperation.getTime());
        operationExample.setSensOperation(SensOperation.DEBIT);
        List<OperationVO> lstOperations = this.acc.findByExample(operationExample);
        Assert.assertNotNull(lstOperations);
        Assert.assertEquals(1, lstOperations.size());

        operationExample = new OperationVO();
        operationExample.setCompte(this.compte);
        lstOperations = this.acc.findByExample(operationExample);
        Assert.assertNotNull(lstOperations);
        Assert.assertEquals(1, lstOperations.size());

        operation = this.acc.findById(OperationBOTest.ID_OPE_3);
        if (operation != null) {
            this.acc.delete(operation);
        }
        operationResult = this.acc.findById(OperationBOTest.ID_OPE_3);
        Assert.assertNull(operationResult);
    }
}
